<?php
/**
 * Archive Page for Course Paths
 */

get_header();

$page_title       = apply_filters( 'geeks_course_path_archive_title', esc_html__( 'Browse Paths', 'geeks' ) );
$page_description = apply_filters( 'geeks_course_path_archive_desc', esc_html__( 'Get started by learning from a path below', 'geeks' ) );

geeks_display_page_header( $page_title, $page_description );

if ( have_posts() ) :

	?><div class="py-6">
		<div class="container">
			<div class="row justify-content-between align-items-center">
				<div class="col-xl-8 col-md-6 col-12"><?php 
					geeks_posts_results_count( esc_html__( 'Path', 'geeks' ), esc_html__( 'Paths', 'geeks' ) ); 
				?></div>
			</div>
		</div>
	</div>
	<div class="container">
		<?php $columns = absint( gke_get_default_paths_per_row() ); ?>
		<div class="row row-cols-1 row-cols-md-2 row-cols-lg-2 row-cols-xl-<?php echo esc_attr( $columns ); ?>">
			<?php

			while( have_posts() ) :

			the_post();

			?>
			<div class="col">
				<div class="card mb-4 card-hover">
					<div class="d-flex justify-content-between align-items-center p-4  position-relative">
						<div class="d-flex">
							<a href="<?php the_permalink(); ?>" class="stretched-link">
								<?php the_post_thumbnail( 'post-thumbnail', array( 'class' => 'avatar-md' ) ); ?>
							</a>
							<div class="ms-3">
								<h4 class="mb-1">
									<a href="<?php the_permalink(); ?>" class="text-inherit stretched-link"><?php the_title(); ?></a>
								</h4>
								<?php
								
								$courses = geeks_get_field( 'number_of_courses' );
								$hours   = geeks_get_field( 'number_of_hours' );

								if ( $courses || $hours ) :

								?>

								<p class="mb-0 fs-6">
									<?php if ( $courses ) : ?>
									<span class="me-2">
										<?php 
										/* translators: %s: span wrap start, %s: number of courses, %s: span wrap close */
										echo wp_kses_post( sprintf( esc_html__( '%s%s%s Courses', 'geeks' ), '<span class="text-dark fw-medium">', $courses, '</span>' ) ); 
										?>
									</span>
									<?php endif; ?>
									<?php if ( $hours ) : ?>
									<span>
										<?php 
										/* translators: %s: span wrap start, %s: number of hours, %s: span wrap close */
										echo wp_kses_post( sprintf( esc_html__( '%s%s%s Hours', 'geeks' ), '<span class="text-dark fw-medium">', $hours, '</span>' ) ); 
										?>
									</span>
									<?php endif; ?>
								</p>
								<?php
								endif; 
								?>
							</div>
						</div>
					</div>
				</div>
			</div>
			<?php
			
			endwhile;

			?>
		</div>

		<div class="course-path__pagination">
			<?php geeks_bootstrap_pagination( null, true, 'justify-content-center' ); ?>
		</div>
	</div>
	<?php

else:

	get_template_part( 'content', 'none' );

endif;

get_footer();