<?php
/**
 * ACF Functions for blog
 */

/**
 * Get term post ID for acf get_field param
 *
 * @param WP_Term $term The WP Term.
 * @return string
 */
function geeks_acf_get_term_post_id( $term ) {
	$post_id = '';
	if ( is_a( $term, 'WP_Term' ) ) {
		$post_id = $term->taxonomy .'_' . $term->term_id;	
	}
	return $post_id;
}

/**
 * Get term field
 *
 * @param string $field_name The meta field name.
 * @param WP_Term $term The WP Term.
 * @return mixed
 */
function geeks_get_term_field( $field_name, $term ) {
	$post_id = geeks_acf_get_term_post_id( $term );
	$value   = false;
	if ( $post_id ) {
		$value = geeks_get_field( $field_name, $post_id );
	}
	return $value;
}

/**
 * Get the context class for the term.
 *
 * @param WP_Term $term The term to which the context class should be returned.
 * @return string
 */
function geeks_acf_get_term_context_class( $term ) {
	$context_class = 'text-danger';
	if ( isset( $term->taxonomy ) ) {
		$context_class = 'text-' . geeks_get_term_field( 'context_class', $term );
		if ( 'text-' === $context_class ) {
			$context_class = 'text-danger';
		}
	}
	return $context_class;
}

/**
 * Get single post main category.
 *
 * @return WP_Term
 */
function geeks_acf_get_main_category() {
	return geeks_get_field( 'main_category' );
}

/**
 * Get the layout of the taxonomy.
 */
function geeks_acf_get_tax_layout() {
	$layout = 'fullwidth';
	$term   = get_queried_object();
	
	if ( ( is_tag() || is_category() ) && is_a( $term, 'WP_Term' ) ) {
		$layout = geeks_get_term_field ( 'layout', $term );
	}

	return $layout;
}