<?php
/**
 * ACF Functions for Course Path
 */

/**
 * Get number of students in path
 */
function geeks_acf_get_path_students_count( $format = true ) {
    $students = geeks_get_field( 'number_of_students' );
    
    if ( $format ) {
        $students = absint( $students );

        if ( $students > 1000 ) {
            $students = number_format_i18n( $students/1000, 1 );
            /* translators: %s is the decimal value of number of students expressed in thousands. */
            $students = sprintf( esc_html__( '%sK', 'geeks' ), $students );
        } else {
            $students = number_format_i18n( $students );
        }
    }
    
    return $students;
}

/**
 * Get number of courses in path
 */
function geeks_acf_get_path_courses_count() {
    return geeks_get_field( 'number_of_courses' );
}

/**
 * Get number of hours in path
 */
function geeks_acf_get_path_hours_count() {
    return geeks_get_field( 'number_of_hours' );
}

/**
 * Get the about meta field of path
 */
function geeks_acf_get_path_about() {
    return geeks_get_field( 'about_path' );
}

/**
 * Get instructors assigned to this path
 */
function geeks_acf_get_path_instructors() {
    return geeks_get_field( 'instructors' );
}

/**
 * Get the display type of courses.
 */
function geeks_acf_get_path_display_type() {
    return 'blocks'; //geeks_get_field( 'display_type' );
}

/**
 * Get the section group info.
 *
 * @param int $number section number.
 */
function geeks_acf_get_path_section( $number ) {
    $number = absint( $number );
    return geeks_get_field( 'section_' . $number );
}

/**
 * Get courses in Path with display type all.
 */
function geeks_acf_get_path_courses() {
    return geeks_get_field( 'courses' );
}