<?php
/**
 * Functions used globally across the theme.
 *
 * @package Geeks
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Get read time in minutes.
 *
 * @param string $content Content to calculate the read time for.
 * @return int
 */
function geeks_get_read_time( $content ) {
	$words   = str_word_count( wp_strip_all_tags( $content ) );
	$minutes = round( $words / 200 );
	return $minutes;
}

/**
 * Get global colors
 */
function geeks_get_global_colors() {
	$colors = array(
		array(
			'_id'   => 'primary',
			'title' => 'Primary',
			'color' => '#754FFE',
		),
		array(
			'_id'   => 'secondary',
			'title' => 'Secondary',
			'color' => '#79758f',
		),
		array(
			'_id'   => 'success',
			'title' => 'Success',
			'color' => '#19cb98',
		),
		array(
			'_id'   => 'info',
			'title' => 'Info',
			'color' => '#29BAF9',
		),
		array(
			'_id'   => 'warning',
			'title' => 'Warning',
			'color' => '#ffaa46',
		),
		array(
			'_id'   => 'danger',
			'title' => 'Danger',
			'color' => '#e53f3c',
		),
		array(
			'_id'   => 'light',
			'title' => 'Light',
			'color' => '#f5f4f8',
		),
		array(
			'_id'   => 'dark',
			'title' => 'Dark',
			'color' => '#18113C',
		),
		array(
			'_id'   => 'light-primary',
			'title' => 'Light Primary',
			'color' => '#e3dcff',
		),
		array(
			'_id'   => 'light-secondary',
			'title' => 'Light Secondary',
			'color' => '#e4e3e9',
		),
		array(
			'_id'   => 'light-success',
			'title' => 'Light Success',
			'color' => '#d1f5ea',
		),
		array(
			'_id'   => 'light-danger',
			'title' => 'Light Danger',
			'color' => '#fad9d8',
		),
		array(
			'_id'   => 'light-warning',
			'title' => 'Light Warning',
			'color' => '#ffeeda',
		),
		array(
			'_id'   => 'light-info',
			'title' => 'Light Info',
			'color' => '#e1f6ff',
		),
		array(
			'_id'   => 'light-dark',
			'title' => 'Light Dark',
			'color' => '#d1cfd8',
		),
		array(
			'_id'   => 'dark-primary',
			'title' => 'Dark Primary',
			'color' => '#593cc1',
		),
		array(
			'_id'   => 'dark-secondary',
			'title' => 'Dark Secondary',
			'color' => '#5c596d',
		),
		array(
			'_id'   => 'dark-success',
			'title' => 'Dark Success',
			'color' => '#139a74',
		),
		array(
			'_id'   => 'dark-danger',
			'title' => 'Dark Danger',
			'color' => '#ae302e',
		),
		array(
			'_id'   => 'dark-warning',
			'title' => 'Dark Warning',
			'color' => '#c28135',
		),
		array(
			'_id'   => 'dark-info',
			'title' => 'Dark Info',
			'color' => '#51a0c2',
		),
		array(
			'_id'   => 'white',
			'title' => 'White',
			'color' => '#FFF',
		),
	);
	return apply_filters( 'geeks_global_colors', $colors );
}

/**
 * Remove background class
 *
 * @param string $search  The class to search.
 * @param array  $classes The array of classes.
 * @return array
 */
function geeks_remove_bg_class( $search, $classes ) {
	$key = array_search( $search, $classes );
	if ( false !== $key ) {
		unset( $classes[$key] );
	}
	return $classes;
}

/**
 * Render the content of the post.
 *
 * @param int $post_id The Post ID.
 * @param bool $echo Should return or display.
 * @return void|string
 */
function geeks_render_content( $post_id, $echo = false ) {
	if ( did_action( 'elementor/loaded' ) ) {
		$content = Elementor\Plugin::instance()->frontend->get_builder_content_for_display( $post_id );
	} else {
		$content = get_the_content( null, false, $post_id );
		$content = apply_filters( 'the_content', $content );
		$content = str_replace( ']]>', ']]&gt;', $content );
	}

	if ( $echo ) {
		echo wp_kses_post( $content );
	} else {
		return $content;
	}
}

/*
 * WP_Query Object
 *
 * @param array $query_args array of arguments for Wp_Query class.
 * @return object
 */
function geeks_get_posts( $query_args = array() ) {

	if ( isset( $query_args[ 'post_type' ] ) && ! empty( $query_args[ 'post_type' ] ) && 'by_id' !== $query_args[ 'post_type' ] ) {

		if ( isset( $query_args[ 'include' ] ) && ! empty( $query_args[ 'include' ] ) && is_array( $query_args[ 'include' ] ) && in_array( 'authors', $query_args[ 'include' ] ) ) {
			
			if ( isset( $query_args[ 'include_authors' ] ) && ! empty( $query_args[ 'include_authors' ] ) && is_array( $query_args[ 'include_authors' ] ) ) {
				$query_args[ 'author__in' ] = $query_args[ 'include_authors' ];
			}
		}

		if ( isset( $query_args[ 'include' ] ) && ! empty( $query_args[ 'include' ] ) && is_array( $query_args[ 'include' ] ) && in_array( 'terms', $query_args[ 'include' ] ) ) {
			
			if ( isset( $query_args[ 'include_terms' ] ) && ! empty( $query_args[ 'include_terms' ] ) && is_array( $query_args[ 'include_terms' ] ) ) {
				
				$terms    = [];
				$taxonomy = '';
				$term_slugs = $query_args[ 'include_terms' ];

				foreach( $term_slugs as $slug ) {
				
					$field      = 'slug';
					$post_type  = $query_args[ 'post_type' ];
					$taxonomies = get_object_taxonomies( $post_type );

					foreach( $taxonomies as $tax ) {
						$term_data = get_term_by( $field, $slug, $tax );
						if ( false !== $term_data ) {
							break;
						}
					}

					if ( false !== $term_data ) {
						$taxonomy = $term_data->taxonomy;
						$terms[ $taxonomy ][] = $term_data->slug;
					}
				}

				$query_args['tax_query'] = array(
					'relation' => 'OR',
				);

				foreach ( $terms as $taxonomy => $slugs ) {
					$terms_query = [
						'taxonomy' => $taxonomy,
						'field' => 'slug',
						'terms' => $slugs,
					];

					$query_args['tax_query'][] = $terms_query;
				}
			}
		}
	}

	if ( isset( $query_args[ 'post_type' ] ) && ! empty( $query_args[ 'post_type' ] ) && 'by_id' === $query_args[ 'post_type' ] ) {
		if ( isset( $query_args[ 'tax_query' ] ) && ! empty( $query_args[ 'tax_query' ] ) ) {
			unset( $query_args[ 'tax_query' ] );
		}

		if ( isset( $query_args[ 'author__in' ] ) && ! empty( $query_args[ 'author__in' ] ) ) {
			unset( $query_args[ 'author__in' ] );
		}

		$query_args[ 'post_type' ] = 'any';

		$post_ids = explode( ',', $query_args[ 'posts_ids' ] );

		$query_args[ 'post__in' ] = $post_ids;
	}

	$defaults_args = array( 
		'post_type'      => 'post',
		'posts_per_page' => 10
	);

	$query_args = wp_parse_args( $query_args, $defaults_args );

	$posts_query = new WP_Query( $query_args ); 

	return $posts_query;
}
