<?php
/**
 * Geeks Theme Customizer
 *
 * @package Geeks
 */

if ( ! function_exists( 'geeks_sass_hex_to_rgba' ) ) {
	function geeks_sass_hex_to_rgba( $hex, $alpa = '' ) {
		$hex = sanitize_hex_color( $hex );
		preg_match( '/^#?([0-9a-f]{2})([0-9a-f]{2})([0-9a-f]{2})$/i', $hex, $matches );
		for ( $i = 1; $i <= 3; $i++ ) {
			$matches[ $i ] = hexdec( $matches[ $i ] );
		}
		if ( ! empty( $alpa ) ) {
			$rgb = 'rgba(' . $matches[1] . ', ' . $matches[2] . ', ' . $matches[3] . ', ' . $alpa . ')';
		} else {
			$rgb = 'rgba(' . $matches[1] . ', ' . $matches[2] . ', ' . $matches[3] . ')';
		}
		return $rgb;
	}
}

if ( ! function_exists( 'geeks_sass_yiq' ) ) {
	function geeks_sass_yiq( $hex ) {
		$hex    = sanitize_hex_color( $hex );
		$length = strlen( $hex );
		if ( $length < 5 ) {
			$hex = ltrim( $hex, '#' );
			$hex = '#' . $hex . $hex;
		}

		preg_match( '/^#?([0-9a-f]{2})([0-9a-f]{2})([0-9a-f]{2})$/i', $hex, $matches );

		for ( $i = 1; $i <= 3; $i++ ) {
			$matches[ $i ] = hexdec( $matches[ $i ] );
		}
		$yiq = ( ( $matches[1] * 299 ) + ( $matches[2] * 587 ) + ( $matches[3] * 114 ) ) / 1000;
		return ( $yiq >= 128 ) ? '#000' : '#fff';
	}
}

/**
 * Get all of the geeks theme colors.
 *
 * @return array $geeks_theme_colors The geeks Theme Colors.
 */
if ( ! function_exists( 'geeks_get_theme_colors' ) ) {
	function geeks_get_theme_colors() {
		$geeks_theme_colors = array(
			'primary_color' => get_theme_mod( 'geeks_primary_color', apply_filters( 'geeks_default_primary_color', '#754ffe' ) ),
		);

		return apply_filters( 'geeks_get_theme_colors', $geeks_theme_colors );
	}
}

/**
 * Get Customizer Color css.
 *
 * @see geeks_get_custom_color_css()
 * @return array $styles the css
 */
if ( ! function_exists( 'geeks_get_custom_color_css' ) ) {
	function geeks_get_custom_color_css() {
		$geeks_theme_colors        = geeks_get_theme_colors();
		$primary_color             = $geeks_theme_colors['primary_color'];
		$primary_color_yiq         = geeks_sass_yiq( $primary_color );
		$primary_color_darken_10p  = geeks_adjust_color_brightness( $primary_color, -4.5 );
		$primary_color_darken_15p  = geeks_adjust_color_brightness( $primary_color, -5.7 );
		$primary_color_lighten_20p = geeks_adjust_color_brightness( $primary_color, 20 );
		$primary_color_lighten_10p = geeks_adjust_color_brightness( $primary_color, 27.7 );


		$styles =
		'
/*
 * Primary Color
 */


';

		return apply_filters( 'geeks_get_custom_color_css', $styles );
	}
}


/**
 * Add CSS in <head> for styles handled by the theme customizer
 *
 * @since 1.0.0
 * @return void
 */
if ( ! function_exists( 'geeks_enqueue_custom_color_css' ) ) {
	function geeks_enqueue_custom_color_css() {
		if ( get_theme_mod( 'geeks_enable_custom_color', 'no' ) === 'yes' ) {
			$geeks_theme_colors        = geeks_get_theme_colors();

			$primary_color             = $geeks_theme_colors['primary_color'];
			$primary_color_yiq         = geeks_sass_yiq( $primary_color );
			$primary_color_darken_10p  = geeks_adjust_color_brightness( $primary_color, -18 );
			$primary_color_darken_15p  = geeks_adjust_color_brightness( $primary_color, -5.7 );
			$primary_color_darken_45p  = geeks_adjust_color_brightness( $primary_color, -45 );
			$primary_color_opacity     = geeks_sass_hex_to_rgba( $primary_color, '.05' );
			$primary_color_outline_25  = geeks_sass_hex_to_rgba( $primary_color, '.25' );
			$primary_color_bg_outline  = geeks_sass_hex_to_rgba( $primary_color, '.08' );
			$primary_color_outline_70  = geeks_sass_hex_to_rgba( $primary_color, '.7' );
			$primary_color_outline_5   = geeks_sass_hex_to_rgba( $primary_color, '.5' );
			$primary_color_opacity_15  = geeks_sass_hex_to_rgba( $primary_color, '.20' );


			$color_root = ':root { --bs-primary: ' . $geeks_theme_colors['primary_color'] . ';  --bs-primary-bg-d
			: ' . $primary_color_darken_10p . '; --bs-primary-border-d: ' . $primary_color_darken_15p . ';  --bs-primary-o-5: ' . $primary_color_opacity . ';  --bs-primary-outline-25: ' . $primary_color_outline_25 . '; --bs-primary-outline-bg: ' . $primary_color_bg_outline . '; --bs-dark-primary: ' . $primary_color_darken_45p . ';  --bs-primary-outline-5: ' .$primary_color_outline_5 .'; --bs-primary-outline-75: ' . $primary_color_outline_70 . '; --bs-primary-opacity-15: ' . $primary_color_opacity_15 . ';}';
			$styles     = $color_root . geeks_get_custom_color_css();

			wp_add_inline_style( 'geeks-color', $styles );
		}
	}
}


add_action( 'wp_enqueue_scripts', 'geeks_enqueue_custom_color_css', 130 );
