<?php
/**
 * Geeks GKE Customizer Class
 *
 * @package  geeks
 * @since    1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

if ( ! class_exists( 'Geeks_GKE_Customizer' ) ) :


    class Geeks_GKE_Customizer extends Geeks_Customizer {
        /**
         * Setup class.
         *
         * @since 1.0.0
         * @return void
         */
        public function __construct() {
            add_action( 'customize_register', array( $this, 'customize_paths' ), 10 );
        }

       
        /**
         * Add postMessage support for site title and description for the Theme Customizer along with several other settings.
         *
         * @param WP_Customize_Manager $wp_customize Theme Customizer object.
         * @since 2.4.0
         */
    
        public function customize_paths( $wp_customize ) {
            /**
             * path
             */
            $wp_customize->add_section( 'geeks_path', [
                'priority' => 100,
                'title'    => esc_html__( 'Paths', 'geeks' ),
            ] );

            $this->add_path_section( $wp_customize );
        }

        private function add_path_section( $wp_customize ) {

            $wp_customize->add_setting( 'geeks_path_title', [
                'default'           => 'no',
                'sanitize_callback' => 'sanitize_key',
            ] );
            
            $wp_customize->add_control( 'geeks_path_title', [
                    'type'        => 'text',
                    'section'     => 'geeks_path',
                    'label'       => esc_html__( 'Add a Title for your path', 'geeks' ),
                    'description' => esc_html__( 'This setting allows you to add a title', 'geeks' ),
            ] );

            $wp_customize->selective_refresh->add_partial( 'geeks_path_title', [
                'fallback_refresh'    => true
            ] );

            $wp_customize->add_setting( 'geeks_path_description', [
                'default'           => 'no',
                'sanitize_callback' => 'sanitize_key',
            ] );

            $wp_customize->add_control( 'geeks_path_description', [
                    'type'        => 'text',
                    'section'     => 'geeks_path',
                    'label'       => esc_html__( 'Add a description for your path', 'geeks' ),
                    'description' => esc_html__( 'This setting allows you to add a description', 'geeks' ),
            ] );

            $wp_customize->selective_refresh->add_partial( 'geeks_path_description', [
                'fallback_refresh'    => true
            ] );

            $wp_customize->add_setting( 'geeks_path_to_show', [
                'default'           => 'no',
                'sanitize_callback' => 'sanitize_key',
            ] );

            $wp_customize->add_control( 'geeks_path_to_show', [
                    'type'        => 'number',
                    'section'     => 'geeks_path',
                    'label'       => esc_html__( 'Number of Paths to show', 'geeks' ),
                    'description' => esc_html__( 'This setting allows you to add a description', 'geeks' ),
            ]);

             $wp_customize->selective_refresh->add_partial( 'geeks_path_to_show', [
                'fallback_refresh'    => true
            ] );
        }
    }

endif;

return new Geeks_GKE_Customizer();