<?php

/**
 * Get the courses orderby options
 */
function geeks_courses_get_orderby_options() {
	$orderby_options = apply_filters(
		'geeks_courses_orderby_options',
		[
			'menu_order' => esc_html__( 'Sort by', 'geeks' ),
			'date'       => esc_html__( 'Newest', 'geeks' ),
			'title'      => esc_html__( 'A &rarr; Z', 'geeks' ),
			'price'      => esc_html__( 'Price &uarr;', 'geeks' ),
			'price-desc' => esc_html__( 'Price &darr;', 'geeks' ),
			'popularity' => esc_html__( 'Most Popular', 'geeks' ),
			'rating'     => esc_html__( 'Highest Rating', 'geeks' ),
		]
	);

	return $orderby_options;
}

/**
 * Get duration of the course
 */
function geeks_get_course_duration() {
	$duration = geeks_acf_get_course_duration();

	if ( $duration ) {
		$duration = strtotime( "+" . $duration . ' minutes', 0 );		
	} else {
		$course = learn_press_get_course();

		if ( $course ) {
			$duration = $course->get_duration();
		}
	}

	return $duration;
}

/**
 * Get duration of the course in a humanized form
 */
function geeks_get_course_duration_humanized() {

	$duration = geeks_get_course_duration();
	
	if ( $duration && class_exists( 'Geeks_Duration' ) ) {
		$duration = new Geeks_Duration( $duration );
		return $duration->humanize();
	}

	return $duration;
}

/**
 * Get course rating info
 */
function geeks_get_course_rating_info() {

	$course_id = get_the_ID();
	$rating    = get_post_meta( $course_id, '_geeks_lp_average_rating', true );
	$count     = get_post_meta( $course_id, '_geeks_lp_review_count', true );

	return [ 'rating' => $rating, 'count' => $count ];
}


function geeks_course_the_review_stars() {
	if ( ! function_exists( 'learn_press_get_course_rate' ) || LP_COURSE_CPT !== get_post_type() ) {
		return;
	}
	$course_rate_res = learn_press_get_course_rate( get_the_ID(), false );
	learn_press_course_review_template( 'rating-stars.php', array( 'rated' => $course_rate_res['rated'] ) );
}

/**
 * Get curriculum section main class
 */
function geeks_get_section_main_class( $section ) {
	$class = array( 'section' );

	if ( ! $section->count_items() ) {
		$class[] = 'section-empty';
	}

	return implode( ' ', $class );
}

if ( ! function_exists( 'geeks_get_single_course_version' ) ) {
	function geeks_get_single_course_version() {
		$style = geeks_get_field( 'geeks_course_style' );

		if ( $style ) {
			$course_version = $style;
		} else {
			$course_version = get_theme_mod( 'single_course_version', 'v1' );
		}

		return apply_filters( 'geeks_single_course_version', $course_version );
	}
}


if ( ! function_exists( 'geeks_is_lesson' ) ) {
	function geeks_is_lesson() {
		global $lp_course_item;
		return $lp_course_item;
	}
}

require get_template_directory() . '/inc/learnpress/functions/courses.php';
require get_template_directory() . '/inc/learnpress/functions/tax.php';
require get_template_directory() . '/inc/learnpress/functions/instructor.php';
require get_template_directory() . '/inc/learnpress/functions/profile.php';
require get_template_directory() . '/inc/learnpress/functions/global.php';