<?php
/**
 * Template functions related to profile pages
 */

if ( ! function_exists( 'geeks_lp_user_become_teacher_registration_form' ) ) {
	/**
	 * Add instructor registration button to register page and admin bar
	 */
	function geeks_lp_user_become_teacher_registration_form() {
		if ( LP()->settings->get( 'instructor_registration' ) != 'yes' ) {
			return;
		}
		?>
		<div class="mb-3">
			<div class="form-check">
				<input type="checkbox" name="become_teacher" id="become_teacher" class="form-check-input">
				<label for="become_teacher" class="form-check-label"><?php esc_html_e( 'Want to become an instructor?', 'geeks' ); ?></label>
			</div>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_profile_display_register_link' ) ) {
	/**
	 * Displays register link below sign in form title
	 */
	function geeks_profile_display_register_link() {
		
		if ( geeks_profile_is_register() ) :
		
		?><span><?php esc_html_e( 'Don\'t have an account?', 'geeks' ); ?><a href="#view-register" data-view="#view-register" class="ms-1"><?php esc_html_e( 'Sign up', 'geeks' ); ?></a></span><?php
		
		endif;
	}
}

if ( ! function_exists( 'geeks_profile_display_login_link' ) ) {
	/**
	 * Displays sign in link below sign in form title
	 */
	function geeks_profile_display_login_link() {
		
		if ( geeks_profile_is_login() ) :

		?><span><?php esc_html_e( 'Already have an account?', 'geeks' ); ?><a href="#view-login" data-view="#view-login" class="ms-1"><?php esc_html_e( 'Sign in', 'geeks' ); ?></a></span><?php

		endif;
	}
}

if ( ! function_exists( 'geeks_profile_login_register_wrap_start' ) ) {
	/**
	 * Output Wrapper Start for Login/Register
	 */
	function geeks_profile_login_register_wrap_start() {

		if ( ! geeks_profile_is_login_register() ) {
			return;
		}

		?>
		<div class="container d-flex flex-column">
			<div class="row align-items-center justify-content-center g-0 min-vh-100">
				<div class="col-lg-5 col-md-8 py-8 py-xl-0"><?php
					learn_press_print_messages( true );
	}
}

if ( ! function_exists( 'geeks_profile_login_register_wrap_end' ) ) {
	/**
	 * Output Wrapper End for Login/Register
	 */
	function geeks_profile_login_register_wrap_end() {

		if ( ! geeks_profile_is_login_register() ) {
			return;
		}
				?>
				</div><!-- /.col -->
			</div><!-- /.row -->
		</div><!-- /.container -->
		<?php
	}
}

if ( ! function_exists( 'geeks_profile_lost_password_form' ) ) {
	/**
	 * Display Lost Password Form
	 */
	function geeks_profile_lost_password_form() {
		if ( geeks_profile_is_login() ) {
			learn_press_get_template( 'global/form-lost-password' );
		}
	}
}

if ( ! function_exists( 'geeks_profile_page_wrap_start' ) ) {
	/**
	 * Wraps Profile page
	 */
	function geeks_profile_page_wrap_start() {
		
		if ( geeks_is_public_profile() ) {
			return;
		}

		?><div class="pt-5 pb-5">
			<div class="container"><?php
	}
}

if ( ! function_exists( 'geeks_profile_page_wrap_end' ) ) {
	/**
	 * Wraps End Profile page
	 */
	function geeks_profile_page_wrap_end() {
		
		if ( geeks_is_public_profile() ) {
			return;
		}

			?></div>
		</div><?php
	}
}

if ( ! function_exists( 'geeks_profile_header' ) ) {
	/**
	 * Display Profile Header
	 */
	function geeks_profile_header() {
		$profile = LP_Global::profile();

		if ( $profile->get_user()->is_guest() ) {
			return;
		}

		learn_press_get_template( 'profile/profile-header.php', array( 'profile' => $profile ) );
	}
}

if ( ! function_exists( 'geeks_profile_sidebar_wrap_start' ) ) {
	/**
	 * Profile page sidebar wrapper start
	 */
	function geeks_profile_sidebar_wrap_start() {

		if ( geeks_profile_is_login_register() ) {
			return;
		}
		
		if ( geeks_is_public_profile() ) : ?>
		
		<div class="py-5 py-md-5">
			<div class="container">
				<div class="row">
					<div class="geeks__sidebar col-lg-3 col-md-4 col-12">
		
		<?php else: ?>

		<div class="row mt-0 mt-md-4">
			<div class="geeks__sidebar col-lg-3 col-md-4 col-12">
		
		<?php endif;
	}
}

if ( ! function_exists( 'geeks_profile_sidebar_wrap_end' ) ) {
	/**
	 * Profile page sidebar wrapper end
	 */
	function geeks_profile_sidebar_wrap_end() {

		if ( geeks_profile_is_login_register() ) {
			return;
		}
		
		?></div><!-- /.geeks__sidebar --><?php
	}
}

if ( ! function_exists( 'geeks_profile_content_wrap_start' ) ) {
	/**
	 * Profile page content wrapper start
	 */
	function geeks_profile_content_wrap_start() {
		
		if ( geeks_profile_is_login_register() ) {
			return;
		}

		?><div class="geeks__content col-lg-9 col-md-8 col-12"><?php
	}
}

if ( ! function_exists( 'geeks_profile_content_wrap_end' ) ) {
	/**
	 * Profile page content wrapper end
	 */
	function geeks_profile_content_wrap_end() {

		if ( geeks_profile_is_login_register() ) {
			return;
		}
		
		if ( geeks_is_public_profile() ) : ?>
		
					</div><!-- /.geeks__content -->
				</div><!-- .row -->
			</div><!-- .container -->
		</div>
		
		<?php else: ?>

				</div><!-- /.geeks__content -->
			</div><!-- .row -->
		</div>
		
		<?php endif;
	}
}