<?php
/**
 * Template functions used in the taxonomy pages
 *
 */

if ( ! function_exists( 'geeks_courses_tax_header_description' ) ) {
	/**
	 * Outputs header description in tax archive pages
	 */
	function geeks_courses_tax_header_description() {
		$description = '';

		$is_override = Geeks_ACF_Course_Category::get_override_desc();

		if ( ! $is_override ) {
			$description = get_the_archive_description();
		} else {
			$students    = Geeks_ACF_Course_Category::get_students_enrolled();
			
			if ( $students ) {
				$description = sprintf( _nx( '%s student is learning %s.', '%s students are learning %s.', $students, 'students enrolled', 'geeks' ), number_format_i18n( $students ), learn_press_page_title( false ) );
			}
		}
		
		if ( ! empty( $description ) ) :
		?><div class="mt-1 mb-0 text-white lead mb-0-last-child"><?php echo wp_kses( $description, [ 'p' => [] ] ); ?></div><?php
		endif;
	}
}

if ( ! function_exists( 'geeks_after_course_category_header' ) ) {
	/**
	 * Display Content after course category header
	 */
	function geeks_after_course_category_header() {
		if ( learn_press_is_course_tax() ) {
			do_action( 'geeks_after_courses_tax_header' );
		}
	}
}

if ( ! function_exists( 'geeks_course_category_display_tabs' ) ) {
	/**
	 * Displays Courses tabs in tax archive pages
	 */
	function geeks_course_category_display_tabs() {
		$content_before = Geeks_ACF_Course_Category::get_content_before_courses();
		$is_enabled     = Geeks_ACF_Course_Category::get_enable_tabs();
		$should_display = ( 'simple' === $content_before && $is_enabled );

		if ( ! $should_display ) {
			return;
		}

		$tab_1  = Geeks_ACF_Course_Category::get_tab_1();
		$tab_2  = Geeks_ACF_Course_Category::get_tab_2();
		$tabs   = apply_filters( 'geeks_course_category_tabs', [ $tab_1, $tab_2 ] );
		$sec_id = uniqid( 'course-category-tab-' );
		$con_id = $sec_id . '-content';

		if ( ! empty( $tabs ) ) : ?>
		<div class="col-12 mb-6">
			<ul class="nav nav-lb-tab mb-6" id="<?php echo esc_attr( $sec_id ); ?>" role="tablist">

			<?php 
			$i = 0; 
			foreach ( $tabs as $key => $tab ) :

				$tab_id     = $sec_id . '-' . $key . '-tab';
				$content_id = $sec_id . '-' . $key . '-tab-content';
				$item_atts  = [
					'class' => 'nav-item',
					'role'  => 'presentation',
				];
				$link_atts  = [
					'class' => 'nav-link',
					'id'    => $tab_id,
					'data-bs-toggle' => 'pill',
					'href'  => '#' . $content_id,
					'role'  => 'tab',
					'aria-controls' => $content_id
				];

				if ( 0 === $i++ ) {
					$item_atts['class']        .= ' ms-0';
					$link_atts['class']        .= ' active';
					$link_atts['aria-selected'] = 'true';
				} else {
					$link_atts['aria-selected'] = 'false';
				}
				?>
				<li <?php echo geeks_get_render_attribute_string( $item_atts ); ?>>
					<a <?php echo geeks_get_render_attribute_string( $link_atts ); ?>>
						<?php echo esc_html( $tab['title'] ); ?>
					</a>
				</li>
			<?php endforeach; ?>
			</ul>
			
			<div class="tab-content" id="<?php echo esc_attr( $con_id ); ?>">
			<?php 
			$i = 0; 
			foreach ( $tabs as $key => $tab ) :
				$tab_id       = $sec_id . '-' . $key . '-tab';
				$content_id   = $sec_id . '-' . $key . '-tab-content';
				$content_atts = [
					'class'           => 'tab-pane fade mb-0-last-child',
					'id'              => $content_id,
					'role'            => 'tabpanel',
					'aria-labelledby' => $tab_id
				];

				if ( 0 === $i++ ) {
					$content_atts['class'] .= ' show active';
				}

				$results = geeks_acf_process_courses_field( $tab, true );

				?><div <?php echo geeks_get_render_attribute_string( $content_atts ); ?>>
					<?php geeks_output_courses( $results ); ?>
				</div><?php

			endforeach; ?>
			</div>
		
		</div>
		<?php

		endif;
	}
}


if ( ! function_exists( 'geeks_course_category_display_courses' ) ) {
	/**
	 * Displays Courses in tax archive pages
	 */
	function geeks_course_category_display_courses() {
		$content_before = Geeks_ACF_Course_Category::get_content_before_courses();
		$is_enabled     = Geeks_ACF_Course_Category::get_enable_courses();
		$should_display = ( 'simple' === $content_before && $is_enabled );

		if ( ! $should_display ) {
			return;
		}

		$section = Geeks_ACF_Course_Category::get_section_courses();

		?><section class="col-12 mb-6 mb-0-last-child">
			
			<?php if ( ! empty( $section['title'] ) ) : ?>
			<header class="mb-5">
				<h2 class="mb-1"><?php echo esc_html( $section['title'] ); ?></h2>
				<?php if ( ! empty( $section['description'] ) ) : ?>
				<p class="mb-0"><?php echo esc_html( $section['description'] ); ?></p>
				<?php endif; ?>
			</header>
			<?php endif; ?>

			<?php geeks_output_courses( $section['results'] ); ?>

		</section><?php
	}
}

if ( ! function_exists( 'geeks_course_category_display_instructors' ) ) {
	/**
	 * Displays instructors in tax archive pages
	 */
	function geeks_course_category_display_instructors() {
		$content_before = Geeks_ACF_Course_Category::get_content_before_courses();
		$is_enabled     = Geeks_ACF_Course_Category::get_enable_instructors();
		$should_display = ( 'simple' === $content_before && $is_enabled );

		if ( ! $should_display ) {
			return;
		}

		$section = Geeks_ACF_Course_Category::get_section_instructors();

		?><section class="col-12 mb-6 mb-0-last-child">

			<?php if ( ! empty( $section['title'] ) ) : ?>
			<header class="mb-5">
            	<h2 class="mb-1"><?php echo esc_html( $section['title'] ); ?></h2>
            	<?php if ( ! empty( $section['description'] ) ) : ?>
            	<p class="mb-0"><?php echo esc_html( $section['description'] ); ?></p>
            	<?php endif; ?>
          	</header>
          	<?php endif; ?>

          	<?php geeks_output_instructors( $section['results'] ); ?>

		</section><?php
	}
}

if ( ! function_exists( 'geeks_course_category_display_courses_header' ) ) {
	/*
	 * Displays a header just above courses top bar
	 */
	function geeks_course_category_display_courses_header() {
		$is_enabled = Geeks_ACF_Course_Category::is_courses_header_enabled();

		if ( ! $is_enabled ) {
			return;
		}

		$header = Geeks_ACF_Course_Category::get_courses_header();

		if ( ! empty( $header['title'] ) ) :

		?><div class="col-lg-12 col-md-12 col-12">
			<div class="mb-5">
            	<h2 class="mb-1"><?php echo esc_html( $header['title'] ); ?></h2>
            	<?php if ( ! empty( $header['description'] ) ) : ?>
            	<p class="mb-0"><?php echo esc_html( $header['description'] ); ?></p>
              	<?php endif; ?>
          	</div>
        </div><?php

    	endif;
	}
}