<?php
/**
 * Geeks OCDI Class
 *
 * @package  geeks
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Geeks_OCDI' ) ) :
	/**
	 * The one click demo import class.
	 */
	class Geeks_OCDI {
		/**
		 * Stores the assets URL.
		 *
		 * @var string
		 */
		public $assets_url;
		/**
		 * Stores the demo URL.
		 *
		 * @var string
		 */
		public $demo_url;
		/**
		 * Instantiate the class.
		 */
		public function __construct() {
			$this->assets_url = 'https://transvelo.github.io/geeks/assets/';
			$this->demo_url   = 'https://geeks.madrasthemes.com/';

			add_filter( 'pt-ocdi/confirmation_dialog_options', [ $this, 'confirmation_dialog_options' ], 10, 1 );

			add_action( 'pt-ocdi/import_files', [ $this, 'import_files' ] );
			add_action( 'pt-ocdi/before_content_import', [ $this, 'set_widgets_area_before_import_content' ] );
			add_action( 'pt-ocdi/before_widgets_import', [ $this, 'clear_default_widgets' ] );

			add_action( 'pt-ocdi/after_import', [ $this, 'import_wpforms' ] );
			add_action( 'pt-ocdi/after_import', [ $this, 'set_nav_menus' ] );
			add_action( 'pt-ocdi/after_import', [ $this, 'set_site_options' ] );
			add_action( 'pt-ocdi/after_import', [ $this, 'replace_uploads_dir' ] );

			add_action( 'pt-ocdi/enable_wp_customize_save_hooks', '__return_true' );
			add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );
		}
		/**
		 * Confirmation dialog box options.
		 *
		 * @param array $options The dialog options.
		 * @return array
		 */
		public function confirmation_dialog_options( $options ) {
			return array_merge(
				$options,
				array(
					'width' => 410,
				)
			);
		}

		/**
		 * Trigger after import
		 */
		public function trigger_ocdi_after_import() {
			$import_files    = $this->import_files();
			$selected_import = end( $import_files );
			do_action( 'pt-ocdi/after_import', $selected_import );
		}
		/**
		 * Replace uploads Dir.
		 *
		 * @param array $selected_import The import that just ran.
		 */
		public function replace_uploads_dir( $selected_import ) {
			if ( isset( $selected_import['uploads_dir'] ) ) {
				$from = $selected_import['uploads_dir'] . '/';
			} else {
				$from = 'https://geeks.madrasthemes.com/demo/wp-content/uploads/';
			}

			$site_upload_dir = wp_get_upload_dir();
			$to              = $site_upload_dir['baseurl'] . '/';
			\Elementor\Utils::replace_urls( $from, $to );
		}
		/**
		 * Set widgets area options.
		 */
		public function set_widgets_area_before_import_content() {
			set_theme_mod( 'geeks_enable_sidebar_widget_area', true );
			set_theme_mod( 'blog_layout', 'fullwidth' );
		}
		/**
		 * Clear default widgets.
		 */
		public function clear_default_widgets() {
			$sidebars_widgets = get_option( 'sidebars_widgets' );
			$all_widgets      = array();

			array_walk_recursive(
				$sidebars_widgets,
				function ( $item, $key ) use ( &$all_widgets ) {
					if ( ! isset( $all_widgets[ $key ] ) ) {
						$all_widgets[ $key ] = $item;
					} else {
						$all_widgets[] = $item;
					}
				}
			);

			if ( isset( $all_widgets['array_version'] ) ) {
				$array_version = $all_widgets['array_version'];
				unset( $all_widgets['array_version'] );
			}

			$new_sidebars_widgets = array_fill_keys( array_keys( $sidebars_widgets ), array() );

			$new_sidebars_widgets['wp_inactive_widgets'] = $all_widgets;
			if ( isset( $array_version ) ) {
				$new_sidebars_widgets['array_version'] = $array_version;
			}

			update_option( 'sidebars_widgets', $new_sidebars_widgets );

		}
		/**
		 * Set site options.
		 *
		 * @param array $selected_import The import that just ran.
		 */
		public function set_site_options( $selected_import ) {
			if ( isset( $selected_import['set_pages'] ) && $selected_import['set_pages'] ) {
				$front_page_title = isset( $selected_import['front_page_title'] ) ? $selected_import['front_page_title'] : 'Home';
				$front_page_id    = get_page_by_title( $front_page_title );
				$blog_page_id     = get_page_by_title( 'Geeks Newsroom' );

				update_option( 'show_on_front', 'page' );
				update_option( 'page_on_front', $front_page_id->ID );
				update_option( 'page_for_posts', $blog_page_id->ID );

			}

			if ( 'learndash' !== $selected_import['plugin_profile'] ) {
				/*
				* Tutor Page Setup
				*/
				(bool) tutor_utils()->update_option( 'course_archive_filter', true );
				tutor_utils()->update_option( 'courses_per_page', 9 );
				tutor_utils()->update_option(
					'supported_course_filters',
					array(
						'category'         => 1,
						'difficulty_level' => 1,
					)
				);
			}

			update_option( 'posts_per_page', 9 );
			set_theme_mod( 'enable_full_width_sticky_post', true );
			set_theme_mod( 'geeks_single_post_social_share', true );
			// Enable Registration on site.
			update_option( 'users_can_register', 1 );

		}
		/**
		 * Set the nav menus.
		 *
		 * @param array $selected_import The import that just ran.
		 */
		public function set_nav_menus( $selected_import ) {
			if ( isset( $selected_import['set_nav_menus'] ) && $selected_import['set_nav_menus'] ) {
				$main_menu       = get_term_by( 'name', 'Main Menu', 'nav_menu' );
				$social_menu     = get_term_by( 'name', 'Social Icons', 'nav_menu' );
				$footer_menu     = get_term_by( 'name', 'Footer Menu', 'nav_menu' );
				$blog_categories = get_term_by( 'name', 'Blog Categories Menu', 'nav_menu' );

				$locations = [
					'navbar'          => $main_menu->term_id,
					'social'          => $social_menu->term_id,
					'footer'          => $footer_menu->term_id,
					'blog_categories' => $blog_categories->term_id,
				];

				set_theme_mod( 'nav_menu_locations', $locations );
			}
		}
		/**
		 * Import WPForms.
		 */
		public function import_wpforms() {

			$assets_url = get_template_directory_uri() . '/assets/demo/';

			if ( ! function_exists( 'wpforms' ) || get_option( 'geeks_wpforms_imported', false ) ) {
				return;
			}

			$wpform_file_url = $assets_url . 'wpforms/all.json';
			$response        = wp_remote_get( $wpform_file_url );

			if ( is_wp_error( $response ) || 200 !== $response['response']['code'] ) {
				return;
			}

			$form_json = wp_remote_retrieve_body( $response );

			if ( is_wp_error( $form_json ) ) {
				return;
			}

			$forms = json_decode( $form_json, true );

			foreach ( $forms as $form_data ) {
				$form_title = $form_data['settings']['form_title'];

				if ( ! empty( $form_data['id'] ) ) {
					$form_content = array(
						'field_id' => '0',
						'settings' => array(
							'form_title' => sanitize_text_field( $form_title ),
							'form_desc'  => '',
						),
					);

					// Merge args and create the form.
					$form = array(
						'import_id'    => (int) $form_data['id'],
						'post_title'   => esc_html( $form_title ),
						'post_status'  => 'publish',
						'post_type'    => 'wpforms',
						'post_content' => wpforms_encode( $form_content ),
					);

					$form_id = wp_insert_post( $form );
				} else {
					// Create initial form to get the form ID.
					$form_id = wpforms()->form->add( $form_title );
				}

				if ( empty( $form_id ) ) {
					continue;
				}

				$form_data['id'] = $form_id;
				// Save the form data to the new form.
				wpforms()->form->update( $form_id, $form_data );
			}

			update_option( 'geeks_wpforms_imported', true );
		}


		/**
		 * Import Files from each demo.
		 */
		public function import_files() {
			$ocdi_host   = 'https://madrasthemes.github.io/assets/geeks';
			$dd_url      =  get_template_directory_uri() . '/assets/demo/';
			$dd_url_ln   =  get_template_directory_uri() . '/assets/demo/learndash/';
			$preview_url = $ocdi_host . '/ocdi/';
			/* translators: %1$s - The demo name. %2$s - Minutes. */
			$notice  = esc_html__( 'This demo will import %1$s. It may take %2$s', 'geeks' );
			$notice .= '<br><br>' . esc_html__( 'Menus, Widgets and Settings will not be imported. Content imported already will not be imported.', 'geeks' );
			$notice .= '<br><br>' . esc_html__( 'Alternatively, you can import this template directly into your page via Edit with Elementor.', 'geeks' );
			$notice .= '<br><br>' . esc_html__( 'Only courses gets imported with homepages, for courses with lessons and quizes import One Click courses.xml.', 'geeks' );

			$import_files = array(
				array(
						'import_file_name'         => 'Home',
						'categories'               => array( 'Landing Page' ),
						'import_file_url'          => $dd_url . 'xml/home.xml',
						'import_preview_image_url' => $preview_url . 'full.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '8 courses including 1 page & 9 images', 'geeks' ) . '</strong>', esc_html__( 'upto a minute', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com',
						'plugin_profile'           => 'tutor',
						'uploads_dir'              => 'https://geeks.madrasthemes.com/demo/wp-content/uploads',
					),
					array(
						'import_file_name'         => 'Landing Course',
						'categories'               => array( 'Landing Page' ),
						'import_file_url'          => $dd_url . 'xml/landing-course.xml',
						'import_preview_image_url' => $preview_url . 'landing-course.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '12 courses including 1 page & 21 images', 'geeks' ) . '</strong>', esc_html__( 'upto a minute', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com/landing-courses/',
						'plugin_profile'           => 'tutor',
						'uploads_dir'              => 'https://geeks.madrasthemes.com/demo/wp-content/uploads',
					),
					array(
						'import_file_name'         => 'Course Lead',
						'categories'               => array( 'Landing Page' ),
						'import_file_url'          => $dd_url . 'xml/lead.xml',
						'import_preview_image_url' => $preview_url . 'lead-course.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '1 course including 1 page & 14 images', 'geeks' ) . '</strong>', esc_html__( 'upto a minute', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com/landings-lead-course/',
						'plugin_profile'           => 'tutor',
						'uploads_dir'              => 'https://geeks.madrasthemes.com/demo/wp-content/uploads',
					),
					array(
						'import_file_name'         => 'Request Access',
						'categories'               => array( 'Landing Page' ),
						'import_file_url'          => $dd_url . 'xml/request-access.xml',
						'import_preview_image_url' => $preview_url . 'request-access.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '1 page & 8 images', 'geeks' ) . '</strong>', esc_html__( 'upto a minute', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com/request-access/',
						'plugin_profile'           => 'tutor',
						'uploads_dir'              => 'https://geeks.madrasthemes.com/demo/wp-content/uploads',
					),
					array(
						'import_file_name'         => 'Saas',
						'categories'               => array( 'Landing Page' ),
						'import_file_url'          => $dd_url . 'xml/saas.xml',
						'import_preview_image_url' => $preview_url . 'saas.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '1 page & 15 images', 'geeks' ) . '</strong>', esc_html__( 'upto a minute', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com/landing-saas/',
						'plugin_profile'           => 'tutor',
						'uploads_dir'              => 'https://geeks.madrasthemes.com/demo/wp-content/uploads',
					),

					array(
						'import_file_name'         => 'Job Listing',
						'categories'               => array( 'Templates' ),
						'import_file_url'          => $dd_url . 'xml/jobs.xml',
						'import_widget_file_url'   => $dd_url . 'widgets/footer.wie',
						'import_preview_image_url' => $preview_url . 'jobs.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '11 job listings, 2 pages & 16 images', 'geeks' ) . '</strong>', esc_html__( '2-3 minutes', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com/career-listing/',
						'plugin_profile'           => 'jobs'
					),

					array(
						'import_file_name'         => 'Blog',
						'categories'               => array( 'Templates' ),
						'import_file_url'          => $dd_url . 'xml/blog.xml',
						'import_widget_file_url'   => $dd_url . 'widgets/blog.wie',
						'import_preview_image_url' => $preview_url . 'blog.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '11 blog posts, 1 page & 6 images', 'geeks' ) . '</strong>', esc_html__( '2-3 minutes', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com/blog/',
						'plugin_profile'           => 'tutor',
						'set_pages'                => true,

					),

					array(
						'import_file_name'         => 'Courses',
						'categories'               => array( 'Templates' ),
						'import_preview_image_url' => $preview_url . 'courses.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '10 images, 31 courses, 600 lessons & 19 paths', 'geeks' ) . '</strong>', esc_html__( '2-3 minutes', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com/courses/',
						'plugin_profile'           => 'tutor',
						'import_file_url'          => $dd_url . 'xml/courses.xml',

					),

					array(
						'import_file_name'         => 'Menus',
						'categories'               => array( 'Misc' ),
						'import_file_url'          => $dd_url . 'xml/menus.xml',
						'import_preview_image_url' => $preview_url . 'menus.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '80 items', 'geeks' ) . '</strong>', esc_html__( '2-3 minutes', 'geeks' ) ),

						'plugin_profile'           => 'tutor'
					),

					array(
						'import_file_name'         => 'Full Demo',
						'categories'               => array( 'Full Demo' ),
						'import_file_url'          => $dd_url . 'xml/full.xml',
						'import_preview_image_url' => $preview_url . 'full.jpg',
						'import_widget_file_url'   => $dd_url . 'widgets/full.wie',
						'import_notice'            => esc_html__( 'It imports the entire demo. It may take upto 5 minutes', 'geeks' ),
						'preview_url'              => 'https://geeks.madrasthemes.com/demo/',
						'plugin_profile'           => 'all',
						'set_nav_menus'            => true,
						'set_pages'                => true,
						'front_page_title'         => 'Home',
					),

					array(
						'import_file_name'         => 'About',
						'categories'               => array( 'Secondary' ),
						'import_file_url'          => $dd_url . 'xml/about.xml',
						'import_preview_image_url' => $preview_url . 'about.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '1 page & 17 images', 'geeks' ) . '</strong>', esc_html__( 'upto a minute', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com/about/',
						'plugin_profile'           => 'tutor',
						'uploads_dir'              => 'https://geeks.madrasthemes.com/demo/wp-content/uploads',
					),

					array(
						'import_file_name'         => 'Pricing',
						'categories'               => array( 'Secondary' ),
						'import_file_url'          => $dd_url . 'xml/pricing.xml',
						'import_preview_image_url' => $preview_url . 'pricing.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '1 page & 9 images', 'geeks' ) . '</strong>', esc_html__( 'upto a minute', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com/pricing/',
						'plugin_profile'           => 'tutor',
						'uploads_dir'              => 'https://geeks.madrasthemes.com/demo/wp-content/uploads',
					),
					array(
						'import_file_name'         => 'Contact',
						'categories'               => array( 'Secondary' ),
						'import_file_url'          => $dd_url . 'xml/contact.xml',
						'import_preview_image_url' => $preview_url . 'contact.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '1 page', 'geeks' ) . '</strong>', esc_html__( 'upto a minute', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com/contact/',
						'plugin_profile'           => 'tutor',
						'uploads_dir'              => 'https://geeks.madrasthemes.com/demo/wp-content/uploads',
					),
					array(
						'import_file_name'         => 'Compare Plan',
						'categories'               => array( 'Secondary' ),
						'import_file_url'          => $dd_url . 'xml/compare-plan.xml',
						'import_preview_image_url' => $preview_url . 'compare-plan.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '1 table including 1 page & 2 images', 'geeks' ) . '</strong>', esc_html__( 'upto a minute', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com/compare-plan/',
						'plugin_profile'           => 'tutor',
						'uploads_dir'              => 'https://geeks.madrasthemes.com/demo/wp-content/uploads',
					),
					array(
						'import_file_name'         => 'Coming Soon',
						'categories'               => array( 'Secondary' ),
						'import_file_url'          => $dd_url . 'xml/coming-soon.xml',
						'import_preview_image_url' => $preview_url . 'coming-soon.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '1 page & 1 image', 'geeks' ) . '</strong>', esc_html__( 'upto a minute', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com/coming-soon/',
						'plugin_profile'           => 'tutor',
						'uploads_dir'              => 'https://geeks.madrasthemes.com/demo/wp-content/uploads',
					),
					array(
						'import_file_name'         => 'Maintenance Mode',
						'categories'               => array( 'Secondary' ),
						'import_file_url'          => $dd_url . 'xml/maintenance-mode.xml',
						'import_preview_image_url' => $preview_url . 'maintenance-mode.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '1 page & 1 image', 'geeks' ) . '</strong>', esc_html__( 'upto a minute', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com/maintenance-mode/',
						'plugin_profile'           => 'tutor',
						'uploads_dir'              => 'https://geeks.madrasthemes.com/demo/wp-content/uploads',
					),
					array(
						'import_file_name'         => 'Terms & Conditions',
						'categories'               => array( 'Secondary' ),
						'import_file_url'          => $dd_url . 'xml/terms-conditions.xml',
						'import_preview_image_url' => $preview_url . 'terms-conditions.jpg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '1 page', 'geeks' ) . '</strong>', esc_html__( 'upto a minute', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com/terms-conditions/',
						'plugin_profile'           => 'tutor',
						'uploads_dir'              => 'https://geeks.madrasthemes.com/demo/wp-content/uploads',
					),
					array(
						'import_file_name'         => 'Home Academy',
						'categories'               => array( 'Landing Page' ),
						'import_file_url'          => $dd_url . 'xml/home-academy.xml',
						'import_preview_image_url' => $preview_url . 'home-academy.jpeg',
						'import_notice'            => sprintf( $notice, '<strong>' . esc_html__( '1 page & 17 image', 'geeks' ) . '</strong>', esc_html__( 'upto a minute', 'geeks' ) ),
						'preview_url'              => 'https://geeks.madrasthemes.com/home-academy/',
						'plugin_profile'           => 'tutor',
						'uploads_dir'              => 'https://geeks.madrasthemes.com/demo/wp-content/uploads',
					),
			);
			
			if ( class_exists( 'SFWD_LMS' ) ) {
				$import_files[] = array(
					'import_file_name'         => 'Learndash Full Demo',
					'categories'               => array( 'Learndash' ),
					'import_file_url'          => $dd_url_ln . 'xml/full.xml',
					'import_preview_image_url' => $preview_url . 'full.jpg',
					'import_widget_file_url'   => $dd_url . 'widgets/full.wie',
					'import_notice'            => esc_html__( 'It imports the entire demo. It may take upto 5 minutes', 'geeks' ),
					'preview_url'              => 'https://geeks.madrasthemes.com/learndash/',
					'plugin_profile'           => 'learndash',
					'set_nav_menus'            => true,
					'set_pages'                => true,
					'front_page_title'         => 'Home',
				);
			}

			return apply_filters( 'geeks_ocdi_files_args', $import_files );
		}
	}

endif;

return new Geeks_OCDI();
