<?php
/**
 * Geeks Tutor Class
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Geeks_Tutor' ) ) :

	/**
	 * The Geeks Tutor Integration class
	 */
	class Geeks_Tutor {

		/**
		 * @var Geeks_Tutor_Template_Course
		 */
		public $tpl_course = null;

		/**
		 * Setup class.
		 */
		public function __construct() {
			$this->includes();
			$this->init_hooks();

			$this->tpl_course = new Geeks_Tutor_Template_Course();
		}

		/**
		 * Include files used in Geeks Tutor integration
		 */
		public function includes() {
			include_once get_template_directory() . '/inc/tutor/class-geeks-tutor-course-filter.php';
			include_once get_template_directory() . '/inc/tutor/class-geeks-tutor-template-course.php';
		}

		/**
		 * Init hooks.
		 */
		public function init_hooks() {
			add_filter( 'load_tutor_css', '__return_false' );
			add_filter( 'geeks_disable_page_header', [ $this, 'page_header' ], 10 );
			add_filter( 'geeks_navbar_disabled', [ $this, 'page_navbar' ], 10 );
			add_filter( 'geeks_footer_disabled', [ $this, 'page_footer' ], 10 );
			//add_action( 'init', [ $this, 'override_course_filter' ], 10 );
			add_action( 'wp_enqueue_scripts', [ $this, 'scripts' ], 10 );
			add_filter( 'tutor_dashboard/bottom_nav_items', [ $this, 'dash_bottom_nav_items'], 10 );
			add_filter( 'body_class', [ $this, 'body_classes' ] );
			add_filter( 'tutor_user_social_icons', [ $this, 'geeks_tutor_user_social_icons' ], 10, 1 );
			add_filter( 'tutor_social_share_icons', [ $this, 'geeks_tutor_share_icons' ], 10, 1 );
			//add_filter( 'tutor_dashboard/nav_items', [ $this, 'geeks_default_nav_items' ], 99 );
			//add_filter( 'tutor_dashboard/instructor_nav_items', [ $this, 'geeks_instructor_nav_items' ], 10 );

		}

		/**
		 * Dashboard nav items at the bottom
		 */
		public function dash_bottom_nav_items( $nav_items ) {
			$account_nav_items = [
				'separator-2'     	=> array( 
					'title' => esc_html__( 'Account Settings', 'geeks' ), 
					'type' => 'separator'
				),
				'settings'          => array( 'title' => esc_html__( 'Edit Profile', 'geeks' ), 'icon' => 'fe fe-settings' ),
				'settings/reset-password' => array( 'title' => esc_html__( 'Security', 'geeks' ), 'icon' => 'fe fe-user' ),
				'settings/withdraw-settings'          => array( 
					'title' => esc_html__( 'Withdraw', 'geeks'), 
					'auth_cap' => tutor()->instructor_role,
					'icon' => 'fe fe-dollar-sign',
				),
				'logout'            => array( 'title' => esc_html__( 'Logout', 'geeks' ), 'icon' => 'fe fe-power' ),
			];
			return $account_nav_items;
		}

		/**
		 * Dashboard default nav items at the bottom
		 */
		public function geeks_default_nav_items( $nav_items ) {
			$account_nav_items = [
				'index'             => array('title' => esc_html__('Dashboard', 'geeks'), 'icon' => 'fe fe-home'),
				'my-profile'        => array('title' => esc_html__('My Profile', 'geeks'), 'icon' => 'fe fe-user'),
				'enrolled-courses'  => array('title' => esc_html__('Enrolled  Courses', 'geeks'), 'icon' => 'fe fe-book'),
				'wishlist'          => array('title' => esc_html__('Wishlist', 'geeks'), 'icon' => 'fe fe-bookmark'),
				'reviews'           => array('title' => esc_html__('Reviews', 'geeks'), 'icon' => 'fe fe-star'),
				'my-quiz-attempts'  => array('title' => esc_html__('My Quiz Attempts', 'geeks'), 'icon' => 'fe fe-box'),
				'purchase_history'  => array('title' => esc_html__('Order History', 'geeks'), 'icon' => 'fe fe-shopping-bag'),
				'question-answer'   => array('title' => esc_html__('Question & Answer', 'geeks'), 'icon' => 'fe fe-help-circle'),
				
				];   
    
			return $account_nav_items;
		}

		/**
		 * Dashboard instructor nav items at the bottom
		 */
		public function geeks_instructor_nav_items( $nav_items ) {
				$account_nav_items = [
					'separator-1'   => array(
					'title'    => esc_html__( 'Instructor', 'geeks' ),
					'auth_cap' => tutor()->instructor_role,
					'type'     => 'separator',
				),
				'create-course' => array(
					'title'    => esc_html__( 'Create Course', 'geeks' ),
					'show_ui'  => false,
					'auth_cap' => tutor()->instructor_role,
				),
				'my-courses'    => array(
					'title'    => esc_html__( 'My Courses', 'geeks' ),
					'auth_cap' => tutor()->instructor_role,
					'icon'     => 'fe fe-bell',
				),
				'announcements' => array(
					'title'    => esc_html__( 'Announcements', 'geeks' ),
					'auth_cap' => tutor()->instructor_role,
					'icon'     => 'fe fe-dollar-sign',
				),
				'withdraw'      => array(
					'title'    => esc_html__( 'Withdrawals', 'geeks' ),
					'auth_cap' => tutor()->instructor_role,
					'icon'     => 'fe fe-box',
				),
				'quiz-attempts' => array(
					'title'    => esc_html__( 'Quiz Attempts', 'geeks' ),
					'auth_cap' => tutor()->instructor_role,
					'icon'     => 'fe fe-help-circle',
				),
				'assignments' => array(
					'title'    => esc_html__( 'Assignments', 'geeks' ),
					'auth_cap' => tutor()->instructor_role,
					'icon'     => 'fe fe-file',
				),
				'zoom' => array(
					'title'    => esc_html__( 'Zoom', 'geeks' ),
					'auth_cap' => tutor()->instructor_role,
					'icon'     => 'fe fe-zoom-in',
				),
				'analytics' => array(
					'title'    => esc_html__( 'Analytics', 'geeks' ),
					'auth_cap' => tutor()->instructor_role,
					'icon'     => 'fe fe-bar-chart',
				)
			];
			return $account_nav_items;
		}

		/**
		 *
		 * Get the user social icons
		 *
		 */
		public function geeks_tutor_user_social_icons( $icons ) {
			$user_social_icons = [
				'_tutor_profile_website'  => array(
					'label'        => esc_html__('Website', 'geeks'),
					'placeholder'  => 'https://example.com/',
					'icon_classes' => 'fa fa-globe'
				),
				'_tutor_profile_github'  => array(
					'label'        => esc_html__('Github', 'geeks'),
					'placeholder'  => 'https://github.com/username',
					'icon_classes' => 'fab fa-github'
				),
				'_tutor_profile_facebook'  => array(
					'label'        => esc_html__('Facebook', 'geeks'),
					'placeholder'  => 'https://facebook.com/username',
					'icon_classes' => 'fab fa-facebook'
				),
				'_tutor_profile_twitter'  => array(
					'label'        => esc_html__('Twitter', 'geeks'),
					'placeholder'  => 'https://twitter.com/username',
					'icon_classes' => 'fab fa-twitter'
				),
				'_tutor_profile_linkedin'  => array(
					'label'        => esc_html__('Linkedin', 'geeks'),
					'placeholder'  => 'https://linkedin.com/username',
					'icon_classes' => 'fab fa-linkedin'
				),
			];
			return $user_social_icons;

		}

		/**
		 *
		 * Get the user share icons
		 *
		 */
		public function geeks_tutor_share_icons( $icons ) {
			$instructor_share_icons = array(
				'facebook' => array( 'share_class' => 's_facebook', 'icon_html' => '<i class="dropdown-item-icon fab fa-facebook"></i>', 'label' => esc_html__('Facebook', 'geeks' ) ),
				'twitter'  => array( 'share_class' => 's_twitter', 'icon_html' => '<i class="dropdown-item-icon fab fa-twitter"></i>', 'label' => esc_html__('Twitter', 'geeks' ) ),
				'linkedin' => array( 'share_class' => 's_linkedin', 'icon_html' => '<i class="dropdown-item-icon fab fa-linkedin"></i>', 'label' => esc_html__( 'Linked In', 'geeks' ) ),
				'tumblr'   => array( 'share_class' => 's_tumblr', 'icon_html' => '<i class="dropdown-item-icon fab fa-tumblr"></i>', 'label' => esc_html__( 'Tumblr', 'geeks' ) ),
			);

			return $instructor_share_icons;
		}


		/**
		 * Enqueue scripts related to Tutor
		 */
		public function scripts() {
			global $geeks_version;
			wp_enqueue_script( 'geeks-tutor', get_template_directory_uri() . '/assets/js/geeks-tutor.js', array( 'jquery', 'tutor-frontend' ), $geeks_version, true );

			if(tutor_utils()->is_tutor_frontend_dashboard()) {
				wp_dequeue_style('tutor-frontend-dashboard-css', tutor()->url . 'assets/css/tutor-frontend-dashboard.min.css', tutor()->version);
			}

			wp_dequeue_style( 'tutor-frontend' );

		}

		/**
		 * Override Tutor's core course filter
		 */
		public function override_course_filter() {
			remove_action( 'wp_ajax_tutor_course_filter_ajax', array( tutor_lms()->course_filter, 'load_listing' ) );
			remove_action( 'wp_ajax_nopriv_tutor_course_filter_ajax', array( tutor_lms()->course_filter, 'load_listing' ) );
			tutor_lms()->course_filter = new Geeks\Tutor\Course_Filter();
		}

		/**
		 * Conditionally disable page header
		 *
		 * @param bool $disabled Is page header disabled.
		 */
		public function page_header( $disabled ) {
			$student_register_page_id    = (int) tutor_utils()->get_option( 'student_register_page' );
			$instructor_register_page_id = (int) tutor_utils()->get_option( 'instructor_register_page' );

			if ( is_page( $student_register_page_id ) || is_page( $instructor_register_page_id ) ) {
				$disabled = true;
			}

			return $disabled;
		}

		/**
		 * Conditionally disable page navbar
		 *
		 * @param bool $disabled Is page navbar disabled.
		 */
		public function page_navbar( $disabled ) {
			global $wp_query;

			$student_register_page_id    = (int) tutor_utils()->get_option( 'student_register_page' );
			$instructor_register_page_id = (int) tutor_utils()->get_option( 'instructor_register_page' );


			if ( is_page( $student_register_page_id ) || is_page( $instructor_register_page_id ) ) {
				$disabled = true;
			}

			// Do not show navbar in retrieve password page.
			$dashboard_page = tutor_utils()->array_get( 'tutor_dashboard_page', $wp_query->query_vars );

			if ( 'retrieve-password' === $dashboard_page ) {
				$disabled = true;
			}

			return $disabled;
		}

		/**
		 * Conditionally disable page footer
		 *
		 * @param bool $disabled Is page footer disabled.
		 */
		public function page_footer( $disabled ) {
			global $post;
			$student_register_page_id    = (int) tutor_utils()->get_option( 'student_register_page' );
			$has_content_access          = tutils()->has_enrolled_content_access('lesson');
			$instructor_register_page_id = (int) tutor_utils()->get_option( 'instructor_register_page' );
			$post_id                     = isset( $post->ID ) ? $post->ID : false;
			$parents                     = get_post_ancestors( $post_id );
    		$course_id                   = ($parents) && ! empty( $parents )  ? $parents[count($parents)-1]: $post_id;
			$is_course_public            = get_post_meta( $course_id, '_tutor_is_public_course', true );
			$_is_preview                 = get_post_meta( $post_id, '_is_preview', true );

			if ( is_page( $student_register_page_id ) || is_page( $instructor_register_page_id ) ) {
				$disabled = true;
			}

			if ( ( ( is_user_logged_in() && $has_content_access ) || 'yes' === $is_course_public || $_is_preview ) && !is_archive() && ! is_single_course() ) {
				$disabled = true;
			}


			return $disabled;
		}

		/**
		 * Adds custom classes to the array of body classes.
		 *
		 * @param array $classes Classes for the body element.
		 * @return array
		 */
		public function body_classes( $classes ) {
			$dashboard_page_id           = (int) tutils()->get_option( 'tutor_dashboard_page_id' );
			$student_register_page_id    = (int) tutor_utils()->get_option( 'student_register_page' );
			$instructor_register_page_id = (int) tutor_utils()->get_option( 'instructor_register_page' );
			$courses_page_id             = (int) tutor_utils()->get_option( 'course_archive_page' );
			$enable_public_profile       = tutor_utils()->get_option( 'enable_public_profile' );
			

			$is_courses_archive = false;
			$queried_object     = get_queried_object();

			if ( $queried_object instanceof \WP_Post_Type ) { 
				$is_courses_archive = 'courses' === $queried_object->name;
			}	

			if ( is_page( $dashboard_page_id ) || is_page( $student_register_page_id ) || is_page( $instructor_register_page_id ) || $enable_public_profile || $is_courses_archive  ) {
				$classes = geeks_remove_bg_class( 'bg-white', $classes );
			}

			return $classes;
		}
	}

endif;

return new Geeks_Tutor();
