<?php
/**
 * Geeks - Tutor functions related to single course page.
 */

/**
 * Get Single Course data
 */
function geeks_tutor_get_single_course_data() {

	$course_tabs = geeks_tutor_get_single_course_tabs();
	$meta_items  = geeks_tutor_get_single_course_meta_items();
	$instructor  = geeks_tutor_get_single_course_instructor();
	$materials   = tutor_course_material_includes();

	return apply_filters(
		'geeks_tutor_single_course_data',
		[
			'course_tabs' => $course_tabs,
			'meta_items'  => $meta_items,
			'instructor'  => $instructor,
			'materials'   => $materials,
		]
	);
}

/**
 * Get Single Course tabs
 */
function geeks_tutor_get_single_course_tabs() {
	return apply_filters( 'geeks_tutor_course_tabs', array() );
}

/**
 * Get Single course meta items
 */
function geeks_tutor_get_single_course_meta_items() {
	return apply_filters(
		'geeks_tutor_single_course_meta_items',
		array(
			'duration' => 'geeks_tutor_loop_meta_course_duration',
			'enrolled' => 'geeks_tutor_meta_course_enrolled',
			'rating'   => 'geeks_tutor_meta_course_rating',
			'level'    => 'geeks_tutor_single_meta_course_level',
		)
	);
}

/**
 * Get Single Course instructor data
 */
function geeks_tutor_get_single_course_instructor() {

	global $authordata;

	$instructor        = tutor_utils()->get_tutor_user( $authordata->ID );
	$instructor_rating = tutor_utils()->get_instructor_ratings( $instructor->ID );

	return apply_filters(
		'geeks_tutor_single_course_instructor',
		[
			'byline' => $instructor->tutor_profile_job_title,
			'bio'    => $instructor->tutor_profile_bio,
			'url'    => tutor_utils()->profile_url( $instructor->ID ),
			'rating' => $instructor_rating->rating_avg,
			'stats'  => [
				'students' => [
					'label' => esc_html__( 'Students', 'geeks' ),
					'value' => tutor_utils()->get_total_students_by_instructor( $instructor->ID ),
				],
				'courses'  => [
					'label' => esc_html__( 'Courses', 'geeks' ),
					'value' => tutor_utils()->get_course_count_by_instructor( $instructor->ID ),
				],
				'reviews'  => [
					'label' => esc_html__( 'Reviews', 'geeks' ),
					'value' => $instructor_rating->rating_count,
				],
			],
		]
	);
}

/**
 * Get the lesson icon
 *
 * @param string $post_type The post type of the lesson
 * @return string
 */
function geeks_tutor_get_lesson_icon( $post_type ) {
	$play_time = geeks_tutor_get_lesson_play_time();
	$icon      = $play_time ? 'mdi mdi-play' : 'mdi mdi-file-document-outline';
	
	if ( 'tutor_quiz' === $post_type ) {
		$icon = 'mdi mdi-puzzle-outline';
	}

	if ( 'tutor_assignments' === $post_type ) {
		$icon = 'mdi mdi-clipboard-text-outline';
	}

	return $icon;
}

/**
 * Get lesson play time
 *
 * @return string|bool
 */
function geeks_tutor_get_lesson_play_time() {
	$video = tutor_utils()->get_video_info();

	$play_time = false;
	if ( $video ){
		$play_time = geeks_get_duration_humanized( $video->playtime );
	}

	return $play_time;
}
