<?php
/**
 * Tutor related functions
 */

include_once get_template_directory() . '/inc/tutor/functions/global.php';
include_once get_template_directory() . '/inc/tutor/functions/courses.php';
include_once get_template_directory() . '/inc/tutor/functions/single-course.php';
include_once get_template_directory() . '/inc/tutor/functions/instructor.php';
include_once get_template_directory() . '/inc/tutor/functions/tax.php';

/**
 * Get order by options available for courses
 *
 * @return array
 */
function geeks_tutor_get_courses_sort_options() {
	return apply_filters(
		'geeks_tutor_courses_orderby',
		[
			'newest_first'    => esc_html__( 'Newest', 'geeks' ),
			'oldest_first'    => esc_html__( 'Oldest', 'geeks' ),
			'course_title_az' => esc_html__( 'Title (A &rarr; Z)', 'geeks' ),
			'course_title_za' => esc_html__( 'Title (Z &rarr; A)', 'geeks' ),
		]
	);
}

/**
 * Get Instructor grid stats
 *
 * @param  int $user_id User ID of the instructor.
 * @return array
 */
function geeks_tutor_get_instructor_grid_stats( $user_id ) {

	$stats = apply_filters(
		'geeks_tutor_instructor_grid_stats',
		[
			'students' => [
				'label'      => esc_html__( 'Students', 'geeks' ),
				'value_html' => '<span class="text-dark">50,274</span>',
			],
			'rating'   => [
				'label'      => esc_html__( 'Instructor Rating', 'geeks' ),
				'value_html' => '<span class="text-warning">4.5 <i class="mdi mdi-star"></i></span>',
			],
			'courses'  => [
				'label'      => esc_html__( 'Courses', 'geeks' ),
				'value_html' => '<span class="text-dark"> 12 </span>',
			],
		]
	);

	return $stats;
}

/**
 * Get Dashboard action button
 *
 * @param  WP_User $user              user object of instructor.
 * @param  string  $instructor_status status of the instructor.
 * @return array
 */
function geeks_tutor_get_dashboard_action_button( $user, $instructor_status ) {
	$rejected_on = get_user_meta( $user->ID, '_is_tutor_instructor_rejected', true );
	$action_button = false;
	$btn_become_instructor= false;

	if ( tutils()->get_option( 'enable_become_instructor_btn' ) ) {
		$btn_become_instructor = [
			'url'   => tutils()->instructor_register_url(),
			'id'    => 'tutor-become-instructor',
			'label' => esc_html__( 'Become an instructor', 'geeks' ),
		];
	}

	if ( current_user_can( tutor()->instructor_role ) ) {
		$course_type   = tutor()->course_post_type;
		if ( function_exists( 'tutor_pro' ) ) {
			$action_button = [
				'url'   => '#',
				'id'    => 'tutor-create-new-course',
				'label' => esc_html__( 'Add A New Course', 'geeks' ),
			];
		} else {
			$action_button = [
				'url'   => admin_url( "post-new.php?post_type=$course_type" ),
				'id'    => 'tutor-create-new-course-1',
				'label' => esc_html__( 'Add A New Course', 'geeks' ),
			];
		}
	} elseif ( 'pending' === $instructor_status ) {
		$on            = get_user_meta( $user->ID, '_is_tutor_instructor', true );
		$on            = gmdate( 'd F, Y', $on );
		$action_button = [
			'url'   => '#',
			'id'    => 'tutor-pending-course',
			/* translators: %s: date on which application was made */
			'label' => sprintf( esc_html__( 'Your Application is pending from %s', 'geeks' ), $on ),
		];
	} elseif ( $rejected_on || 'blocked' !== $instructor_status  ) {
		$action_button = $btn_become_instructor;
	}

	return $action_button;
}

if ( ! function_exists( 'geeks_course_archive_filter_bar' ) ) {
	function geeks_course_archive_filter_bar() {
		ob_start();
		tutor_load_template( 'global.course-archive-filter-bar' );
		$output = apply_filters( 'geeks_course_archive_filter_bar', ob_get_clean() );

		echo $output;
	}
}