<?php
/**
 * Template functions related to Tutor
 */

if ( ! function_exists( 'geeks_tutor_meta_course_enrolled' ) ) {
	/**
	 * Display students enrolled in the course
	 */
	function geeks_tutor_meta_course_enrolled() {
		$students = (int) tutor_utils()->count_enrolled_users_by_course();
		geeks_display_course_enrolled( $students );
	}
}

if ( ! function_exists( 'geeks_tutor_loop_meta_course_duration' ) ) {
	/**
	 * Display course duration in meta items
	 */
	function geeks_tutor_loop_meta_course_duration() {
		geeks_display_course_duration( get_tutor_course_duration_context() );
	}
}

if ( ! function_exists( 'geeks_tutor_loop_meta_course_level' ) ) {
	/**
	 * Display course level in meta items
	 */
	function geeks_tutor_loop_meta_course_level() {

		$current = '#DBD8E9';
		$next    = '#754FFE';

		geeks_tutor_course_level( $current, $next );
	}
}

/**
 * General course level display
 *
 * @param string $current Hex value for current fill color.
 * @param string $next    Hex value for next level fill color.
 */
function geeks_tutor_course_level( $current, $next ) {
	$id    = get_the_ID();
	$level = get_post_meta( $id, '_tutor_course_level', true );
	$label = '';

	if ( ! empty( $level ) ) {
		$label = tutor_utils()->course_levels( $level );
	}

	geeks_display_course_level( $level, $label, $current, $next );
}

if ( ! function_exists( 'geeks_tutor_single_meta_course_level' ) ) {
	/**
	 * Display course level in single course
	 */
	function geeks_tutor_single_meta_course_level() {
		$current = '#DBD8E9';
		$next    = '#DBD8E9';
		geeks_tutor_course_level( $current, $next );
	}
}

if ( ! function_exists( 'geeks_tutor_meta_course_rating' ) ) {
	/**
	 * Display course rating in meta items
	 */
	function geeks_tutor_meta_course_rating() {
		$course_rating = tutor_utils()->get_course_rating();
		$text_class    = 'fs-6 text-muted';

		if ( is_single() ) {
			$text_class  = 'text-white';
			$course_id   = get_the_ID();
			$is_enrolled = tutor_utils()->is_enrolled( $course_id );
			
			if( is_user_logged_in() ) {
				if ( $is_enrolled ) {
					$text_class = '';
				}
			}
		}

		geeks_display_course_rating( $course_rating->rating_avg, $course_rating->rating_count, $text_class );
	}
}

if ( ! function_exists( 'geeks_tutor_default_course_tabs' ) ) {
	/**
	 * Add default course tabs to course pages.
	 *
	 * @param array $tabs Array of tabs.
	 * @return array
	 */
	function geeks_tutor_default_course_tabs( $tabs = array() ) {
		global $post;
		$course_id   = get_the_ID();
		$is_enrolled = tutor_utils()->is_enrolled( $course_id );
		$course_post_type = tutor()->course_post_type;



		// Curriculum Tab.
		$topics = tutor_utils()->get_topics();
		if ( $topics->have_posts() ) {
			$tabs['topics'] = array(
				'title'    => esc_html__( 'Curriculum', 'geeks' ),
				'priority' => 10,
				'callback' => 'geeks_tutor_course_curriculum_tab',
			);
		}

		// Description tab - shows course content.
		if ( $post->post_content ) {
			$tabs['description'] = array(
				'title'         => esc_html__( 'Description', 'geeks' ),
				'priority'      => 20,
				'callback'      => 'geeks_tutor_course_description_tab',
				'content_title' => esc_html__( 'Course description', 'geeks' ),
			);
		}

		// Question & Answer tab - show course question and answer.
		$disable_qa_for_this_course = get_post_meta($post->ID, '_tutor_enable_qa', true) =='yes';

		$enable_q_and_a_on_course     = tutor_utils()->get_option('enable_q_and_a_on_course');
		$course_nav_item              = apply_filters( 'tutor_course/single/nav_items', tutor_utils()->course_nav_items(), get_the_ID() ); 
		$disable_course_announcements = tutor_utils()->get_option('enable_course_announcements');
		$has_lesson_attachment = count( tutor_utils()->get_attachments() ) > 0;
		$has_tutor_pro = tutor()->has_pro;
		


		if( is_user_logged_in() ) {
			if ( $is_enrolled ){
				
				if( $enable_q_and_a_on_course && $disable_qa_for_this_course ) {

					$tabs['questions'] = array(
						'title'         => esc_html__( 'Q&A', 'geeks' ),
						'priority'      => 30,
						'callback'      => 'tutor_course_question_and_answer',
						'content_title' => esc_html__( 'Course Question & Answer', 'geeks' ),
					);
				 }

				if (  $disable_course_announcements ) {

					$tabs['announcements'] = array(
						'title'         => esc_html__( 'Announcements', 'geeks' ),
						'priority'      => 40,
						'callback'      => 'tutor_course_announcements',
						'content_title' => esc_html__( 'Course Announcements', 'geeks' ),
					);
				}

				if ( is_single() && $course_id && $has_lesson_attachment && $has_tutor_pro ) {

					$course_attachments = new TUTOR_CA\CourseAttachments();
					$tabs['resources'] = array(
						'title'         => esc_html__( 'Resources', 'geeks' ),
						'callback'      => 'get_tutor_posts_attachments',
						'priority'      => 60,
						'content_title' => esc_html__( 'Resources', 'geeks' ),
					);
				}
			}
		}

		// Reviews tab - show course reviews.
		$disable_reviews = get_tutor_option( 'enable_course_review' );

		if ( $disable_reviews ) {
			$reviews = tutor_utils()->get_course_reviews();

			if( is_user_logged_in() ) {
				if ( ( is_array( $reviews ) && count( $reviews ) ) || $is_enrolled ) {
					$tabs['reviews'] = array(
						'title'         => esc_html__( 'Reviews', 'geeks' ),
						'priority'      => 50,
						'callback'      => 'geeks_tutor_course_review_tab',
						'content_title' => esc_html__( 'How students rated this course', 'geeks' ),
					);
				}
			}
		}
		
		if( is_user_logged_in() ) {
			if ( $is_enrolled ):
				unset( $tabs['topics'] );
			endif;
		}

		return $tabs;
	}
}

if ( ! function_exists( 'geeks_tutor_sort_course_tabs' ) ) {

	/**
	 * Sort tabs by priority.
	 *
	 * @param array $tabs Array of tabs.
	 * @return array
	 */
	function geeks_tutor_sort_course_tabs( $tabs = array() ) {

		// Make sure the $tabs parameter is an array.
		if ( ! is_array( $tabs ) ) {
			// phpcs:ignore WordPress.PHP.DevelopmentFunctions.error_log_trigger_error
			trigger_error( 'Function geeks_sort_course_tabs() expects an array as the first parameter. Defaulting to empty array.' );
			$tabs = array();
		}

		// Re-order tabs by priority.
		if ( ! function_exists( '_sort_priority_callback' ) ) {
			/**
			 * Sort Priority Callback Function
			 *
			 * @param array $a Comparison A.
			 * @param array $b Comparison B.
			 * @return bool
			 */
			function _sort_priority_callback( $a, $b ) {
				if ( ! isset( $a['priority'], $b['priority'] ) || $a['priority'] === $b['priority'] ) {
					return 0;
				}
				return ( $a['priority'] < $b['priority'] ) ? -1 : 1;
			}
		}

		uasort( $tabs, '_sort_priority_callback' );

		return $tabs;
	}
}

if ( ! function_exists( 'geeks_tutor_course_curriculum_tab' ) ) {
	/**
	 * Displays Course curriculum tab content
	 *
	 * @param string $key Key of the tab.
	 * @param array  $tab Tab details.
	 */
	function geeks_tutor_course_curriculum_tab( $key, $tab ) {
		geeks_get_template( 'single-course/tabs/curriculum.php', $tab );
	}
}

if ( ! function_exists( 'geeks_tutor_course_description_tab' ) ) {
	/**
	 * Displays Course description tab content
	 *
	 * @param string $key Key of the tab.
	 * @param array  $tab Tab details.
	 */
	function geeks_tutor_course_description_tab( $key, $tab ) {
		geeks_get_template( 'single-course/tabs/description.php', $tab );
	}
}

if ( ! function_exists( 'geeks_tutor_course_review_tab' ) ) {
	/**
	 * Displays Course review tab content
	 *
	 * @param string $key Key of the tab.
	 * @param array  $tab Tab details.
	 */
	function geeks_tutor_course_review_tab( $key, $tab ) {
		geeks_get_template( 'single-course/tabs/review.php', $tab );
	}
}

if ( ! function_exists( 'geeks_tutor_course_loop_author' ) ) {
	/**
	 * Display author in course loop
	 */
	function geeks_tutor_course_loop_author() {
		global $authordata;
		$display_name = get_the_author();
		geeks_display_courses_loop_author( $authordata->ID, $display_name );
	}
}

if ( ! function_exists( 'geeks_tutor_course_loop_bookmark' ) ) {
	/**
	 * Displays bookmark in course loop
	 */
	function geeks_tutor_course_loop_bookmark() {
		$course_id     = get_the_ID();
		$is_wishlisted = tutor_utils()->is_wishlisted($course_id);
		$action_class  = '';
		$is_enrolled   = tutor_utils()->is_enrolled( $course_id );
		$is_wish_listed = tutor_utils()->is_wishlisted( $course_id );

        
        if ( is_user_logged_in() ){
            $action_class = apply_filters('tutor_wishlist_btn_class', 'tutor-course-wishlist-btn');
        } else {
            $action_class = apply_filters('tutor_popup_login_class', 'cart-required-login');
        }

        // if ( $is_wishlisted ){
	       //  $action_class .= ' has-wish-listed';
        // } elseif ($is_enrolled && is_single_course() ) {
        // 	$action_class .= ' text-inherit';
        // } else {
        // 	$action_class .= ' text-muted';
        // }
        
        if ( $is_enrolled && is_single_course() && is_user_logged_in() ) {
        	$wishlisted_icon_class = 'fs-3 ';
        	$icon_class = 'fs-3 ';

        } else {
        	$wishlisted_icon_class = 'fs-6 ';
        	$icon_class = '';

        }
	    
        if( !is_user_logged_in() ) {
			$wrap_class = ' tutor-course-entry-box-login';
		} else {
			$wrap_class = '';
		}
		$login_url   = tutor_utils()->get_option( 'enable_tutor_native_login', null, true, true ) ? '' : wp_login_url( tutor()->current_url );

		?><div class="col-auto">
			<span class="tutor-course-wishlist">
				
				<?php
				echo '<a href="javascript:;" class="'. esc_attr( $action_class ) .' save-bookmark-btn tutor-iconic-btn" data-course-id="'. esc_attr( $course_id  ).'">
            <i class="' . ( $is_wish_listed ? 'tutor-icon-bookmark-bold' : 'tutor-icon-bookmark-line') . '"></i>
        </a>';
		        ?>
			</span>
		</div><?php
	
	}
}


if ( ! function_exists( 'geeks_tutor_single_course_bookmark' ) ) {
	/**
	 * Displays bookmark in Single Course
	 */
	function geeks_tutor_single_course_bookmark() {
		$course_id     = get_the_ID();
		$is_wish_listed = tutor_utils()->is_wishlisted( $course_id );
        
        if ( $is_wish_listed ){
	        $text = esc_html__( 'Added to Bookmark', 'geeks' );
        } else {
        	$text = esc_html__( 'Add to Bookmark', 'geeks' );

        }
		
		?><div class="tutor-course-details-actions mt-2">
			<a href="javascript:;" class="tutor-btn tutor-course-wishlist-btn w-100 btn d-block btn-outline-primary btn-block" data-course-id="<?php echo esc_attr( $course_id ); ?>">
				<span class="muted"><?php echo esc_html( $text ); ?></span>
			</a>
		</div>


		<?php
	}
}
if ( ! function_exists( 'geeks_tutor_courses_orderby_select' ) ) {
	/**
	 * Displays select dropdown for courses orderby
	 */
	function geeks_tutor_courses_orderby_select( $atts ) {
		$sort_by = '';
		isset( $_GET['tutor_course_filter'] ) ? $sort_by  = $_GET['tutor_course_filter'] : 0;
		isset( $_POST['tutor_course_filter'] ) ? $sort_by = $_POST['tutor_course_filter'] : 0;
		$sort_options = geeks_tutor_get_courses_sort_options();
		?><select <?php echo geeks_get_render_attribute_string( $atts ); ?>>
			<option value=""><?php esc_html_e( 'Sort by', 'geeks' ); ?></option>
			<?php foreach ( $sort_options as $value => $option ) : ?>
			<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $sort_by ); ?>><?php echo esc_html( $option ); ?></option>
			<?php endforeach; ?>
		</select><?php
	}
}

if ( ! function_exists( 'geeks_tutor_popup_login_header' ) ) {
	/**
	 * Display the header for the popup login
	 */
	function geeks_tutor_popup_login_header() {
		$current_url   = tutils()->get_current_url();
    	$register_page = tutor_utils()->student_register_url();
		$register_url  = add_query_arg( 'redirect_to', $current_url, $register_page );

		?>
		<div class="mb-4">
              <?php geeks_profile_form_branding(); ?>
              <h1 class="mb-1 fw-bold"><?php esc_html_e( 'Sign in', 'geeks' ); ?></h1>
              <?php if ( get_option( 'users_can_register', false ) ) : ?>
              <span class="fs-5"><?php esc_html_e( 'Don\'t have an account?', 'geeks' ); ?>&nbsp;<a href="<?php echo esc_url( $register_url ); ?>" class="ms-1"><?php esc_html_e( 'Sign up', 'geeks' ); ?></a></span>
          	<?php endif; ?>
        </div>
        <?php
	}
}

if ( ! function_exists( 'geeks_tutor_dashboard_navigation' ) ) {
	/**
	 * Dashboard Navigation
	 */
	function geeks_tutor_dashboard_navigation( $dashboard_page_slug, $dashboard_page_name ) {
		?>

		<nav class="navbar navbar-expand-md navbar-light shadow-sm mb-4 mb-lg-0 sidenav">
			
			<a href="#" class="d-xl-none d-lg-none d-md-none text-inherit fw-bold"><?php esc_html_e( 'Menu', 'geeks' ); ?></a>

			<button class="navbar-toggler d-md-none icon-shape icon-sm rounded bg-primary text-light" type="button" data-bs-toggle="collapse" data-bs-target="#sidenav" aria-controls="sidenav" aria-expanded="false" aria-label="<?php esc_attr_e( 'Toggle navigation', 'geeks' ); ?>">
				<span class="fe fe-menu"></span>
			</button>
			
			<div class="collapse navbar-collapse" id="sidenav">
				<div class="navbar-nav flex-column">
					<span class="navbar-header"><?php esc_html_e( 'Dashboard', 'geeks' ); ?></span>
					<ul class="tutor-dashboard-permalinks list-unstyled ms-n2 mb-0">
					<?php
						$dashboard_pages = tutils()->tutor_dashboard_nav_ui_items();
						// get reviews settings value.
						$disable = !get_tutor_option('enable_course_review');
						foreach ( $dashboard_pages as $dashboard_key => $dashboard_page ) {

							if ($disable && 'reviews' === $dashboard_key) {
								continue;
							}
							$menu_title = $dashboard_page;
							$menu_link  = tutils()->get_tutor_dashboard_page_permalink( $dashboard_key );
							$separator  = false;
							$icon       = isset( $dashboard_page['icon'] ) ? $dashboard_page['icon'] : geeks_tutor_get_nav_item_icon( $dashboard_key );
							
							if ( is_array( $dashboard_page ) ) {
								$menu_title = tutils()->array_get( 'title', $dashboard_page );
								
								// Add new menu item property "url" for custom link
								if ( isset( $dashboard_page['url'] ) ) {
									$menu_link = $dashboard_page['url'];
								}
								if ( isset( $dashboard_page['type'] ) && $dashboard_page['type'] == 'separator' ) {
									$separator = true;
								}
							}
							if ( $separator ) {
								if ( $menu_title ) {
									?><li class="mt-4 tutor-dashboard-menu-divider-header">
										<span class="navbar-header"><?php echo esc_html( $menu_title ); ?></span>
									</li><?php
								}
							} else {
								$li_class = "tutor-dashboard-menu-{$dashboard_key} nav-item";
								
								if ( 'index' === $dashboard_key ) {
									$dashboard_key = '';
								}

								if ( $dashboard_key === $dashboard_page_name ) {
									$li_class .= ' active';
								}

								?><li class="<?php echo esc_attr( $li_class ); ?>">
									<a href="<?php echo esc_url( $menu_link ); ?>" class="nav-link">
										<?php if ( ! empty( $icon ) ) : ?>
											<i class="<?php echo esc_attr( $icon ); ?> nav-icon"></i>
										<?php endif; ?>
										<?php echo esc_html( $menu_title ); ?>
									</a>
								</li><?php
							}
						}
					?>
					<!-- </ul> -->
				</div>
			</div>
		</nav>
		<?php
	}
}

if ( ! function_exists( 'geeks_tutor_get_nav_item_icon' ) ) {
	/**
	 * Get Icon from nav items
	 *
	 * @param  string $key Dashboard page slug
	 * @return string
	 */
	function geeks_tutor_get_nav_item_icon( $key ) {
		$icon = '';
		switch ( $key ) {
			case 'index':
				$icon = 'fe fe-home';
			break;
			case 'my-profile':
				$icon = 'fe fe-user';
			break;
			case 'enrolled-courses':
			case 'my-courses':
				$icon = 'fe fe-book';
			break;
			case 'wishlist':
				$icon = 'fe fe-bookmark';
			break;
			case 'reviews':
				$icon = 'fe fe-star';
			break;
			case 'my-quiz-attempts':
			case 'quiz-attempts':
				$icon = 'fe fe-box';
			break;
			case 'purchase_history':
				$icon = 'fe fe-shopping-bag';
			break;
			case 'create-course':
				$icon = 'fe fe-plus';
			case 'announcements':
				$icon = 'fe fe-bell';
			break;
			case 'earning':
				$icon = 'fe fe-pie-chart';
			break;
			case 'withdraw':
				$icon = 'fe fe-dollar-sign';
			break;
			case 'question-answer':
				$icon = 'fe fe-help-circle';
			break;
			case 'calendar':
				$icon = 'fe fe-calendar';
			break;
			case 'assignments':
				$icon = 'fe fe-file';
			break;
			case 'zoom':
				$icon = 'fe fe-zoom-in';
			break;
			case 'analytics':
				$icon = 'fe fe-bar-chart';
			break;
		}
		return $icon;
	}
}

if ( ! function_exists( 'geeks_tutor_page_title' ) ) {
	/**
	 * Get Page title of courses and courses tax
	 *
	 * @param  bool   $echo Should return or print the page title?
	 * @return string
	 */
	function geeks_tutor_page_title( $echo = true ) {
		$search_query = get_search_query();
		if ( is_search() && ! empty( $search_query ) ) {
			/* translators: %s: search query */
			$page_title = sprintf( esc_html__( 'Search Results for: &ldquo;%s&rdquo;', 'geeks' ), $search_query );

			if ( get_query_var( 'paged' ) ) {
				/* translators: %s: page number */
				$page_title .= sprintf( esc_html__( '&nbsp;&ndash; Page %s', 'geeks' ), get_query_var( 'paged' ) );
			}
		} else if ( is_tax() ) {
			/* translators: %s: course category title */
			$page_title = sprintf( esc_html__( '%s Courses', 'geeks' ), single_term_title( '', false ) );
		} else {
			$courses_page_id = (int) tutor_utils()->get_option( 'course_archive_page' );

			if( $courses_page_id === -1 ) {
				$page_title      = esc_html__( 'Courses', 'geeks');
			} else {
				$page_title      = get_the_title( $courses_page_id );
				
			}
		}

		$page_title = apply_filters( 'geeks_tutor_page_title', $page_title );
		
		if ( $echo ) {
			echo esc_html( $page_title );
		} else {
			return $page_title;
		}
	}
}

if ( ! function_exists( 'geeks_tutor_taxonomy_archive_course_description' ) ) {
	/**
	 * Displays description of course taxonomy
	 */
	function geeks_tutor_taxonomy_archive_course_description() {
		if ( geeks_tutor_is_course_tax() && 0 === absint( get_query_var( 'paged' ) ) ) {
			$term = get_queried_object();

			if ( $term && ! empty( $term->description ) ) {
				?><div class="mb-0 text-white lead"><?php echo wp_kses_post( $term->description ); ?></div><?php
			}
		}
	}
}

if ( ! function_exists( 'geeks_after_tutor_tax_header' ) ) {
	/**
	 * Executes geeks_after_tutor_tax_header hook on tutor tax pages.
	 */
	function geeks_after_tutor_tax_header() {
		if ( geeks_tutor_is_course_tax() ) {
			do_action( 'geeks_after_tutor_tax_header' );
		}
	}
}

if ( ! function_exists( 'geeks_tutor_display_instructor_list_view' ) ) {
	/**
	 * Displays instructor list view.
	 *
	 * @param int $user_id User ID of the instructor.
	 */
	function geeks_tutor_display_instructor_list_view( $user_id ) {
		$instructor_rating = tutor_utils()->get_instructor_ratings( $user_id );
		$data = [
			'user_id' 	  => $user_id,
			'profile_url' => tutor_utils()->profile_url( $user_id ),
			'rating'      => geeks_format_rating_avg( $instructor_rating->rating_avg ),
			'list_stats'  => geeks_tutor_get_list_view_instructor_stats( $user_id ),
			'byline'      => geeks_tutor_get_instructor_byline( $user_id ),
			'bio'         => geeks_tutor_get_instructor_bio( $user_id ),
		];
		geeks_get_template( 'instructor/list.php', $data );
	}
}

if ( ! function_exists( 'geeks_tutor_tax_display_tabs' ) ) {
	/**
	 * Displays tabs before courses
	 */
	function geeks_tutor_tax_display_tabs() {

	}
}

if ( ! function_exists( 'geeks_tutor_tax_display_instructors' ) ) {
	/**
	 * Displays instructors grid before courses
	 */
	function geeks_tutor_tax_display_instructors() {
		
	}
}

if ( ! function_exists( 'geeks_tutor_tax_display_courses' ) ) {
	/**
	 * Displays courses grid before courses
	 */
	function geeks_tutor_tax_display_courses() {
		
	}
}

if ( ! function_exists( 'geeks_tutor_tax_display_courses_header' ) ) {
	/**
	 * Displays courses header for before courses in tax pages.
	 */
	function geeks_tutor_tax_display_courses_header() {
		if ( geeks_tutor_is_course_tax() && Geeks_Tutor_ACF_Tax::is_courses_header_enabled() ) {
			$header = Geeks_Tutor_ACF_Tax::get_courses_header();

			if ( ! empty( $header['title'] ) ) :

			?>
			<div class="col-lg-12 col-md-12 col-12">
				<div class="mb-5">
					<h2 class="mb-1"><?php echo esc_html( $header['title'] ); ?></h2>
					<?php if ( ! empty( $header['description'] ) ) : ?>
					<p class="mb-0"><?php echo esc_html( $header['description'] ); ?></p>
					<?php endif; ?>
				</div>
			</div>
			<?php

			endif;
		}
	}
}

if ( ! function_exists( 'geeks_tutor_tax_display_jumbotron' ) ) {
	/**
	 * Display Jumbotron in Course category page.
	 */
	function geeks_tutor_tax_display_jumbotron() {
		$content_id = Geeks_Tutor_ACF_Tax::get_content_before_courses();
		if ( geeks_tutor_is_course_tax() && $content_id ) {
			geeks_render_content( $content_id, true );
		}
	}
}

if ( ! function_exists( 'geeks_tutor_dashboard_wc_endpoint' ) ) {
	/**
	 * Integrate WC endpoints in tutor dashboard.
	 */
	function geeks_tutor_dashboard_wc_endpoint( $nav_items ) {
		if ( geeks_is_woocommerce_activated() ) {
			$user_account_link              = get_permalink( get_option( 'woocommerce_myaccount_page_id' ) );

			$nav_items['new-separator']     = array('title' => esc_html__('Store', 'geeks'), 'type' => 'separator');
			$nav_items['dashboard']         = array('title' => esc_html__('Dashboard', 'geeks'), 'icon' => 'fe fe-home', 'url' => $user_account_link );
			$nav_items['orders']            = array('title' => esc_html__('Orders', 'geeks'), 'icon' => 'fe fe-shopping-bag', 'url' => $user_account_link . 'orders' );
			$nav_items['downloads']         = array('title' => esc_html__('Downloads', 'geeks'), 'icon' => 'fe fe-download',  'url' => $user_account_link . 'downloads' );
			$nav_items['edit-address']      = array('title' => esc_html__('Edit Address', 'geeks'), 'icon' => 'fe fe-map-pin',  'url' => $user_account_link . 'edit-address');
			$nav_items['edit-account']      = array('title' => esc_html__('Edit Account', 'geeks'),  'icon' => 'fe fe-user',  'url' => $user_account_link . 'edit-account ');
			$nav_items['payment-methods']   = array('title' => esc_html__('Payment Methods', 'geeks'), 'icon' => 'fe fe-credit-card',  'url' => $user_account_link . 'payment-methods' );

		}

		return $nav_items;

	}
}


