<?php
/**
 * Template functions used in Cart
 */

if ( ! function_exists( 'geeks_empty_cart_message' ) ) {
	/**
	 * Empty Cart Message
	 */
	function geeks_empty_cart_message() {
		echo '<p class="cart-empty display-5 mb-6">' . wp_kses_post( apply_filters( 'wc_empty_cart_message', esc_html__( 'Your cart is currently empty.', 'geeks' ) ) ) . '</p>';

	}
}


if ( ! function_exists( 'geeks_output_cross_sell_products' ) ) {
	/**
	 * Cross sell products display count
	 */
	function geeks_output_cross_sell_products() {
		if ( apply_filters( 'geeks_enable_cross_sell_products', true ) ) {
			woocommerce_cross_sell_display( 4, 4 );
		}
	}
}

if ( ! function_exists( 'geeks_wc_cart_totals_coupon_html' ) ) {
	/**
	 * Override coupons HTML
	 *
	 * @param string           $coupon_html Coupon HTML.
	 * @param string|WC_Coupon $coupon Coupon data or code.
	 * @param string           $discount_amount_html Discount price HTML.
	 */
	function geeks_wc_cart_totals_coupon_html( $coupon_html, $coupon, $discount_amount_html ) {

		$coupon_html = $discount_amount_html . ' <a href="' . esc_url( add_query_arg( 'remove_coupon', rawurlencode( $coupon->get_code() ), defined( 'WOOCOMMERCE_CHECKOUT' ) ? wc_get_checkout_url() : wc_get_cart_url() ) ) . '" class="woocommerce-remove-coupon" data-coupon="' . esc_attr( $coupon->get_code() ) . '"><i class="fe fe-x-circle small"></i></a>';

		echo wp_kses( $coupon_html, array_replace_recursive( wp_kses_allowed_html( 'post' ), array( 'a' => array( 'data-coupon' => true ) ) ) );
	}
}

if ( ! function_exists( 'geeks_cart_link_fragment' ) ) {
    /**
     * Cart Fragments
     * Ensure cart contents update when products are added to the cart via AJAX
     *
     * @param  array $fragments Fragments to refresh via AJAX.
     * @return array            Fragments to refresh via AJAX
     */
    function geeks_cart_link_fragment( $fragments ) {
        global $woocommerce;

        ob_start();
        geeks_cart_link_count();
        $fragments['span.cart-contents-count'] = ob_get_clean();

        ob_start();
        geeks_wc_mini_cart_content();
        $fragments['div.geeks-minicart'] = ob_get_clean();


        return $fragments;
    }
}