<?php
/**
 * WP Forms Integration
 */

add_filter( 'wpforms_field_properties', 'geeks_wpforms_field_atts', 10, 3 );

add_filter( 'wpforms_frontend_form_atts', 'geeks_wpforms_frontend_form_atts', 10, 2 );

add_action( 'wpforms_form_settings_general', 'geeks_wpforms_settings_general', 10, 1 );

if ( ! function_exists( 'geeks_wpforms_field_atts' ) ) {
	/**
	 * Adding Wpforms field attributes
	 *
	 * @param array $properties Field properties.
	 * @param array $field Form Fields.
	 * @param array $form_data Form data.
	 * @return array $properties Form properties.
	 */
	function geeks_wpforms_field_atts( $properties, $field, $form_data ) {

		if ( isset( $properties['inputs'] ) && isset( $properties['inputs']['primary'] ) && isset( $properties['inputs']['primary']['class'] ) ) {
			$properties['inputs']['primary']['class'][] = 'form-control';
		}

		if ( isset( $properties['label'] ) && isset( $properties['label']['class'] ) ) {
			$properties['label']['class'][] = 'form-label';
		}

		return $properties;
	}
}

if ( ! function_exists( 'geeks_wpforms_frontend_form_atts' ) ) {
	/**
	 * Begin to build the output
	 *
	 * @param array $form_atts Form atts.
	 * @param array $form_data Form data.
	 */
	function geeks_wpforms_frontend_form_atts( $form_atts, $form_data ) {

		if ( isset( $form_data['settings']['form_tag_class'] ) && ! empty( $form_data['settings']['form_tag_class'] ) ) {

			$form_classes       = explode( ' ', $form_data['settings']['form_tag_class'] );
			$form_atts['class'] = array_merge( $form_atts['class'], $form_classes );
		}

		return $form_atts;
	}
}

if ( ! function_exists( 'geeks_wpforms_settings_general' ) ) {
	/**
	 * Adding Wpform field
	 *
	 * @param object $settings Adding Form settings.
	 */
	function geeks_wpforms_settings_general( $settings ) {

		wpforms_panel_field(
			'text',
			'settings',
			'form_tag_class',
			$settings->form_data,
			esc_html__( 'Form Tag Class', 'geeks' ),
			[
				'tooltip' => esc_html__( 'Enter CSS class names for the form tag. Multiple class names should be separated with spaces.', 'geeks' ),
			]
		);
	}
}












