<?php
/**
 * Template for displaying order detail.
 *
 * This template can be overridden by copying it to yourtheme/learnpress/checkout/order-received.php.
 *
 * @author   ThimPress
 * @package  Learnpress/Templates
 * @version  4.0.0
 */

defined( 'ABSPATH' ) || exit();
?>
<div class="pt-4 pb-10">
	<div class="row justify-content-center">
		<div class="col-lg-8 col-md-12 col-12">
			<!-- text center -->
			<div class="text-center pb-6">
				<?php
				/**
				 * @var LP_Order $order_received
				 */
				if ( ! isset( $order_received ) ) {
					echo wp_sprintf(
						'<h1 class="display-3 fw-bold"><i class="fe fe-alert-circle d-block mb-3 text-danger"></i>%s</h1><p class="lead px-8">%s</p>',
						esc_html(
							apply_filters(
								'learn-press/order/received-invalid-order-heading',
								__( 'Invalid order.', 'geeks' )
							)
						),
						esc_html(
							apply_filters(
								'learn-press/order/received-invalid-order-message',
								__( 'We are sorry. We could not validate your order.', 'geeks' )
							)
						)
					);

					return;
				}

				echo wp_sprintf(
					'<h1 class="display-3 fw-bold"><i class="fe fe-check-circle d-block mb-3 text-success"></i>%s</h1><p class="lead px-8">%s</p>',
					esc_html(
						apply_filters(
							'learn-press/order/received-order-message',
							__( 'Order Received', 'geeks' )
						)
					),
					esc_html(
						apply_filters(
							'learn-press/order/received-order-message',
							__( 'Thank you. Your order has been received.', 'geeks' )
						)
					)
				);

				?>
			</div>
		</div>
	</div>

	<div class="row justify-content-center">
		<div class="col-lg-6 col-md-12 col-12">
			<table class="order_details table card table-borderless mb-4">
				<tr class="order">
					<th><?php esc_html_e( 'Order Number', 'geeks' ); ?></th>
					<td>
						<?php echo esc_html( $order_received->get_order_number() ); ?>
					</td>
				</tr>
				<tr class="item">
					<th><?php esc_html_e( 'Item', 'geeks' ); ?></th>
					<td>
						<?php
						$links = array();
						$items = $order_received->get_items();
						$count = count( $items );

						foreach ( $items as $item ) {
							if ( empty( $item['course_id'] ) || get_post_type( $item['course_id'] ) !== LP_COURSE_CPT ) {
								$links[] = apply_filters(
									'learn-press/order-item-not-course-id',
									__( 'Course does not exist', 'geeks' ),
									$item
								);
							} else {
								$link = '<a href="' . get_the_permalink( $item['course_id'] ) . '">' . get_the_title( $item['course_id'] ) . ' (#' . $item['course_id'] . ')' . '</a>';
								if ( $count > 1 ) {
									$link = sprintf( '<li>%s</li>', $link );
								}
								$links[] = apply_filters( 'learn-press/order-received-item-link', $link, $item );
							}
						}

						if ( $count > 1 ) {
							echo sprintf( '<ol>%s</ol>', join( '', $links ) );
						} elseif ( 1 == $count ) {
							echo wp_kses_post( implode( '', $links ) );
						} else {
							echo esc_html__( '(No item)', 'geeks' );
						}
						?>
					</td>
				</tr>
				<tr class="date">
					<th><?php esc_html_e( 'Date', 'geeks' ); ?></th>
					<td>
						<?php
						echo wp_kses_post(
							date_i18n(
								get_option( 'date_format' ),
								strtotime( $order_received->get_order_date() )
							)
						);
						?>
					</td>
				</tr>
				<tr class="total">
					<th><?php esc_html_e( 'Total', 'geeks' ); ?></th>
					<td>
						<?php echo wp_kses_post( $order_received->get_formatted_order_total() ); ?>
					</td>
				</tr>
				<?php
				$method_title = $order_received->get_payment_method_title();
				if ( $method_title ) :
					?>
					<tr class="method">
						<th><?php esc_html_e( 'Payment Method', 'geeks' ); ?></th>
						<td>
							<?php echo esc_html( $method_title ); ?>
						</td>
					</tr>
				<?php endif; ?>
			</table>

			<?php do_action( 'learn-press/order/received/' . $order_received->payment_method, $order_received->get_id() ); ?>
			<?php do_action( 'learn-press/order/received', $order_received ); ?>
		</div>
	</div>
</div>