<?php
/**
 * Template for displaying courses tab in user profile page.
 *
 * This template can be overridden by copying it to yourtheme/learnpress/tabs/courses.php.
 *
 * @author  ThimPress
 * @package  Learnpress/Templates
 * @version  4.0.9
 */

defined( 'ABSPATH' ) || exit();

if ( ! LP_Profile::instance()->current_user_can( 'view-tab-courses' ) ) {
	return;
}

$user = LP_Profile::instance()->get_user();

$data_course_progress = apply_filters(
	'learnpress/template/profile/tabs/courses/course_progress',
	array(
		'userID' => $user->get_id(),
		'status' => 'in-progress',
	)
);

$enrolleds = array(
	''            => esc_html__( 'All', 'geeks' ),
	'in-progress' => esc_html__( 'In-Progress', 'geeks' ),
	'finished'    => esc_html__( 'Finished', 'geeks' ),
	'passed'      => esc_html__( 'Passed', 'geeks' ),
	'failed'      => esc_html__( 'Failed', 'geeks' ),
);

$createds = array(
	''        => esc_html__( 'All', 'geeks' ),
	'publish' => esc_html__( 'Publish', 'geeks' ),
	'pending' => esc_html__( 'Pending', 'geeks' ),
);

$enrolled_active = ! learn_press_user_maybe_is_a_teacher() ? 'in-progress' : '';
$tab_active      = ! learn_press_user_maybe_is_a_teacher() ? 'enrolled' : 'created';
?>

<div class="learn-press-subtab-content">
	<div class="learn-press-profile-course__statistic"
		 data-ajax="<?php echo htmlentities( wp_json_encode( array( 'userID' => $user->get_id() ) ) ); ?>">
		<?php lp_skeleton_animation_html( 4, 'random', 'height: 30px;border-radius:4px;' ); ?>
	</div>

	<div class="learn-press-profile-course__tab card mb-4">
		<div class="card-header py-0 h4">
			<ul class="learn-press-profile-course__tab__inner nav nav-lb-tab border-bottom-0">
				<li class="nav-item ms-0"><a class="nav-link <?php echo 'enrolled' === $tab_active ? 'active' : ''; ?>" data-tab="enrolled"><?php esc_html_e( 'Enrolled', 'geeks' ); ?></a></li>

				<?php if ( learn_press_user_maybe_is_a_teacher() ) : ?>
					<li class="nav-item"><a class="nav-link <?php echo 'created' === $tab_active ? 'active' : ''; ?>" data-tab="created"><?php esc_html_e( 'Created', 'geeks' ); ?></a></li>
				<?php endif; ?>
			</ul>
		</div>

		<div class="card-body">
			<div class="learn-press-course-tab-enrolled learn-press-course-tab-filters" data-tab="enrolled" style="<?php echo 'enrolled' !== $tab_active ? 'display: none;' : ''; ?>">
				<ul class="learn-press-filters nav nav-pills mb-5">
					<?php foreach ( $enrolleds as $key => $enrolled ) : ?>
						<li class="nav-item">
							<?php
							$nav_link_class = 'nav-link';
							if ( $key === $enrolled_active ) {
								$nav_link_class .= ' active';
							}
							?>
							<a class="<?php echo esc_attr( $nav_link_class ); ?>" data-tab="<?php echo esc_attr( '' === $key ? 'all' : $key ); ?>">
								<?php echo esc_html( $enrolled ); ?>
							</a>
						</li>
					<?php endforeach; ?>
				</ul>

				<div class="learn-press-profile-course__progress">
					<?php foreach ( $enrolleds as $key => $enrolled ) : ?>
						<div class="learn-press-course-tab__filter__content" data-tab="<?php echo esc_attr( '' === $key ? 'all' : $key ); ?>" data-ajax="<?php echo htmlentities( wp_json_encode( [ 'userID' => $user->get_id(), 'status' => $key, 'query' => 'purchased', 'layout' => 'list' ] ) ); ?>" style="<?php echo esc_attr( $key !== $enrolled_active ? 'display: none' : '' ); ?>"> <?php // phpcs:ignore ?>
							<?php lp_skeleton_animation_html( 4, 'random', 'height: 30px;border-radius:4px;' ); ?>
						</div>
					<?php endforeach; ?>
				</div>
			</div>

			<?php if ( learn_press_user_maybe_is_a_teacher() ) : ?>
				<div class="learn-press-course-tab-created learn-press-course-tab-filters" data-tab="created" style="<?php echo 'created' !== $tab_active ? 'display: none;' : ''; ?>">
					<ul class="learn-press-filters nav nav-pills mb-5">
						<?php foreach ( $createds as $key => $created ) : ?>
							<li class="nav-item">
								<a class="nav-link <?php echo '' === $key ? 'active' : ''; ?>" data-tab="<?php echo esc_attr( $key === '' ? 'all' : $key ); ?>">
									<?php echo esc_html( $created ); ?>
								</a>
							</li>
						<?php endforeach; ?>
					</ul>

					<?php foreach ( $createds as $key => $created ) : ?>
						<div class="learn-press-course-tab__filter__content" data-tab="<?php echo esc_attr( $key === '' ? 'all' : $key ); ?>" data-ajax="<?php echo htmlentities( wp_json_encode( [ 'userID' => $user->get_id(), 'status' => $key, 'query' => 'own' ] ) ); ?>" style="<?php echo '' !== $key ? 'display: none' : ''; ?>"> <?php // phpcs:ignore ?>
							<?php lp_skeleton_animation_html( 4, 'random', 'height: 30px;border-radius:4px;' ); ?>
						</div>
					<?php endforeach; ?>
				</div>
			<?php endif; ?>
		</div><!-- /.card-body -->
	</div>
</div>
