<?php
/**
 * Template for displaying list orders in orders tab of user profile page.
 *
 * This template can be overridden by copying it to yourtheme/learnpress/orders/list.php.
 *
 * @author   ThimPress
 * @package  Learnpress/Templates
 * @version  4.0.0
 */

defined( 'ABSPATH' ) || exit();

$profile = LP_Profile::instance();

$query_orders = $profile->query_orders( array( 'fields' => 'ids' ) );

?>
<div class="card mb-4">
	<div class="card-header border-bottom-0">
		<h3 class="profile-heading mb-0"><?php esc_html_e( 'My Orders', 'geeks' ); ?></h3>
		<p class="mb-0"><?php esc_html_e( 'You can find all of your orders here.', 'geeks' ); ?></p>
	</div>
	
	<?php if ( ! $query_orders['items'] ) : ?>
	<div class="card-body"><div class="alert aler-warning"><?php esc_html_e( 'No orders!', 'geeks' ); ?></div></div>
	<?php else: ?>
	
	<div class="table-responsive border-0">
		<table class="lp-list-table profile-list-orders profile-list-table table-invoice table mb-0 text-nowrap">
			<thead>
				<tr class="order-row">
					<th class="border-bottom-0 column-order-number"><?php esc_html_e( 'Order', 'geeks' ); ?></th>
					<th class="border-bottom-0 column-order-total"><?php esc_html_e( 'Total', 'geeks' ); ?></th>
					<th class="border-bottom-0 column-order-status"><?php esc_html_e( 'Status', 'geeks' ); ?></th>
					<th class="border-bottom-0 column-order-date"><?php esc_html_e( 'Date', 'geeks' ); ?></th>
					<th class="border-bottom-0 column-order-actions"><?php esc_html_e( 'Actions', 'geeks' ); ?></th>
				</tr>
			</thead>

			<tbody>
				<?php
				foreach ( $query_orders['items'] as $order_id ) {
					$order = learn_press_get_order( $order_id );
					?>

					<tr class="order-row">
						<td class="column-order-number">
							<a href="<?php echo esc_html( $order->get_view_order_url() ); ?>">
								<?php echo esc_html( $order->get_order_number() ); ?>
							</a>
						</td>
						<td class="column-order-total"><?php echo esc_html( $order->get_formatted_order_total() ); ?></td>
						<td class="column-order-status">
							<span class="lp-label badge bg-<?php echo esc_attr( geeks_get_order_context( $order->get_status() ) ); ?>">
								<?php echo wp_kses_post( $order->get_order_status_html() ); ?>
							</span>
						</td>
						<td class="column-order-date"><?php echo esc_html( $order->get_order_date() ); ?></td>
						<td class="column-order-actions">
							<?php
							$actions = $order->get_profile_order_actions();

							if ( $actions ) {
								foreach ( $actions as $action ) {
									printf( '<a href="%s">%s</a>', esc_url( $action['url'] ), $action['text'] );
								}
							}
							?>
						</td>
					</tr>
				<?php } ?>
			</tbody>

			<tfoot>
				<tr class="list-table-nav">
					<td colspan="2" class="border-top-0 nav-text"><?php echo wp_kses_post( $query_orders->get_offset_text() ); ?></td>
					<td colspan="2" class="border-top-0 nav-pages"><?php $query_orders->get_nav_numbers( true ); ?></td>
				</tr>
			</tfoot>
		</table>
	</div>
	<?php endif; ?>
</div>