<?php
/**
 * Template for displaying change password form in profile page.
 *
 * This template can be overridden by copying it to yourtheme/learnpress/settings/tabs/change-password.php.
 *
 * @author   ThimPress
 * @package  Learnpress/Templates
 * @version  4.0.0
 */

defined( 'ABSPATH' ) || exit();

$profile = LP_Profile::instance();
$privacy = $profile->get_privacy_settings();
?>
<div class="card">
	<div class="card-header">
		<h3 class="mb-0"><?php esc_html_e( 'Profile Privacy', 'geeks' ); ?></h3>
		<p class="mb-0"><?php esc_html_e( 'These controls give you the ability to customize what areas of your profile others are able to see.', 'geeks' ); ?></p>
	</div>
	<div class="card-body">
		<form method="post" name="profile-privacy" enctype="multipart/form-data" class="learn-press-form">

			<?php do_action( 'learn-press/before-profile-privacy-fields', $profile ); ?>

			<ul class="form-fields list-group list-group-flush">

				<?php
				do_action( 'learn-press/begin-profile-privacy-fields', $profile );

				foreach ( $privacy as $item ) {
					?>
					<li class="form-field list-group-item d-flex align-items-center justify-content-between px-0 py-2">
						<div>
							<label for="privacy-<?php echo esc_attr( $item['id'] ); ?>">
								<?php echo esc_html( $item['name'] ); ?>
							
								<?php if ( ! empty( $item['description'] ) ) : ?>
								<span class="description">&mdash;&nbsp;<?php echo esc_html( $item['description'] ); ?></span>
								<?php endif; ?>
							
							</label>
						</div>
						<div>
							<div class="form-field-input form-check form-switch">
								<input type="hidden" name="privacy[<?php echo esc_attr( $item['id'] ); ?>]" value="no"/>
								<input class="form-check-input" type="checkbox" name="privacy[<?php echo esc_attr( $item['id'] ); ?>]" value="yes" id="privacy-<?php echo esc_attr( $item['id'] ); ?>" <?php checked( $profile->get_privacy( $item['id'] ), 'yes' ); ?>>
							</div>
						</div>
					</li>
					<?php
				}
				?>

				<?php do_action( 'learn-press/end-profile-privacy-fields', $profile ); ?>

			</ul>
			<input type="hidden" name="save-profile-privacy" value="<?php echo wp_create_nonce( 'learn-press-save-profile-privacy' ); ?>"/>

			<?php do_action( 'learn-press/after-profile-privacy-fields', $profile ); ?>

			<button type="submit" class="btn btn-primary" name="submit" id="submit"><?php esc_html_e( 'Save changes', 'geeks' ); ?></button>

		</form>
	</div>
</div>