<?php
/**
 * Template for displaying loop course of section.
 *
 * This template can be overridden by copying it to yourtheme/learnpress/single-course/loop-section.php.
 *
 * @author   ThimPress
 * @package  Learnpress/Templates
 * @version  4.0.1
 */

defined( 'ABSPATH' ) || exit();

/**
 * @var LP_Course_Section $section
 */
if ( ! isset( $section ) || ! isset( $can_view_content_course ) ) {
	return;
}

$course = learn_press_get_the_course();

if ( ! apply_filters( 'learn-press/section-visible', true, $section, $course ) ) {
	return;
}

$user           = learn_press_get_current_user();
$user_course    = $user->get_course_data( get_the_ID() );
$section_class  = geeks_get_section_main_class( $section );
$collapse_id    = 'section-' . $course->get_id() . '-' . $section->get_id();
$collapsed      = learn_press_cookie_get( 'closed-section-' . $section->get_course_id() );
$is_collapsed   = false;
$items          = $section->get_items();
$section_class .= ' list-group-item';
$course_item    = LP_Global::course_item();
$single_version = geeks_get_single_course_version();

if ( ! $course_item ) {
	$section_class .= ' px-0';
}

if ( $collapsed && in_array( $section->get_id(), $collapsed ) ) {
	$is_collapsed = true;
}

$header_atts = [
	'class'          => 'section-header h4 mb-0 d-flex align-items-center text-inherit text-decoration-none',
	'href'           => '#' . $collapse_id,
	'data-bs-toggle' => 'collapse',
	'data-bs-target' => '#' . $collapse_id,
	'aria-controls'  => $collapse_id
];

if ( $is_collapsed ) {
	$header_atts['aria-expanded'] = 'false';
	$header_atts['class']        .= ' collapsed';
} else {
	$header_atts['aria-expanded'] = 'true';
}


if( 'v2' === $single_version && !geeks_is_lesson() ) {
	$section_class           .= ' p-0';
	$header_atts['class']    .= ' px-4 py-3';
}

if( 'v2' === $single_version && !geeks_is_lesson() ) {
	$section_content_classes = 'list-group-flush';
	$section_content_list_classes = 'list-group-item';
	$wrap_classes                 = 'p-0';
} else {
	$section_content_classes = 'mb-n2';
	$section_content_list_classes = 'mb-2';
	$wrap_classes                 = 'pt-3 pb-2';
}

if( geeks_is_lesson() ) {
	$wrap_classes = 'py-4';
} 

?>
<li class="<?php echo esc_attr( $section_class ); ?>"
	id="section-<?php echo esc_attr( $section->get_slug() ); ?>"
	data-id="<?php echo esc_attr( $section->get_slug() ); ?>"
	data-section-id="<?php echo esc_attr( $section->get_id() ); ?>">
	
	<?php do_action( 'learn-press/before-section-summary', $section, $course->get_id() ); ?>

	<a <?php echo geeks_get_render_attribute_string( $header_atts ); ?>>
		
		<div class="section-title me-auto">
			<?php
			$title = $section->get_title();
			echo ! $title ? esc_html_x( 'Untitled', 'template title empty', 'geeks' ) : $title;
			?>
			<?php $description = $section->get_description(); ?>

			<?php if ( $description ) : ?>
				<p class="section-desc mb-0 text-muted fs-6 mt-1 fw-normal <?php if( 'v2' !== $single_version ||  geeks_is_lesson()):?>sr-only<?php endif;?>"><?php echo esc_html( $description ); ?></p>
			<?php endif; ?>
		</div>

		<span class="chevron-arrow ms-4">
          	<i class="fe fe-chevron-down fs-4"></i>
        </span>
	</a>
	
	<div class="collapse<?php if ( ! $is_collapsed ): ?> show<?php endif; ?>" id="<?php echo esc_attr( $collapse_id ); ?>">
		<div class="<?php echo esc_attr( $wrap_classes );?>">

			<?php $description = $section->get_description(); ?>

			<?php if ( $description ) : ?>
				<p class="section-desc d-none"><?php echo esc_html( $description); ?></p>
			<?php endif; ?>

			<?php do_action( 'learn-press/before-section-content', $section, $course->get_id() ); ?>

			<?php if ( ! $items ) : ?>
				<?php learn_press_display_message( esc_html__( 'No items in this section', 'geeks' ) ); ?>
			<?php else : ?>

				<ul class="section-content list-unstyled list-group <?php echo esc_attr( $section_content_classes );?>">					
					<?php if ( $user->has_enrolled_course( $section->get_course_id() ) && 'v2' === $single_version && !geeks_is_lesson() ) : ?>
						<?php $percent = $user_course->get_percent_completed_items( '', $section->get_id() ); ?>

						<li class="section-meta list-group-item">
							<div class="progress" style="height: 6px;" title="<?php echo esc_attr( sprintf( esc_html__( 'Section progress %s%%', 'geeks' ), round( $percent, 2 ) ) ); ?>">
								<div class="learn-press-progress__active progress-bar bg-success" data-value="<?php echo esc_attr( $percent ); ?>" role="progressbar" style="width: <?php echo esc_attr( $percent );?>%" aria-valuenow="<?php echo esc_attr( $percent );?>" aria-valuemin="0" aria-valuemax="100"></div>
							</div>

							<small><?php echo round( $percent ); ?>% <?php esc_html_e(' Completed', 'geeks')?></small>
						</li>

						<?php do_action( 'learnpress/single-course/section-header/after', $section ); ?>
					<?php endif; ?>


					<?php
					foreach ( $items as $item ) :
						
						$can_view_item     = $user->can_view_item( $item->get_id(), $can_view_content_course );
						$item_classes      = $item->get_class();
						$item_link_classes = 'section-item-link d-flex justify-content-between align-items-center text-decoration-none';

						?>
						<li class="<?php echo esc_attr( $section_content_list_classes);?> <?php echo esc_attr( implode( ' ', $item->get_class() ) ); ?>" data-id="<?php echo esc_attr( $item->get_id() ); ?>">

							<?php
							do_action( 'learn-press/before-section-loop-item', $item, $section, $course );

							$item_link = $can_view_item->flag ? $item->get_permalink() : false;
							$item_link = apply_filters( 'learn-press/section-item-permalink', $item_link, $item, $section, $course );

							?>

							<a class="<?php echo esc_attr( $item_link_classes ); ?>" href="<?php echo false === $item_link ? 'javascript:void(0);' : esc_url( $item_link ); ?>">
								<div class="text-truncate">
									<?php
									do_action( 'learn-press/before-section-loop-item-title', $item, $section, $course );

									learn_press_get_template(
										'single-course/section/' . $item->get_template(),
										array(
											'item'    => $item,
											'section' => $section,
										)
									);

									?>
								</div>
								<div class="text-truncate">
									<?php
									do_action( 'learn-press/after-section-loop-item-title', $item, $section, $course );
									?>
								</div>
							</a>

							<?php do_action( 'learn-press/after-section-loop-item', $item, $section, $course ); ?>
						</li>
					<?php endforeach; ?>
				</ul>
			<?php endif; ?>

			<?php do_action( 'learn-press/after-section-summary', $section, $course->get_id() ); ?>
		</div>
	</div><!-- /.collapse -->
</li>
