<?php
/**
 * Template for displaying tab nav of single course.
 *
 * This template can be overridden by copying it to yourtheme/learnpress/single-course/tabs/tabs.php.
 *
 * @author   ThimPress
 * @package  Learnpress/Templates
 * @version  4.0.0
 */

defined( 'ABSPATH' ) || exit();

$tabs           = learn_press_get_course_tabs();
$single_version = geeks_get_single_course_version();

if ( 'v2' === $single_version ) {
	$nav_classes = 'nav-lt-tab';
} else {
	$nav_classes = 'nav-lb-tab';

}
if ( empty( $tabs ) ) {
	return;
}

$active_tab = learn_press_cookie_get( 'course-tab' );

if ( ! $active_tab ) {
	$tab_keys   = array_keys( $tabs );
	$active_tab = reset( $tab_keys );
}

// Show status course
$lp_user = learn_press_get_current_user();

if ( $lp_user && ! $lp_user instanceof LP_User_Guest ) {
	$can_view_course = $lp_user->can_view_content_course( get_the_ID() );

	if ( ! $can_view_course->flag ) {
		if ( LP_BLOCK_COURSE_FINISHED === $can_view_course->key ) {
			learn_press_display_message(
				esc_html__( 'You finished this course. This course has been blocked', 'geeks' ),
				'warning'
			);
		} elseif ( LP_BLOCK_COURSE_DURATION_EXPIRE === $can_view_course->key ) {
			learn_press_display_message(
				esc_html__( 'This course has been blocked reason by expire', 'geeks' ),
				'warning'
			);
		}
	}
}
?>

<div id="learn-press-course-tabs" class="course-tabs <?php if( 'v2' !== $single_version ):?>card rounded-3<?php endif;?>">

	<div class="<?php if( 'v2' === $single_version ):?>card rounded-top-left-0 rounded-top-end-0 mb-5<?php else:?>card-header<?php endif;?> border-bottom-0 p-0">
		<ul class="learn-press-nav-tabs course-nav-tabs nav <?php echo esc_attr( $nav_classes );?>" id="tab" role="tablist" data-tabs="<?php echo count( $tabs ); ?>">
			<?php if ( 'v2' === $single_version ):
				$i = 0;
			endif;

			foreach ( $tabs as $key => $tab ) : ?>
				<?php
				$classes = array( 'course-nav course-nav-tab-' . esc_attr( $key ) . ' nav-item' );

				$label_atts = [
					'for'            => 'tab-' . $key . '-input',
					'class'          => 'nav-link',
					'id'             => $key . '-tab',
					'data-bs-toggle' => 'pill',
					'data-bs-target' => '#' . $key . '-tab-pane',
					'role'           => 'tab',
					'aria-controls'  => $key . '-tab-pane',
				];

				$label_atts['aria-selected'] = 'false';

				if ( 'v2' === $single_version ){

					if ( 0 === $i ) {
						$label_atts['aria-selected'] = 'true';
						$label_atts['class']        .= ' active';
	                }
	           } else {
	           		if ( $active_tab === $key ) {
						$label_atts['aria-selected'] = 'true';
						$label_atts['class']        .= ' active';
					} 
	           }

				?>

				<li class="<?php echo implode( ' ', $classes ); ?>">
					<label <?php echo geeks_get_render_attribute_string( $label_atts ); ?>>
						<input type="radio" class="btn-check" name="learn-press-course-tab-radio" id="tab-<?php echo esc_attr( $key ); ?>-input" <?php checked( $active_tab === $key ); ?> value="<?php echo esc_attr( $key ); ?>">
						<?php echo esc_html( $tab['title'] ); ?>
					</label>
				</li>
				<?php if ( 'v2' === $single_version ):
					$i++;
				endif;
			endforeach; ?>
		</ul>
	</div>

	<?php if( 'v2' ===  $single_version ): ?>
		<div class="card rounded-3">
	<?php endif; ?>

	<div class="card-body">
		<div class="course-tab-panels tab-content" id="tab-content">
			<?php if ( 'v2' === $single_version ):
				$i = 0;
			endif;
			foreach ( $tabs as $key => $tab ) : ?>
				<?php
					$tab_pane_atts = [
						'class'           => 'course-tab-panel-' . $key . ' course-tab-panel tab-pane fade',
						'id'              => $key . '-tab-pane',
						'role'            => 'tabpanel',
						'aria-labelledby' => $key . '-tab'
					];

					if ( 'v2' === $single_version ){
						if ( $i === 0 ) {
							$tab_pane_atts['class'] .= ' show active';
						}
					} else {
						if ( $active_tab === $key ) {
							$tab_pane_atts['class'] .= ' show active';
						}
					}

					
				?>
				<div <?php echo geeks_get_render_attribute_string( $tab_pane_atts ); ?>>
					<div>
					
					<?php if ( isset( $tab['content_title'] ) && ! empty( $tab['content_title'] ) ) : ?>
					<h3 class="mb-3"><?php echo esc_html( $tab['content_title'] ); ?></h3>
					<?php endif; ?>
					
					<?php
						if ( is_callable( $tab['callback'] ) ) {
							call_user_func( $tab['callback'], $key, $tab );
						}
						
						do_action( 'learn-press/course-tab-content', $key, $tab );

						do_action( 'geeks_after_tab_content_' . $key, $key, $tab );
					?>
					</div>
				</div>
				<?php if ( 'v2' === $single_version ):
					$i++;
				endif;
			endforeach; ?>
		</div>
	</div>

	<?php if( 'v2' ===  $single_version ): ?>
		</div>
	<?php endif; ?>
</div>