<?php
/**
 * Template for displaying course reviews
 *
 * @since v.1.0.0
 *
 * @author Themeum
 * @url https://themeum.com
 *
 * @package TutorLMS/Templates
 * @version 1.4.5
 */

$disable = ! get_tutor_option( 'enable_course_review' );
if ( $disable ) {
    return;
}

$per_page = tutor_utils()->get_option( 'pagination_per_page', 10 );
$current_page = max(1, (int)tutor_utils()->avalue_dot('current_page', $_POST));
$offset = ($current_page - 1) * $per_page;

$course_id = isset($_POST['course_id']) ? (int)$_POST['course_id'] : get_the_ID();
$is_enrolled = tutor_utils()->is_enrolled($course_id, get_current_user_id());

$reviews = tutor_utils()->get_course_reviews($course_id, $offset, $per_page);
$reviews_total = tutor_utils()->get_course_reviews($course_id, null, null, true);
$rating = tutor_utils()->get_course_rating($course_id);
$my_rating = tutor_utils()->get_reviews_by_user(0, 0, 150, false, $course_id);
$content_title = isset( $content_title ) ? $content_title : esc_html__( 'How students rated this course', 'geeks' );

if(isset($_POST['course_id'])) {
    // It's load more
    tutor_load_template('single.course.reviews-loop', array('reviews' => $reviews));
    return;
}

do_action( 'tutor_course/single/enrolled/before/reviews' );

?>
<div class="tutor-pagination-wrapper-replaceable">
	<div class="tutor-card tutor-review-card">
		<div class="mb-3">
			<h3 class="mb-4"><?php echo esc_html( $content_title ); ?></h3>
			<?php if(! is_array( $reviews ) || ! count( $reviews )): ?>
				<?php tutor_utils()->tutor_empty_state(esc_html__('No Review Yet', 'geeks')); ?>
			<?php else: ?>
				<div class="row align-items-center">
					<div class="col-auto text-center">
						<h3 class="display-2 fw-bold"><?php echo esc_html( number_format_i18n( $rating->rating_avg, 1 ) ); ?></h3>
						<div class="tutor-star-rating-group">
							<?php geeks_display_review_stars( $rating->rating_avg ); ?>
						</div>

						<p class="mb-0 fs-6">(<?php echo esc_html( sprintf( _nx( 'Based on %s review', 'Based on %s reviews', $rating->rating_count, 'number of reviews', 'geeks' ), number_format_i18n( $rating->rating_count ) ) ); ?>)</p>
					</div>
					<!-- Progress bar -->
					<div class="col pt-3 order-3 order-md-2">
						<?php 
						foreach ( $rating->count_by_value as $key => $value ): 
							$rating_count_percent = ( 0 < $value ) ? ( $value  * 100 ) / $rating->rating_count : 0;
						?>
						<div class="progress mb-3" style="height: 6px;">
							<div class="progress-bar bg-warning" role="progressbar" style="width: <?php echo esc_attr( $rating_count_percent ); ?>%;" aria-valuenow="<?php echo esc_attr( $rating_count_percent ); ?>" aria-valuemin="0" aria-valuemax="100"></div>
						</div>
						<?php endforeach; ?>
					</div>
					<div class="col-md-auto col-6 order-2 order-md-3">
						<!-- Rating -->
						<?php 
						foreach ( $rating->count_by_value as $key => $value ):
							$rating_count_percent = ( 0 < $value ) ? ( $value  * 100 ) / $rating->rating_count : 0;

						?>
						<div>
							<?php for ( $i = 0; $i < 5; $i++ ) : ?>
							<i class="mdi mdi-star me-n1 <?php if ( $i < $key ) : ?>text-warning<?php else: ?>text-light<?php endif; ?>"></i>
							<?php endfor; ?>
							<span class="ms-1"><?php echo esc_html( number_format_i18n( $rating_count_percent, apply_filters( 'geeks_rating_decimal_value', 0 ) )  ); ?>%</span>
						</div>
						<?php endforeach; ?>
					</div>
				</div>
			<?php endif; ?>
		</div>
		<!-- hr -->
		<hr class="my-5">
		<div class="mb-3 tutor-reviews tutor-card-list tutor-pagination-content-appendable">
			<div class="d-lg-flex align-items-center justify-content-between mb-5">
				<!-- Reviews -->
				<div class="mb-3 mb-lg-0">
					<h3 class="mb-0"><?php esc_html_e( 'Reviews', 'geeks' ); ?></h3>
				</div>
			</div>
			<?php 
			
			tutor_load_template('single.course.reviews-loop', array('reviews' => $reviews)); ?>

		</div>
	</div>

	<div class="tutor-bs-row tutor-mt-40 tutor-mb-20 d-flex justify-content-between align-items-center">
		<div class="tutor-bs-col">
			<?php if($is_enrolled): ?>
				<button class="tutor-btn5 write-course-review-link-btn btn btn-outline-primary d-flex align-items-center">
					<i class="tutor-icon-star-line-filled tutor-icon-24 tutor-mr-5"></i>
					<?php
						$is_new = !$my_rating || empty($my_rating->rating) || empty($my_rating->comment_content);
						$is_new ? esc_html_e('Write a review', 'geeks') : esc_html_e('Edit review', 'geeks');
					?>
				</button>
			<?php endif; ?>
		</div>
		
		<div class="tutor-col-auto">
			<?php
				$pagination_data = array(
					'total_items' => $reviews_total,
					'per_page'    => $per_page,
					'paged'       => $current_page,
					'layout'	  => array(
						'type' => 'load_more',
						'load_more_text' => esc_html__('Load More', 'geeks')
					),
					'ajax'		  => array(
						'action' => 'tutor_single_course_reviews_load_more',
						'course_id' => $course_id,
					)
				);

				$pagination_template_frontend = tutor()->path . 'templates/dashboard/elements/pagination.php';
				tutor_load_template_from_custom_path( $pagination_template_frontend, $pagination_data );
			?>
		</div>
	</div>
</div>

<?php if($is_enrolled): ?>
	<div class="tutor-course-enrolled-review-wrap tutor-mt-15">
		<div class="tutor-write-review-form" style="display: none;">
			<form method="post">
				<div class="tutor-star-rating-container">
					<input type="hidden" name="course_id" value="<?php echo esc_attr( $course_id ); ?>"/>
					<input type="hidden" name="review_id" value="<?php echo esc_attr( $my_rating ? $my_rating->comment_ID : '' ); ?>"/>
					<input type="hidden" name="action" value="tutor_place_rating"/>
					<div class="tutor-form-group mb-3">
						<div class="tutor-ratings tutor-ratings-lg tutor-ratings-selectable" tutor-ratings-selectable>
							<?php
								tutor_utils()->star_rating_generator(tutor_utils()->get_rating_value($my_rating ? $my_rating->rating : 0));
							?>
						</div>
					</div>
					<div class="tutor-form-group mb-3">
						<textarea class="form-control" name="review" placeholder="<?php _e('write a review', 'geeks'); ?>"><?php echo stripslashes($my_rating ? $my_rating->comment_content : ''); ?></textarea>
					</div>
					<div class="tutor-form-group">
						<button type="submit" class="tutor_submit_review_btn tutor-btn btn btn-primary">
							<?php echo esc_html__('Submit Review', 'geeks'); ?>
						</button>
					</div>
				</div>
			</form>
		</div>
	</div>
<?php endif; ?>
<?php do_action( 'tutor_course/single/enrolled/after/reviews' ); ?>