<?php
/**
 * Template for course filter
 *
 * @package Tutor\Templates
 * @subpackage Course_Filter
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.0.0
 */
 
$filter_object = new \Geeks\Tutor\Course_Filter();
$filter_levels = array(
	'beginner'     => esc_html__( 'Beginner', 'geeks' ),
	'intermediate' => esc_html__( 'Intermediate', 'geeks' ),
	'expert'       => esc_html__( 'Expert', 'geeks' ),
);
$filter_prices = array(
	'free' => esc_html__( 'Free', 'geeks' ),
	'paid' => esc_html__( 'Paid', 'geeks' ),
);

$supported_filters = tutor_utils()->get_option( 'supported_course_filters', array() );
$supported_filters = array_keys( $supported_filters );
$reset_link		   = remove_query_arg( $supported_filters, get_pagenum_link() );

?>

<form>
	<div class="mb-3 tutor-d-block tutor-d-lg-none tutor-text-right">
		<a href="#" class="tutor-iconic-btn tutor-mr-n8" tutor-hide-course-filter=""><span class="tutor-icon-times" area-hidden="true"></span></a>
	</div>

	<div class="card">
		<div class="card-header">
			<div class="d-flex align-items-center justify-content-between">
				<h4 class="mb-0"><?php esc_html_e( 'Filter', 'geeks' ); ?></h4>
				<div class="tutor-clear-all-filter">
					<a href="#" class="fs-6 text-muted" onclick="window.location.replace('<?php echo esc_url( $reset_link ); ?>')" action-tutor-clear-filter>
						<i class="fe fe-x-circle"></i> <?php esc_html_e( 'Clear', 'geeks' ); ?>
					</a>
				</div>
			</div>
		</div>
		<?php do_action( 'tutor_course_filter/before' ); //phpcs:ignore WordPress.NamingConventions.ValidHookName.UseUnderscores ?>
		<?php
			$has_border = false;
		if ( in_array( 'search', $supported_filters, true ) ) {
			?>
				<div class="card-body">
					<div class="tutor-course-search-field position-relative">
						<input class="form-control" type="text" name="keyword" placeholder="<?php esc_attr_e( 'Search...', 'geeks' ); ?>"/>
						<i class="tutor-icon-magnifying-glass-1 position-absolute top-50 end-0 translate-middle-y me-3"></i>
					</div>
				</div>
				<?php
				$has_border = true;
		}


		/**
		 * Add action before category filter.
		 *
		 * @since 2.2.0
		 */
		do_action( 'tutor_before_course_category_filter' );
	

		if ( in_array( 'category', $supported_filters, true ) ) {
			$args = [
				'taxonomy'   => 'course-category',
				'hide_empty' => true,
			];
			if ( 0 < absint( wp_count_terms( $args ) ) ) :
				?>
				<div class="card-body<?php echo esc_attr( $has_border ? ' border-top' : '' ); ?>">
					<h4 class="dropdown-header px-0 mb-2"><?php esc_html_e( 'Category', 'geeks' ); ?></h4>
					<div class="ms-n4"><?php $filter_object->render_terms( $args, 'category' ); ?></div>
				</div>
				<?php
				$has_border = true;
				endif;
		}

		if ( in_array( 'tag', $supported_filters, true ) ) {
			$args = [
				'taxonomy'   => 'course-tag',
				'hide_empty' => true,
			];
			if ( 0 < absint( wp_count_terms( $args ) ) ) :
				?>
				<div class="card-body<?php echo esc_attr( $has_border ? ' border-top' : '' ); ?>">
					<h4 class="dropdown-header px-0 mb-2"><?php esc_html_e( 'Tag', 'geeks' ); ?></h4>
					<div class="ms-n4"><?php $filter_object->render_terms( $args, 'tag' ); ?></div>
				</div>
				<?php
				$has_border = true;
				endif;
		}

		if ( in_array( 'difficulty_level', $supported_filters, true ) ) {
			?>
				<div class="card-body<?php echo esc_attr( $has_border ? ' border-top' : '' ); ?>">
					<h4 class="dropdown-header px-0 mb-2"><?php esc_html_e( 'Level', 'geeks' ); ?></h4>
				<?php foreach ( $filter_levels as $value => $filter_label ) : ?>
					<div class="form-check mb-1">
						<input type="checkbox"  class="form-check-input" id="check-<?php echo esc_attr( $value ); ?>" name="tutor-course-filter-level" value="<?php echo esc_attr( $value ); ?>">
						<label class="form-check-label" for="check-<?php echo esc_attr( $value ); ?>"><?php echo esc_html( $filter_label ); ?></label>
					</div>
					<?php endforeach; ?>
				</div>
				<?php
				$has_border = true;
		}

		$is_membership = 'pmpro' === get_tutor_option( 'monetize_by' ) && tutils()->has_pmpro();
		if ( ! $is_membership && in_array( 'price_type', $supported_filters, true ) ) {
			?>
			<?php
			/**
			 * Add action before price filter.
			 *
			 * @since 2.2.0
			 */
			do_action( 'tutor_before_course_price_filter' );
			?>
			<div class="card-body<?php echo esc_attr( $has_border ? ' border-top' : '' ); ?>">
				<h4 class="dropdown-header px-0 mb-2"><?php esc_html_e( 'Price', 'geeks' ); ?></h4>
			<?php foreach ( $filter_prices as $value => $filter_label ) : ?>
				<div class="form-check mb-1">
					<input type="checkbox" class="form-check-input" id="check-<?php echo esc_attr( $value ); ?>" name="tutor-course-filter-price" value="<?php echo esc_attr( $value ); ?>">
					<label class="form-check-label" for="check-<?php echo esc_attr( $value ); ?>"><?php echo esc_html( $filter_label ); ?></label>
				</div>
				<?php endforeach; ?>
			</div>
			<?php
			$has_border = true;
		}
		?>
		<?php do_action( 'tutor_course_filter/after' ); //phpcs:ignore WordPress.NamingConventions.ValidHookName.UseUnderscores ?>
	</div>
</form>
