<?php
/**
 * Template for displaying frontend dashboard
 *
 * @package Tutor\Templates
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.4.3
 */


$is_by_short_code = isset( $is_shortcode ) && $is_shortcode === true;
if ( ! $is_by_short_code ) {
	get_header();
}

global $wp_query;

$dashboard_page_slug = '';
$dashboard_page_name = '';
if ( isset( $wp_query->query_vars['tutor_dashboard_page'] ) && $wp_query->query_vars['tutor_dashboard_page'] ) {
	$dashboard_page_slug = $wp_query->query_vars['tutor_dashboard_page'];
	$dashboard_page_name = $wp_query->query_vars['tutor_dashboard_page'];
}
/**
 * Getting dashboard sub pages
 */
if ( isset( $wp_query->query_vars['tutor_dashboard_sub_page'] ) && $wp_query->query_vars['tutor_dashboard_sub_page'] ) {
	$dashboard_page_name = $wp_query->query_vars['tutor_dashboard_sub_page'];
	if ( $dashboard_page_slug ) {
		$dashboard_page_name = $dashboard_page_slug . '/' . $dashboard_page_name;
	}
}
$dashboard_page_name = apply_filters( 'tutor_dashboard_sub_page_template', $dashboard_page_name );

$user_id = get_current_user_id();
$user    = get_user_by( 'ID', $user_id );

$enable_profile_completion = tutils()->get_option( 'enable_profile_completion' );

$instructor_status = tutor_utils()->instructor_status( 0, false );
$instructor_status = is_string( $instructor_status ) ? strtolower( $instructor_status ) : '';
$rejected_on       = get_user_meta( $user->ID, '_is_tutor_instructor_rejected', true );

$header_dasboard_data = [
	'user_id'       => $user_id,
	'action_button' => geeks_tutor_get_dashboard_action_button( $user, $instructor_status ),
];

do_action( 'tutor_dashboard/before/wrap' );
?>
<div class="pt-5 pb-5 tutor-wrap tutor-dashboard tutor-dashboard-student container">
	
	<?php geeks_get_template( 'profile/header-dashboard.php', $header_dasboard_data ); ?>

	<?php
	if ( 'approved' !== $instructor_status &&
		'pending' !== $instructor_status &&
		$rejected_on &&
		get_user_meta( get_current_user_id(), 'tutor_instructor_show_rejection_message', true )
	) :
		?>

	<div class="tutor-instructor-rejection-notice alert alert-danger alert-dismissible fade show mt-0 mt-md-4" role="alert">
		<?php
			$on = gmdate( 'd F, Y', $rejected_on );
			/* translators: %s: date on which the application was rejected */
			echo esc_html( sprintf( esc_html__( 'Your application to become an instructor was rejected on %s', 'geeks' ), $on ) );
		?>
		<button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="<?php esc_attr_e( 'Close', 'geeks' ); ?>"></button>
	</div>

	<?php endif; ?>

	<?php do_action( 'tutor_dashboard/notification_area' ); ?>

	<div class="row mt-0 mt-md-4">
		<div class="col-lg-3 col-md-4 col-12 tutor-dashboard-left-menu">
			<?php geeks_tutor_dashboard_navigation( $dashboard_page_slug, $dashboard_page_name ); ?>
		</div>
		<div class="col-lg-9 col-md-8 col-12">
			<div class="tutor-dashboard-content">
				<?php
				// if ( $dashboard_page_name ) {
				// 	do_action( 'tutor_load_dashboard_template_before', $dashboard_page_name );
				// 	tutor_load_template( 'dashboard.' . $dashboard_page_name );
				// 	do_action( 'tutor_load_dashboard_template_before', $dashboard_page_name );
				// } else {
				// 	tutor_load_template( 'dashboard.dashboard' );
				// }

				if ($dashboard_page_name){
                    do_action('tutor_load_dashboard_template_before', $dashboard_page_name);

                    /**
                     * Load dashboard template part from other location
                     * 
                     * this filter is basically added for adding templates from respective addons
                     * 
                     * @since version 1.9.3
                     */
                    $other_location = '';
                    $from_other_location = apply_filters( 'load_dashboard_template_part_from_other_location', $other_location );
                    
                    if ( $from_other_location == '' ) {
						tutor_load_template('dashboard.' . $dashboard_page_name);
                    } else {
                        //load template from other location full abspath
                        include_once $from_other_location;
                    }
                    
                    do_action('tutor_load_dashboard_template_before', $dashboard_page_name);
                } else {
                    tutor_load_template("dashboard.dashboard");
                }
				?>
			</div>
		</div>
	</div>

</div>

<?php do_action( 'tutor_dashboard/after/wrap' ); ?>

<?php
if ( ! $is_by_short_code ) {
	get_footer();
}
