<?php

/**
 * Template for displaying Assignments
 *
 * @package Tutor\Templates
 * @subpackage Dashboard
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.3.4
 */

if ( ! defined( 'TUTOR_PRO_VERSION' ) ) {
    return;
}

use TUTOR\Input;
use TUTOR_ASSIGNMENTS\Assignments_List;

$per_page     = tutor_utils()->get_option( 'pagination_per_page', 10 ); //phpcs:ignore
$current_page = max( 1, Input::get( 'current_page', 1, Input::TYPE_INT ) );
$offset       = ( $current_page - 1 ) * $per_page;

$course_id    = Input::get( 'course-id', 0, Input::TYPE_INT );
$order_filter = Input::get( 'order', 'DESC' );
$date_filter  = Input::get( 'date', '' );

$current_user = get_current_user_id();
$assignments  = tutor_utils()->get_assignments_by_instructor( null, compact( 'course_id', 'order_filter', 'date_filter', 'per_page', 'offset' ) );
$courses      = ( current_user_can( 'administrator' ) ) ? tutor_utils()->get_courses() : tutor_utils()->get_courses_by_instructor();

?>

<div class="card mb-3">
    <div class="card-header">
        <div class="tutor-dashboard-announcement-sorting-wrap row align-items-center geeks-announcement-sorting-wrap">
            <div class="tutor-form-group col-lg-5 col-md-6 pr-md-0 mb-2 mb-lg-0">
                <label class="form-label d-block">
                    <?php esc_html_e('Courses', 'geeks'); ?>
                </label>
                <select class="tutor-report-category tutor-announcement-course-sorting ignore-nice-select border rounded w-100">

                    <option value=""><?php esc_html_e('All', 'geeks'); ?></option>

                    <?php if ($courses) : ?>
                        <?php foreach ($courses as $course) : ?>
                            <option value="<?php echo esc_attr($course->ID) ?>" <?php selected($course_id, $course->ID, 'selected') ?>>
                                <?php echo esc_html( $course->post_title ); ?>
                            </option>
                        <?php endforeach; ?>
                    <?php else : ?>
                        <option value=""><?php esc_html_e('No course found', 'geeks'); ?></option>
                    <?php endif; ?>
                </select>
            </div>
            <div class="tutor-form-group col-lg-3 col-md-6 pr-md-0 mb-2 mb-2 mb-lg-0">
                <label class="form-label d-block"><?php esc_html_e( 'Sort By', 'geeks' ); ?></label>
                <select class="tutor-announcement-order-sorting ignore-nice-select border rounded w-100">
                    <option <?php selected($order_filter, 'ASC'); ?>><?php esc_html_e('ASC', 'geeks'); ?></option>
                    <option <?php selected($order_filter, 'DESC'); ?>><?php esc_html_e('DESC', 'geeks'); ?></option>
                </select>
            </div>
            <div class="tutor-form-group tutor-announcement-datepicker col-lg-4 col-md-6 pr-md-0 mb-2 mb-2 mb-lg-0">
                <label class="form-label"><?php esc_html_e( 'Create Date', 'geeks' ); ?></label>
                <div class="input-group">
                    <input type="text" class="form-control text-dark flatpickr tutor-announcement-date-sorting"  value="<?php echo esc_attr( $date_filter !== '' ? tutor_get_formated_date( get_option( 'date_format' ), $date_filter ) : '' ); ?>" placeholder="<?php echo get_option( 'date_format' ); ?>" autocomplete="off" />
                    <span class="input-group-text text-muted"><i class="fe fe-calendar"></i></span>
                </div>
            </div>
        </div>
    </div>


    <div class="tutor-announcement-table-wrap table-responsive border-0">
        <table class="tutor-dashboard-announcement-table table mb-0 text-nowrap">
            <thead>
                <tr>
                    <th scope="col" class="border-0"><?php esc_html_e('Assignment Name', 'geeks') ?></th>
                    <th scope="col" class="border-0" width="15%"><?php esc_html_e('Total Marks', 'geeks') ?></th>
                    <th scope="col" class="border-0" width="15%"><?php esc_html_e('Total Submits', 'geeks') ?></th>
                    <th scope="col" class="border-0" width="10%">&nbsp;</th>
                </tr>
            </thead>

            <tbody>
                <?php
                
                if ( is_array( $assignments->results ) && count( $assignments->results ) ) : 
                    $submitted_url = tutor_utils()->get_tutor_dashboard_page_permalink('assignments/submitted');

                        foreach ($assignments->results as $item) {
                           $max_mark      = tutor_utils()->get_assignment_option( $item->ID, 'total_mark' );
                            $course_id     = tutor_utils()->get_course_id_by( 'assignment', $item->ID );
                            $comment_count = Assignments_List::assignment_comment_count( $item->ID );
                            // @TODO: assign post_meta is empty if user don't click on update button (http://prntscr.com/oax4t8) but post status is publish.
                        ?>
                            <tr>
                                <td class="border-top-0">
                                    <div class="tutor-announcement-content">
                                        <h4 class="mb-1 h5"><?php echo esc_html($item->post_title); ?></h4>
                                        <p class="mb-0 fs-6"><?php echo esc_html__('Course: ', 'geeks'); ?><a href='<?php echo get_the_permalink($course_id) ?>' target="_blank"><?php echo get_the_title($course_id); ?> </a></p>
                                    </div>
                                </td>
                                <td class="border-top-0"><?php echo esc_html( $max_mark ); ?></td>
                                <td class="border-top-0"><?php echo esc_html( $comment_count ); ?></td>
                                <td class="border-top-0">
                                    <a href="<?php echo esc_url($submitted_url . '?assignment=' . $item->ID); ?>" class="tutor-btn bordered-btn tutor-announcement-details btn btn-outline-primary">
                                        <?php esc_html_e('Details', 'geeks'); ?>
                                    </a>
                                </td>
                            </tr>
                            <?php
                        }
                    else : ?>
                        <tr>
                            <td colspan="100%">
                                <?php tutor_utils()->tutor_empty_state( tutor_utils()->not_found_text() ); ?>
                            </td>
                        </tr>
                <?php endif; ?>
            
            </tbody>
        </table>
    </div>
</div>

    <?php
    if($assignments->count > $per_page) {
        $pagination_data = array(
            'total_items' => $assignments->count,
            'per_page'    => $per_page,
            'paged'       => $current_page,
        );
        tutor_load_template_from_custom_path(
            tutor()->path . 'templates/dashboard/elements/pagination.php',
            $pagination_data
        );
    }
    ?>



