<?php
/**
 * Template for displaying Assignments Review Form
 *
 * @package Tutor\Templates
 * @subpackage Dashboard\Assignments
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @version 1.3.4
 */


use TUTOR\Input;

$assignment_id           = Input::get( 'assignment', 0, Input::TYPE_INT );
$assignment_submitted_id = Input::get( 'view_assignment', 0, Input::TYPE_INT );
$submitted_url           = tutor_utils()->get_tutor_dashboard_page_permalink( 'assignments/submitted' );

if(!$assignment_submitted_id){
	echo esc_html__("Sorry, but you are looking for something that isn't here." , 'geeks');
	return;
}
?>
<div class="tutor-dashboard-content-inner tutor-dashboard-assignment-review">
    <?php

    $submitted_assignment = tutor_utils()->get_assignment_submit_info($assignment_submitted_id);
    if ( $submitted_assignment ){

    	$max_mark = tutor_utils()->get_assignment_option($submitted_assignment->comment_post_ID, 'total_mark');

    	$given_mark = get_comment_meta($assignment_submitted_id, 'assignment_mark', true);
        $instructor_note = get_comment_meta($assignment_submitted_id, 'instructor_note', true);
        $comment_author = get_user_by('login', $submitted_assignment->comment_author)
    	?>

        <div class="submitted-assignment-title mb-2">
            <a class="prev-btn" href="<?php echo esc_url($submitted_url . '?assignment=' . $assignment_id); ?>"><span>&leftarrow;</span><span class="ms-2"><?php esc_html_e('Back', 'geeks'); ?></span></a>
        </div>

        <div class="tutor-assignment-review-header card mb-4">
            <div class="card-body">
                <h3>
                    <a href="<?php echo get_the_permalink($submitted_assignment->comment_post_ID); ?>" target="_blank">
        				<?php echo get_the_title($submitted_assignment->comment_post_ID); ?>
                    </a>
                </h3>
                <p>
        			<?php esc_html_e('Course' , 'geeks'); ?>:
                    <a href="<?php echo get_the_permalink($submitted_assignment->comment_parent); ?>" target="_blank">
        				<?php echo get_the_title($submitted_assignment->comment_parent); ?>
                    </a>
                </p>
                <p>
        			<?php esc_html_e('Student' , 'geeks'); ?>:
                    <span><?php echo esc_html( $comment_author->display_name. ' ('.$comment_author->user_email.')' ); ?></span>
                </p>
                <p>
        			<?php esc_html_e('Submitted Date' , 'geeks'); ?>:
                    <span><?php echo date('j M, Y, h:i a', strtotime($submitted_assignment->comment_date)); ?></span>
                </p>
            </div>
        </div>

        <hr>

        <div class="tutor-dashboard-assignment-submitted-content card mb-4">
            <div class="card-body">
                <h4 class="mb-0"><?php echo esc_html__('Assignment Description:', 'geeks'); ?></h4>
                <?php if( !empty( $submitted_assignment->comment_content ) ) { ?>
                    <p class="mt-2"><?php echo wp_kses_post( nl2br(stripslashes($submitted_assignment->comment_content)) ); ?></p>
                <?php } ?>

        		<?php
        		$attached_files = get_comment_meta($submitted_assignment->comment_ID, 'uploaded_attachments', true);
                    if ( $attached_files && is_array( json_decode( $attached_files ) ) ) {
        			?>
                    <h5><?php esc_html_e('Attach assignment file(s)', 'geeks'); ?></h5>
                    <div class="tutor-dashboard-assignment-files">
        				<?php
                        if ( $attached_files ) {
            				$attached_files = json_decode($attached_files, true);
            				if (tutor_utils()->count($attached_files)){
            					$upload_dir = wp_get_upload_dir();
            					$upload_baseurl = trailingslashit(tutor_utils()->array_get('baseurl', $upload_dir));
            					foreach ($attached_files as $attached_file){
            						?>
                                
                                    <div class="border p-3">
                                        <div>
                                            <a href="<?php echo esc_url( $upload_baseurl . tutor_utils()->array_get( 'uploaded_path', $attached_file ) ); ?>" target="_blank">
                                        <?php echo esc_html( tutor_utils()->array_get( 'name', $attached_file ) ); ?>
                                            </a>
                                            <span class="filesize"><?php esc_html_e( 'Size', 'geeks' ); ?><?php esc_html_e( ': 2MB', 'geeks' ); ?></span>
                                        </div>
                                        <div>
                                           <a href="<?php echo esc_url( $upload_baseurl . tutor_utils()->array_get( 'uploaded_path', $attached_file ) ); ?>" class="tutor-iconic-btn tutor-iconic-btn-secondary tutor-iconic-btn-lg" target="_blank" rel="noopener noreferrer">
                                                <span class="tutor-icon-download"></span>
                                            </a>
                                        </div>
                                    </div>
            						<?php
            					}
            				}
                        }
        				?>
                    </div>
        			<?php
        		}
        		?>
            </div>
        </div>

        <div class="tutor-dashboard-assignment-review card">
            <div class="card-body">
                <h3><?php esc_html__('Evaluation', 'geeks'); ?></h3>
                <form action="" method="post" class="tutor-form-submit-through-ajax" data-toast_success_message="<?php esc_attr_e('Assignment evaluated', 'geeks'); ?>">
        			<?php wp_nonce_field( tutor()->nonce_action, tutor()->nonce ); ?>
                    <input type="hidden" value="tutor_evaluate_assignment_submission" name="tutor_action"/>
                    <input type="hidden" value="<?php echo esc_html( $assignment_submitted_id ); ?>" name="assignment_submitted_id"/>
                    <div class="tutor-assignment-evaluate-row">
                        <div class="tutor-option-field-label">
                            <label class="form-label" for=""><?php _e('Your Points', 'geeks'); ?></label>
                        </div>
                        <div class="tutor-option-field input-mark">
                            <input class="form-control" type="number" name="evaluate_assignment[assignment_mark]" value="<?php echo esc_attr( $given_mark ? $given_mark : 0 ); ?>">
                            <p class="desc"><?php echo sprintf(__('Evaluate this assignment out of %s', 'geeks'), "<code>{$max_mark}</code>" ); ?></p>
                        </div>
                    </div>
                    <div class="tutor-assignment-evaluate-row">
                        <div class="tutor-option-field-label">
                            <label class="form-label" for=""><?php _e('Write a note', 'geeks'); ?></label>
                        </div>
                        <div class="tutor-option-field">
                            <textarea class="form-control" name="evaluate_assignment[instructor_note]"><?php echo esc_html( $instructor_note ); ?></textarea>
                            <p class="desc"><?php esc_html__('Write a note to students about this submission', 'geeks'); ?></p>
                        </div>
                    </div>
                    <div class="tutor-assignment-evaluate-row">
                        <div class="tutor-option-field-label"></div>
                        <div class="tutor-option-field">
                            <button type="submit" class="tutor-button tutor-button-primary btn btn-primary"><?php _e('Evaluate this submission', 'geeks'); ?></button>
                        </div>
                    </div>
                </form>
            </div>
        </div>

    <?php } else {
        ?>
        <div class="card">
            <p class="p-4 mb-0">
                <?php
    	           esc_html_e('Assignments submission not found or not completed', 'geeks');
                   ?>
               </p>
           </div>
           <?php
    } ?>
</div>