<?php
/**
 * Assignment Submitted Page
 *
 * @package Tutor\Templates
 * @subpackage Dashboard\Assignments
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @version 1.4.3
 */
if ( ! defined( 'TUTOR_PRO_VERSION' ) ) {
    return;
}
use TUTOR\Input;
use TUTOR_ASSIGNMENTS\Assignments_List;

$order_filter          = Input::get( 'order', 'desc' );
$assignment_id         = Input::get( 'assignment' );
$assignments_submitted = Assignments_List::get_submitted_assignments( $assignment_id, $order_filter );

$max_mark       = tutor_utils()->get_assignment_option( $assignment_id, 'total_mark' );
$pass_mark      = tutor_utils()->get_assignment_option( $assignment_id, 'pass_mark' );
$format         = get_option( 'date_format' ) . ' ' . get_option( 'time_format' );
$deadline       = tutor_utils()->get_assignment_deadline_date( $assignment_id, $format, __( 'No Limit', 'geeks' ) );
$comment_parent = ! empty( $assignments_submitted ) ? $assignments_submitted[0]->comment_parent : null;
?>

<div class="submitted-assignment-title mb-2">
    <a class="prev-btn" href="<?php echo tutor_utils()->get_tutor_dashboard_page_permalink('assignments'); ?>"><span>&leftarrow;</span><span class="ms-2"><?php esc_html_e('Back', 'geeks'); ?></span></a>
</div>

<div class="tutor-assignment-review-header tutor-assignment-submitted-page card mb-4">
    <div class="card-body">
        <p>
            <?php esc_html_e('Course', 'geeks'); ?> : <?php echo esc_html( get_the_title($comment_parent) ); ?>
            
        </p>
        <h3>
            <a href="<?php echo get_the_permalink($assignment_id); ?>" target="_blank">
                <?php echo esc_html( get_the_title($assignment_id) ); ?>
            </a>
        </h3>
        <div class="assignment-info">
            <p>
                <?php esc_html_e('Submission Deadline', 'geeks'); ?>:
                <strong><?php echo esc_html( $deadline ); ?></strong>
            </p>
            <p>
                <?php esc_html_e('Total Points', 'geeks'); ?>:
                <strong><?php echo esc_html( $max_mark ); ?></strong>
            </p>
            <p>
                <?php esc_html_e('Pass Points', 'geeks'); ?>:
                <strong><?php echo esc_html( $pass_mark ); ?></strong>
            </p>
        </div>
    </div>
</div>

<div class="tutor-announcement-table-wrap card">
    <div class="card-body">
        <div class="tutor-dashboard-announcement-sorting-wrap submitted-assignments-sorting-wrap mb-2">
            <div class="tutor-form-group w-100">
                <label class="form-label d-block"><?php esc_html_e('Sort By:', 'geeks'); ?></label>
                <select class="tutor-announcement-order-sorting ignore-nice-select border rounded w-100">
                    <option value="desc" <?php selected($order_filter, 'desc'); ?>><?php esc_html_e('Latest', 'geeks'); ?></option>
                    <option value="asc" <?php selected($order_filter, 'asc'); ?>><?php esc_html_e('Oldest', 'geeks'); ?></option>
                </select>
            </div>
        </div>

        <div class="table-responsive border-0 overflow-y-hidden">
            <table class="tutor-dashboard-announcement-table tutor-dashboard-assignment-table table mb-0 text-nowrap">
                <thead>
                    <tr>
                        <th scope="col" class="border-0" style="width:25%;"><?php esc_attr_e('Date', 'geeks'); ?></td>
                        <th scope="col" class="border-0"><?php esc_attr_e('Student', 'geeks'); ?></td>
                        <th scope="col" class="border-0" style="width:15%;"><?php esc_attr_e('Total Points', 'geeks'); ?></td>
                        <th scope="col" class="border-0" style="width:12%;"><?php esc_attr_e('Result', 'geeks'); ?></td>
                        <th scope="col" class="border-0" style="width:10%;">&nbsp;</td>
                    </tr>
                </thead>

                <tbody>
                    <?php
                    if (tutor_utils()->count($assignments_submitted)) {
                        foreach ($assignments_submitted as $assignment) {
                            $review_url                = tutor_utils()->get_tutor_dashboard_page_permalink('assignments/review');
                            $comment_author            = get_user_by('login', $assignment->comment_author); // login=username
                            $is_reviewed_by_instructor = get_comment_meta($assignment->comment_ID, 'evaluate_time', true);
                            $given_mark                = get_comment_meta($assignment->comment_ID, 'assignment_mark', true);
                            $not_evaluated             = $given_mark === '';
                            $status                    = 'pending';
                            $button_text               = esc_html__('Evaluate', 'geeks');

                            if (!empty($given_mark) || !$not_evaluated) {
                                $status = (int) $given_mark >= (int) $pass_mark ? sprintf(__('%s Pass %s', 'geeks'), '<span class="result-pass">', '</span>') : sprintf(esc_html__('%s Fail %s', 'geeks'), '<span class="result-fail">', '</span>');
                                $button_text = esc_html__('Details', 'geeks');
                            }

                            $review_url = tutor_utils()->get_tutor_dashboard_page_permalink('assignments/review');

                        ?>
                            <tr>
                                <td class="border-top-0"><?php echo date('j M, Y,<\b\r>h:i a', strtotime($assignment->comment_date)); ?></td>
                                <td class="border-top-0">
                                    <div class="student-column d-flex align-items-center">
                                        <div class="student-avatar me-2">
                                            <img class="mw-none rounded img-4by3-xs" src="<?php echo get_avatar_url( $comment_author->ID ); ?>" alt=" - Profile Picture">
                                        </div>
                                        <div class="student-details">
                                            <h4><?php echo esc_html( $comment_author->display_name ); ?></h4>
                                            <p class="mb-0"><?php echo esc_html( $comment_author->user_email ); ?></p>
                                        </div>
                                    </div>
                                </td>
                                <td class="border-top-0"><?php echo !empty($given_mark) ? $given_mark . '/' . $max_mark : '&nbsp;'; ?></td>
                                <td class="border-top-0"><?php echo tutor_utils()->translate_dynamic_text($status, true); ?></td>
                                <td class="border-top-0">
                                    <a href="<?php echo esc_url($review_url . '?view_assignment=' . $assignment->comment_ID) . '&assignment=' . $assignment_id; ?>" class="btn btn-primary tutor-btn5 bordered-btn tutor-announcement-details">
                                        <?php echo esc_html( $button_text ); ?>
                                    </a>
                                </td>
                            </tr>
                        <?php
                        }
                    } else {
                    ?>
                        <tr>
                            <td colspan="100%">
                                <div class="td-empty-state">
                                    <?php tutor_utils()->tutor_empty_state( 'No assignment', 'geeks' ); ?>
                                </div>
                            </td>
                        </tr>
                        <?php
                    }

                    ?>

                </tbody>
            </table>
        </div>
    </div>
</div>
