<?php
/**
 * Template for displaying instructors earnings
 *
 * @since v.1.1.2
 *
 * @author Themeum
 * @url https://themeum.com
 *
 * @package TutorLMS/Templates
 * @version 1.4.3
 */

global $wpdb;

$user_id = get_current_user_id();

/**
 * Getting the last week
 */
$start_date = date( 'Y-m-01' );
$end_date   = date( 'Y-m-t' );

$stats = tutils()->get_earning_chart( $user_id, $start_date, $end_date );
extract( $stats );

if ( ! $earning_sum ) {
	echo '<p>' . esc_html__( 'No Earning info available', 'geeks' ) . '</p>';
	return;
}

?>

<div class="tutor-dashboard-content-inner">

	<div class="tutor-dashboard-inline-links px-1 mb-4">
		<ul class="list-unstyled d-flex align-items-center nav nav-pills">
			<li class="nav-item ms-0">
				<a class="nav-link active" href="<?php echo esc_url( tutor_utils()->get_tutor_dashboard_page_permalink( 'earning' ) ); ?>">
					<?php esc_html_e( 'Earnings', 'geeks' ); ?>
				</a>
			</li>
			<li class="nav-item">
				<a class="nav-link" href="<?php echo esc_url( tutor_utils()->get_tutor_dashboard_page_permalink( 'earning/report' ) ); ?>">
					<?php esc_html_e( 'Reports', 'geeks' ); ?>
				</a>
			</li>
			<li class="nav-item">
				<a class="nav-link" href="<?php echo esc_url( tutor_utils()->get_tutor_dashboard_page_permalink( 'earning/statements' ) ); ?>">
					<?php esc_html_e( 'Statements', 'geeks' ); ?>
				</a>
			</li>
		</ul>
	</div>

		<div class="tutor-dashboard-info-cards row row-cols-lg-3 row-cols-md-1 row-cols-1">
			<div class="col">
				<div class="tutor-dashboard-info-card card mb-4">
					<p class="mb-0 p-4">
						<span class="fs-6 text-uppercase fw-semi-bold"> <?php esc_html_e( 'My Balance', 'geeks' ); ?> </span>
						<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo wp_kses_post( tutor_utils()->tutor_price( $earning_sum->balance ) ); ?></span>
					</p>
				</div>
			</div>

			<div class="col">
				<div class="tutor-dashboard-info-card card mb-4" title="<?php esc_attr_e( 'All Time', 'geeks' ); ?>">
					<p class="mb-0 p-4">
						<span class="fs-6 text-uppercase fw-semi-bold"> <?php esc_html_e( 'My Earnings', 'geeks' ); ?> </span>
						<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo wp_kses_post( tutor_utils()->tutor_price( $earning_sum->instructor_amount ) ); ?></span>
					</p>
				</div>
			</div>

			<div class="col">
				<div class="tutor-dashboard-info-card card mb-4"  title="<?php esc_attr_e( 'Based on course price', 'geeks' ); ?>">
					<p class="mb-0 p-4">
						<span class="fs-6 text-uppercase fw-semi-bold"> <?php esc_html_e( 'All time sales', 'geeks' ); ?> </span>
						<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo wp_kses_post( tutor_utils()->tutor_price( $earning_sum->course_price_total ) ); ?></span>
					</p>
				</div>
			</div>

			<div class="col">
				<div class="tutor-dashboard-info-card card mb-4" title="<?php esc_attr_e( 'All of withdraw type excluding rejected.', 'geeks' ); ?>">
					<p class="mb-0 p-4">
						<span class="fs-6 text-uppercase fw-semi-bold"> <?php esc_html_e( 'All time withdrawals', 'geeks' ); ?> </span>
						<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo wp_kses_post( tutor_utils()->tutor_price( $earning_sum->withdraws_amount ) ); ?></span>
					</p>
				</div>
			</div>

			<div class="col">  
				<div class="tutor-dashboard-info-card card mb-4">
					<p class="mb-0 p-4">
						<span class="fs-6 text-uppercase fw-semi-bold"> <?php esc_html_e( 'Deducted Commissions', 'geeks' ); ?> </span>
						<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo wp_kses_post( tutor_utils()->tutor_price( $earning_sum->admin_amount ) ); ?></span>
					</p>
				</div>
			</div>

			<?php if ( $earning_sum->deduct_fees_amount > 0 ) { ?>
				<div class="col">
					<div class="tutor-dashboard-info-card card mb-4">
						<p class="mb-0 p-4">
							<span class="fs-6 text-uppercase fw-semi-bold"> <?php esc_html_e( 'Deducted Fees.', 'geeks' ); ?> </span>
							<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo wp_kses_post( tutor_utils()->tutor_price( $earning_sum->deduct_fees_amount ) ); ?></span>
						</p>
					</div>
				</div>
			<?php } ?>
		</div>

		<div class="tutor-dashboard-item-group card mb-4">
			<div class="card-header">
				<h4 class="mb-0"><?php esc_html_e( 'Earnings Chart for this month', 'geeks' ); ?> (<?php echo date( 'F' ); ?>)</h4>
			</div>

			<div class="card-body">
				<canvas id="tutorChart" style="width: 100%; height: 400px;"></canvas>
			</div>
		</div>

</div>


<?php
$tutor_primary_color = tutor_utils()->get_option( 'tutor_primary_color' );
if ( ! $tutor_primary_color ) {
	$tutor_primary_color = '#3057D5';
}
?>

<script>
	var ctx = document.getElementById("tutorChart").getContext('2d');
	var tutorChart = new Chart(ctx, {
		type: 'line',
		data: {
			labels: <?php echo json_encode( array_keys( $chartData ) ); ?>,
			datasets: [{
				label: '<?php esc_html__( 'Earning', 'geeks' ); ?>',
				backgroundColor: '<?php echo esc_attr( $tutor_primary_color ); ?>',
				borderColor: '<?php echo esc_attr( $tutor_primary_color ); ?>',
				data: <?php echo json_encode( array_values( $chartData ) ); ?>,
				borderWidth: 2,
				fill: false,
				lineTension: 0,
			}]
		},
		options: {
			scales: {
				yAxes: [{
					ticks: {
						min: 0, // it is for ignoring negative step.
						beginAtZero: true,
						callback: function(value, index, values) {
							if (Math.floor(value) === value) {
								return value;
							}
						}
					}
				}]
			},

			legend: {
				display: false
			}
		}
	});
</script>
