<?php
/**
 * Template for displaying instructors earnings
 *
 * @since v.1.1.2
 *
 * @author Themeum
 * @url https://themeum.com
 *
 * @package TutorLMS/Templates
 * @version 1.4.3
 */

global $wpdb;

$user_id = get_current_user_id();

/**
 * Getting the Last Month
 */
$year = date( 'Y' );

$stats = tutils()->get_earning_chart_yearly( $user_id, $year );
extract( $stats );

if ( ! $earning_sum ) {
	echo '<p>' . esc_html__( 'No Earning info available', 'geeks' ) . '</p>';
	return;
}
?>
<div class="tutor-dashboard-info-cards row row-cols-lg-3 row-cols-md-1 row-cols-1">
	<div class="col">
		<div class="tutor-dashboard-info-card card mb-4" title="<?php echo esc_attr__( 'All time', 'geeks' ); ?>">
			<p class="mb-0 p-4">
				<span class="fs-6 text-uppercase fw-semi-bold"> <?php echo esc_html__( 'My Earning', 'geeks' ); ?> </span>
				<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo tutor_utils()->tutor_price( $earning_sum->instructor_amount ); ?></span>
			</p>
		</div>
	</div>

	<div class="col">
		<div class="tutor-dashboard-info-card card mb-4" title="<?php echo esc_attr__( 'Based on course price', 'geeks' ); ?>">
			<p class="mb-0 p-4">
				<span class="fs-6 text-uppercase fw-semi-bold"> <?php echo esc_html__( 'All time sales', 'geeks' ); ?> </span>
				<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo tutor_utils()->tutor_price( $earning_sum->course_price_total ); ?></span>
			</p>
		</div>
	</div>

	<div class="col">
		<div class="tutor-dashboard-info-card card mb-4">
			<p class="mb-0 p-4">
				<span class="fs-6 text-uppercase fw-semi-bold"> <?php echo esc_html__( 'Deducted Commissions', 'geeks' ); ?> </span>
				<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo tutor_utils()->tutor_price( $earning_sum->admin_amount ); ?></span>
			</p>
		</div>
	</div>


	<?php if ( $earning_sum->deduct_fees_amount > 0 ) { ?>
		<div class="col">
			<div class="tutor-dashboard-info-card card mb-4" title="<?php echo esc_attr__( 'Deducted Fees', 'geeks' ); ?>">
				<p class="mb-0 p-4">
					<span class="fs-6 text-uppercase fw-semi-bold"> <?php echo esc_html__( 'Deducted Fees', 'geeks' ); ?> </span>
					<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo tutor_utils()->tutor_price( $earning_sum->deduct_fees_amount ); ?></span>
				</p>
			</div>
		</div>
	<?php } ?>
</div>


<div class="tutor-dashboard-item-group card mb-4">
	<div class="card-header">
		<h4 class="mb-0"><?php echo sprintf( esc_html__( 'Earning Data for the year of %s', 'geeks' ), $year ); ?></h4>
	</div>

	<div class="card-body">
		<?php
		tutor_load_template( 'dashboard.earning.chart-body', compact( 'chartData', 'statements' ) );
		?>
	</div>
</div>

<div class="tutor-dashboard-item-group card mb-4">
	<div class="card-header">
		<h4 class="mb-0"><?php esc_html_e( 'Sales statements for this period', 'geeks' ); ?></h4>
	</div>

	<div class="card-body">
		<?php tutor_load_template( 'dashboard.earning.statement', compact( 'chartData', 'statements' ) ); ?>
	</div>
</div>
