<?php
/**
 * My Courses Page
 *
 * @package Tutor\Templates
 * @subpackage Dashboard
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.4.3
 */

use TUTOR\Input;
use Tutor\Models\CourseModel;

$post_meta_items = [
	'duration' => 'geeks_tutor_loop_meta_course_duration',
	'level'    => 'geeks_tutor_loop_meta_course_level',
];

$current_user_id = get_current_user_id();
!isset($active_tab) ? $active_tab = 'my-courses' : 0;

// Map required course status according to page.
$status_map = array(
	'my-courses'                 => CourseModel::STATUS_PUBLISH,
	'my-courses/draft-courses'   => CourseModel::STATUS_DRAFT,
	'my-courses/pending-courses' => CourseModel::STATUS_PENDING,
);

// Set currently required course status fo rcurrent tab
$status = isset( $status_map[ $active_tab ] ) ? $status_map[ $active_tab ] : CourseModel::STATUS_PUBLISH;

// Get counts for course tabs
$count_map = array(
	'publish' => tutor_utils()->get_courses_by_instructor( $current_user_id, CourseModel::STATUS_PUBLISH, 0, 0, true ),
	'pending' => tutor_utils()->get_courses_by_instructor( $current_user_id, CourseModel::STATUS_PENDING, 0, 0, true ),
	'draft'   => tutor_utils()->get_courses_by_instructor( $current_user_id, CourseModel::STATUS_DRAFT, 0, 0, true ),
);

$course_archive_arg = isset($GLOBALS['tutor_course_archive_arg']) ? $GLOBALS['tutor_course_archive_arg']['column_per_row'] : null;
$courseCols         = null === $course_archive_arg ? tutor_utils()->get_option( 'courses_col_per_row', 4 ) : $course_archive_arg;
$per_page           = tutor_utils()->get_option( 'courses_per_page', 10 );
$paged              = Input::get( 'current_page', 1, Input::TYPE_INT );
$offset             = $per_page * ($paged-1);
$results            = tutor_utils()->get_courses_by_instructor($current_user_id, $status, $offset, $per_page);

?>
<div class="card mb-4">
	<div class="card-header">
		<h3 class="mb-0"><?php echo esc_html__( 'My Courses', 'geeks' ); ?></h3>
		<p class="mb-0"><?php esc_html_e( 'Manage your courses and its updates.', 'geeks' ); ?></p>
	</div>

	<div class="tutor-dashboard-inline-links px-4 pt-2">
		<ul class="border-0 list-unstyled d-flex align-items-center nav nav-lb-tab">
			<li class="ms-0 nav-item">
                <a class="nav-link <?php echo esc_attr( $active_tab == 'my-courses' ? 'active' : '' ); ?>" href="<?php echo esc_url(tutor_utils()->get_tutor_dashboard_page_permalink('my-courses')); ?>">
                    <?php esc_html_e('Publish', 'geeks'); ?> <?php echo "(" . $count_map['publish'] . ")"; ?>
                </a>
            </li>
            <li class="nav-item">
                <a class="nav-link <?php echo esc_attr( $active_tab == 'my-courses/pending-courses' ? 'active' : '' ); ?>" href="<?php echo esc_url(tutor_utils()->get_tutor_dashboard_page_permalink('my-courses/pending-courses')); ?>">
                    <?php esc_html_e('Pending', 'geeks'); ?> <?php echo "(" . $count_map['pending'] . ")"; ?>
                </a>
            </li>
             <li class="nav-item">
                <a class="nav-link <?php echo esc_attr( $active_tab == 'my-courses/draft-courses' ? 'active' : '' ); ?>" href="<?php echo esc_url(tutor_utils()->get_tutor_dashboard_page_permalink('my-courses/draft-courses')); ?>">
                    <?php esc_html_e('Draft', 'geeks'); ?> <?php echo "(" . $count_map['draft'] . ")"; ?>
                </a>
            </li>
		</ul>
	</div>
</div>

<div class="tutor-dashboard-content-inner my-courses">
	 <!-- Course list -->
	<?php
	$placeholder_img = tutor()->url . 'assets/images/placeholder.png';

if ( !is_array($results) || (!count($results) && $paged==1) ) {
        tutor_utils()->tutor_empty_state(tutor_utils()->not_found_text());
    } else {
    	global $post;
	    ?>
	    <div class="tutor-grid tutor-grid-3">
	        <?php


	        foreach ($results as $post) :
	            setup_postdata($post);

	            $avg_rating         = tutor_utils()->get_course_rating()->rating_avg;
				$tutor_course_img   = get_tutor_course_thumbnail_src();
				$id_string_delete   = 'tutor_my_courses_delete_' . $post->ID;
				$row_id             = 'tutor-dashboard-my-course-' . $post->ID;
				$course_duration    = get_tutor_course_duration_context( $post->ID, true );
				$course_students    = tutor_utils()->count_enrolled_users_by_course();
				$is_main_instructor = CourseModel::is_main_instructor( $post->ID );

	            do_action('tutor_course/archive/before_loop_course');


	        ?>

	      	<div id="<?php echo esc_attr( $row_id ); ?>" class="card card-hover tutor-mycourse-<?php the_ID(); ?>">

				<a href="<?php the_permalink(); ?>" class="card-img-top">
					<?php if ( has_post_thumbnail() ) : ?>
						<?php the_post_thumbnail( 'full', array( 'class' => 'card-img-top rounded-top-md' ) ); ?>
					<?php endif; ?>
				</a>
				<?php if ( false === $is_main_instructor ) : ?>
				<div class="tutor-course-co-author-badge"><?php esc_html_e( 'Co-author', 'geeks' ); ?></div>
				<?php endif; ?>

				<!-- Card body -->
				<div class="card-body">

					<?php do_action( 'geeks_courses_card_body_top' ); ?>
					
					<h4 class="mb-2 text-truncate-line-2 ">
						<a href="<?php the_permalink(); ?>" class="text-inherit"><?php the_title(); ?></a>
					</h4>
					
					<?php if ( isset( $post_meta_items ) ) : ?>
					<!-- List inline -->
					<ul class="mb-0 list-inline">
						<?php 
						foreach ( $post_meta_items as $post_meta_item ) :
							
							ob_start();
							call_user_func( $post_meta_item );
							$list_item = ob_get_clean();
							
							if ( ! empty( $list_item ) ) :
						?>
						<li class="list-inline-item"><?php echo wp_kses( $list_item, 'post-svg' ); ?></li>
						<?php 
							endif;
						endforeach; 
						?>
					</ul>
					<?php endif; ?>
				</div>
		
				<div class="card-footer rounded-3 rounded-top-left-0 rounded-top-right-0">
		            <div class="d-flex align-items-center justify-content-between">
		                <div class="d-flex align-items-center">
		                    <span class="tutor-text-medium-caption tutor-color-text-hints tutor-mr-3">
		                        <?php esc_html_e('Price:', 'geeks') ?>
		                    </span>
		                    <span class="tutor-fs-7 tutor-fw-medium tutor-color-black">
                                <?php
                                    $price = tutor_utils()->get_course_price();
                                    if ( null === $price ) {
                                        esc_html_e( ' Free', 'geeks' );
                                    } else {
                                        echo wp_kses_post( tutor_utils()->get_course_price() );
                                    }
                                ?>
                            </span>
		                </div>
		                <div class="d-flex align-items-center">
		                    <a href="<?php echo esc_url( tutor_utils()->course_edit_link($post->ID) ); ?>" class="tutor-btn tutor-btn-icon tutor-btn-disable-outline tutor-btn-ghost tutor-no-hover tutor-btn-sm">
		                        <i class="fe fe-edit"></i>
		                    </a>
		                    <?php if ( $is_main_instructor && in_array( $post->post_status, array( CourseModel::STATUS_PUBLISH, CourseModel::STATUS_DRAFT ) ) ) : ?>
		                    <a href="#" data-tutor-modal-target="<?php echo esc_attr( $id_string_delete ); ?>" class="tutor-dashboard-element-delete-btn tutor-btn tutor-btn-icon tutor-btn-disable-outline tutor-btn-ghost tutor-no-hover tutor-btn-sm ms-2">
		                        <i class="fe fe-trash"></i>
		                    </a>
		                    <?php endif; ?>
							<!-- # Delete Action -->
		                </div>
		            </div>
		        </div>
				
	            <!-- Delete prompt modal -->
	            <div id="<?php echo esc_attr( $id_string_delete ); ?>" class="tutor-modal">
	                <span class="tutor-modal-overlay"></span>
	                <div class="tutor-modal-window">
	                    <div class="tutor-modal-content tutor-modal-content-white">
	                    	 <button data-tutor-modal-close class="tutor-modal-close-o bg-transparent border-0">
			                    <span class="tutor-icon-times"></span>
			                </button>
	                        <div class="tutor-modal-body tutor-text-center">
	                            <div class="tutor-mt-48 tutor-modal-icon">
	                                <img class="tutor-d-inline-block" src="<?php echo tutor()->url; ?>assets/images/icon-trash.svg" />
	                            </div>
	                            <div class="tutor-modal-text-wrap">
	                                <h3 class="tutor-modal-title tutor-fs-3 tutor-fw-medium tutor-color-black tutor-mb-12">
	                                    <?php esc_html_e('Delete This Course?', 'geeks'); ?>
	                                </h3>
	                                <p class="tutor-fs-6 tutor-color-muted">
	                                    <?php esc_html_e('Are you sure you want to delete this course permanently from the site? Please confirm your choice.', 'geeks'); ?>
	                                </p>
	                            </div>
	                            <div class="tutor-d-flex tutor-justify-center tutor-my-48">
	                                <button data-tutor-modal-close class="tutor-btn tutor-btn-outline-primary">
	                                    <?php esc_html_e('Cancel', 'geeks'); ?>
	                                </button>
	                             
	                                <button class="btn btn-primary ms-3 tutor-btn tutor-list-ajax-action" data-request_data='{"course_id":<?php echo esc_attr( $post->ID ); ?>,"action":"tutor_delete_dashboard_course","redirect_to":"<?php echo esc_url( tutor_utils()->get_current_url() ); ?>"}' data-delete_element_id="<?php echo esc_attr( $row_id ); ?>">
	                                    <?php esc_html_e('Yes, Delete This', 'geeks'); ?>
	                                </button>
	                            </div>
	                        </div>
	                    </div>
	                </div>
	            </div>
	        </div>
	        <?php do_action('tutor_course/archive/after_loop_course'); ?>

	    	<?php endforeach;
	    	wp_reset_postdata(); 
	    	?>
	    </div>
		
	    <div class="tutor-mt-20">
            <?php
                if ($count_map[$status] > $per_page) {
                    $pagination_data = array(
                        'total_items' => $count_map[$status],
                        'per_page'    => $per_page,
                        'paged'       => $paged,
                    );

                    tutor_load_template_from_custom_path(
                        tutor()->path . 'templates/dashboard/elements/pagination.php',
                        $pagination_data
                    );
                }
            ?>

        </div>
	 <?php
    } 
    ?>
</div>
