<?php
/**
 * Reviews received
 *
 * @package Tutor\Templates
 * @subpackage Dashboard
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.4.3
 */

if ( ! tutor_utils()->is_instructor( 0, true ) ) {
	include __DIR__ . '/reviews/given-reviews.php';
	return;
}

use TUTOR\Input;

// Pagination Variable.
$per_page     = tutor_utils()->get_option( 'pagination_per_page', 20 );
$current_page = max( 1, Input::get( 'current_page', 1, Input::TYPE_INT ) );
$offset       = ( $current_page - 1 ) * $per_page;

$reviews     = tutor_utils()->get_reviews_by_instructor( get_current_user_id(), $offset, $per_page );
$given_count = tutor_utils()->get_reviews_by_user( 0, 0, 0, true )->count;

?>
<div class="card">
	<div class="card-header">
		<h3 class="mb-0"><?php esc_html_e( 'Reviews', 'geeks' ); ?></h3>
	</div>

	<div class="tutor-dashboard-content-inner">

		<?php
		if ( current_user_can( tutor()->instructor_role ) ) {
			?>
			<div class="tutor-dashboard-inline-links px-4 pt-2">
				<ul class="list-unstyled d-flex align-items-center nav nav-lb-tab">
					<li class="nav-item ms-0">
						<a class="nav-link active" href="<?php echo esc_url( tutor_utils()->get_tutor_dashboard_page_permalink( 'reviews' ) ); ?>"> 
							<?php esc_html_e( 'Received', 'geeks' ); ?>
						</a> 
					</li>

					<?php if ( $given_count ) : ?>
						<li class="nav-item"> 
							<a class="nav-link" href="<?php echo esc_url( tutor_utils()->get_tutor_dashboard_page_permalink( 'reviews/given-reviews' ) ); ?>"> 
								<?php esc_html_e( 'Given', 'geeks' ); ?>
							</a> 
						</li>
					<?php endif; ?>
				</ul>
			</div>
		<?php } ?>

		<div class="tutor-dashboard-reviews-wrap card-body py-0">
			<?php if ( $reviews->count ) : ?>
				<ul class="tutor-dashboard-reviews list-group list-group-flush">
					<?php
					
					foreach ( $reviews->results as $review ) {
						?>
						<li class="list-group-item px-0 py-4 tutor-dashboard-single-review tutor-review-<?php echo esc_html( $review->comment_ID );?>">
							<div class="d-flex">
								<?php echo wp_kses_post( get_avatar( $review->comment_post_ID, 56, '', '', array( 'class' => 'rounded-circle avatar-lg' ) ) ); ?>
								<div class="ms-3 mt-2">
									<div class="d-flex align-items-center justify-content-between">
										<div>
											<h4 class="mb-0"><?php echo esc_html( $review->comment_author ); ?></h4>
											<span class="fs-6 text-muted"><?php echo esc_html( sprintf( esc_html__( '%s ago', 'geeks' ), human_time_diff( strtotime( $review->comment_date ) ) ) ); ?></span>
										</div>
									</div>
									<div class="mt-2">
										<span class="me-1"><?php geeks_display_review_stars( $review->rating ); ?></span>
										<span class="me-1"><?php echo esc_html__( 'for', 'geeks' ); ?></span>
										<span class="h5"><?php echo esc_html( get_the_title( $review->comment_post_ID ) ); ?></span>
										<div class="mt-2"><?php echo wp_kses_post( stripslashes( $review->comment_content ) ); ?></div>

									</div>
								</div>
							</div>
						</li>
						<?php
					}
					?>
				</ul>
			<?php else : ?>
			<div class="tutor-dashboard-content-inner">
				<?php tutor_utils()->tutor_empty_state( tutor_utils()->not_found_text() ); ?>
			</div>
		<?php endif; ?>
		</div>
	</div>
</div>

<?php
	if ( $reviews->count > $per_page ) {
		$pagination_data = array(
			'total_items' => $reviews->count,
			'per_page'    => $per_page,
			'paged'       => $current_page,
		);
		
		$pagination_template_frontend = tutor()->path . 'templates/dashboard/elements/pagination.php';
		tutor_load_template_from_custom_path( $pagination_template_frontend, $pagination_data );
	}
?>




