<?php
/**
 * My Own reviews
 *
 * @package Tutor\Templates
 * @subpackage Dashboard\Reviews
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.1.2
 */

use TUTOR\Input;

// Pagination Variable.
$per_page     = tutor_utils()->get_option( 'pagination_per_page', 1 );
$current_page = max( 1, Input::get( 'current_page', 0, Input::TYPE_INT ) );
$offset       = ( $current_page - 1 ) * $per_page;


$all_reviews    = tutor_utils()->get_reviews_by_user( 0, $offset, $per_page, true );
$review_count   = $all_reviews->count;
$reviews        = $all_reviews->results;
$received_count = tutor_utils()->get_reviews_by_instructor( 0, 0, 0 )->count;
?>
<div class="card">
	<div class="card-header">
		<h3 class="mb-0"><?php esc_html_e( 'Reviews', 'geeks' ); ?></h3>
	</div>
	<div class="tutor-dashboard-content-inner">
		
		<?php
		if ( current_user_can( tutor()->instructor_role ) ) {
			?>
			<div class="tutor-dashboard-inline-links px-4 pt-2">
				<ul class="list-unstyled d-flex align-items-center nav nav-lb-tab">
					<li class="nav-item ms-0">
						<a class="nav-link" href="<?php echo tutor_utils()->get_tutor_dashboard_page_permalink( 'reviews' ); ?>"> 
							<?php esc_html_e( 'Received', 'geeks' ); ?>
						</a> 
					</li>

					<li class="nav-item"> 
						<a class="nav-link active" href="<?php echo tutor_utils()->get_tutor_dashboard_page_permalink( 'reviews/given-reviews' ); ?>"> 
							<?php esc_html_e( 'Given', 'geeks' ); ?>
						</a> 
					</li>
				</ul>
			</div>
		<?php } ?>

		<div class="tutor-dashboard-reviews-wrap card-body py-0">
			<?php
			if ( ! is_array( $reviews ) || ! count( $reviews ) ) {
				?>
				<div class="tutor-dashboard-content-inner">
					<?php //tutor_utils()->tutor_empty_state( tutor_utils()->not_found_text() ); ?>
				</div>
				<?php
			}
			?>

			<ul class="tutor-dashboard-reviews list-group list-group-flush">
				<?php
				$total_reviews = count( $reviews );
				$review_index = 1;

				foreach ( $reviews as $review ) {
					$profile_url = tutor_utils()->profile_url( $review->user_id, false );
					$update_id   = 'tutor_review_update_' . $review->comment_ID;
					$delete_id   = 'tutor_review_delete_' . $review->comment_ID;
					$row_id      = 'tutor_review_row_' . $review->comment_ID;
					
					?>
					<li class="px-0 list-group-item py-4 tutor-dashboard-single-review tutor-review-<?php echo esc_html( $review->comment_ID ); ?>" id="<?php echo esc_html( $row_id ); ?>">
						
						<div class="d-md-flex justify-content-between">
							<div>
								<h4 class="mb-0"><?php echo esc_html( $review->comment_author ); ?></h4>
								<span class="fs-6 text-muted"><?php echo esc_html( sprintf( esc_html__( '%s ago', 'geeks' ), human_time_diff( strtotime( $review->comment_date ) ) ) ); ?></span>
							</div>
							<div class="mt-2 mt-md-0 tutor-given-review-action text-primary tutor-color-text-subsued tutor-bs-d-flex tutor-bs-align-items-center">
								<span data-tutor-modal-target="<?php echo esc_html( $update_id ); ?>" class="tutor-bs-d-flex tutor-bs-align-items-center">
									<i class="tutor-icon-edit-filled fs-3 tutor-mr-3"></i>
									<span><?php esc_html_e( 'Edit', 'geeks' ); ?></span>
								</span>
								<span data-tutor-modal-target="<?php echo esc_html( $delete_id ); ?>" class="ms-2 tutor-bs-d-flex tutor-bs-align-items-center">
									<i class="tutor-icon-delete-stroke-filled fs-3 tutor-mr-3"></i>
									<span><?php esc_html_e( 'Delete', 'geeks' ); ?></span>
								</span>
							</div>
						</div>

						<div class="mt-2">
							<span class="me-1"><?php geeks_display_review_stars( $review->rating ); ?></span>
							<span class="me-1"><?php echo esc_html__( 'for', 'geeks' ); ?></span>
							<span class="h5"><?php echo esc_html( get_the_title( $review->comment_post_ID ) ); ?></span>
							<div class="mt-2"><?php echo esc_textarea( htmlspecialchars( stripslashes( $review->comment_content ) ) ); ?></div>

						</div>
						
						<!-- Edit Modal -->
						<form class="tutor-modal tutor-modal-is-close-inside-inner modal-sticky-header-footer" id="<?php echo esc_html( $update_id ); ?>">
								<span class="tutor-modal-overlay"></span>
								<div class="tutor-modal-window">
									<div class="tutor-modal-content tutor-modal-content-white">
										<button data-tutor-modal-close="" class="tutor-modal-close-o bg-transparent border-0">
											<span class="tutor-icon-times"></span>
										</button>
										<div class="tutor-modal-body tutor-text-center">
											<div class="tutor-fs-3 tutor-fw-medium tutor-color-black tutor-mt-48 tutor-mb-12"><?php esc_html_e("How would you rate this course?", "geeks"); ?></div>
											<div class="tutor-fs-6 tutor-color-muted"><?php esc_html_e('Select Rating', 'geeks'); ?></div>
											<input type="hidden" name="course_id" value="<?php echo esc_html( $review->comment_post_ID ); ?>"/>
											<input type="hidden" name="review_id" value="<?php echo esc_html( $review->comment_ID ); ?>"/>
											<input type="hidden" name="action" value="tutor_place_rating"/>

											<div class="tutor-ratings tutor-ratings-lg tutor-ratings-selectable tutor-justify-center tutor-mt-16" tutor-ratings-selectable>
												<?php
													tutor_utils()->star_rating_generator( tutor_utils()->get_rating_value( $review->rating ) );
												?>
											</div>
											<textarea class="tform-control tutor-form-control tutor-mt-28" name="review" placeholder="<?php esc_html_e( 'write a review', 'geeks' ); ?>"><?php echo esc_html( stripslashes( $review->comment_content ) ); ?></textarea>

											<div class="mt-3 tutor-modal-delete-footer tutor-modal-btns tutor-btn-group">
													<button data-tutor-modal-close type="button" data-action="back" class="tutor-btn btn btn-outline-primary">
														<?php esc_html_e( 'Cancel', 'geeks' ); ?>
													</button>
													<button type="submit" data-action="next" class="mt-md-0 ms-2 tutor-btn btn btn-primary tutor_submit_review_btn">
														<?php esc_html_e( 'Update Review', 'geeks' ); ?>
													</button>
											</div>
										</div>
									</div>
								</div>
							<!-- </div> -->
						</form>

						<!-- Delete Modal -->
						<?php
						tutor_load_template(
							'modal.confirm',
							array(
								'id'      => $delete_id,
								'image'   => 'icon-trash.svg',
								'title'   => __( 'Do You Want to Delete This Review?', 'geeks' ),
								'content' => __( 'Are you sure you want to delete this review permanently from the site? Please confirm your choice.', 'geeks' ),
								'yes'     => array(
									'text'  => __( 'Yes, Delete This', 'geeks' ),
									'class' => 'tutor-list-ajax-action',
									'attr'  => array( 'data-request_data=\'{"action":"delete_tutor_review", "review_id":"' . $review->comment_ID . '"}\'', 'data-delete_element_id="' . $row_id . '"' ),
								),
							)
						);
						?>
					</li>
					<?php
				}
				?>
			</ul>
		</div>
	</div>
</div>
<?php
if ( $all_reviews->count > $per_page ) {
	$pagination_data              = array(
		'total_items' => $all_reviews->count,
		'per_page'    => $per_page,
		'paged'       => $current_page,
	);
	$pagination_template_frontend = tutor()->path . 'templates/dashboard/elements/pagination.php';
	tutor_load_template_from_custom_path( $pagination_template_frontend, $pagination_data );
}
?>
