<?php
/**
 * Courses taken template
 *
 * @package Tutor\Templates
 * @subpackage Profile
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.4.3
 */

$user_name = sanitize_text_field( get_query_var( 'tutor_profile_username' ) );
$get_user  = tutor_utils()->get_user_by_login( $user_name );
$user_id   = $get_user->ID;

$pageposts = tutor_utils()->get_courses_by_instructor( $user_id );

$post_meta_items = [
	'duration' => 'geeks_tutor_loop_meta_course_duration',
	'level'    => 'geeks_tutor_loop_meta_course_level',
	'rating'   => 'geeks_tutor_meta_course_rating',
];

?>


<ul class="list-unstyled list-group list-group-flush tutor-courses">
	<?php
	if ( $pageposts ) :
		global $post;
		$index = 0;

		foreach ( $pageposts as $post ) :
			$tutor_course_img = get_tutor_course_thumbnail_src();

			setup_postdata( $post );

			/**
			 * @hook tutor_course/archive/before_loop_course
			 * @type action
			 * Usage Idea, you may keep a loop within a wrap, such as bootstrap col
			 */
			do_action( 'before_course_taken' );
			$list_classes = 'p-0';

			if ( 0 === $index && count( $pageposts ) !== $index + 1 ) {
				$list_classes = 'pb-3 pt-0';
			} elseif ( count( $pageposts ) !== $index + 1 ) {
				$list_classes = 'py-3';
			} elseif ( 0 !== $index ) {
				$list_classes = 'pb-0 pt-3';
			}
			?>
			<li class="list-group-item px-0 <?php echo esc_attr( $list_classes ); ?>">
				<div class="d-flex align-items-center justify-content-between">
					<a href="<?php the_permalink(); ?>">
						<div class="d-lg-flex align-items-center">
							<div>
								<img src="<?php echo esc_url( $tutor_course_img ); ?>" class="mw-none rounded img-4by3-lg" alt>
							</div>

							<div class="ms-lg-3 mt-2 mt-lg-0">
								<h4 class="text-primary-hover"><?php the_title(); ?></h4>
									<?php if ( isset( $post_meta_items ) ) : ?>

										<ul class="list-inline fs-6 mb-0 text-inherit">
										<?php
										foreach ( $post_meta_items as $post_meta_item ) :

											ob_start();
											call_user_func( $post_meta_item );
											$list_item = ob_get_clean();

											if ( ! empty( $list_item ) ) :
												?>
											<li class="list-inline-item"><?php echo wp_kses( $list_item, 'post-svg' ); ?></li>
												<?php
											endif;
										endforeach;
										?>
									</ul>
								<?php endif; ?>
							</div>
						</div>
					</a>

            		<?php if (tutor_utils()->get_option('enable_course_share', false, true, true)) {
						$tutor_social_share_icons = tutor_utils()->tutor_social_share_icons();
					?>
						<div>
							<?php $course_dropdown_id = 'courseDropdown-' . $post->ID; ?>
							<!-- Dropdown -->
							<span class="dropdown dropstart share-dropdown">
								<a class="text-muted text-decoration-none" href="#" role="button" id="<?php echo esc_attr( $course_dropdown_id ); ?>" data-bs-toggle="dropdown" aria-expanded="false">
									<i class="fe fe-more-vertical"></i>
								</a>
								<span class="dropdown-menu" aria-labelledby="<?php echo esc_attr( $course_dropdown_id ); ?>">
									<?php tutor_load_template( 'single.course.social_share', array( 'tutor_social_share_icons' => $tutor_social_share_icons ) ); ?>
								</span>
							</span>
						</div>
					<?php } ?>	
					 
				</div>
			</li>
			<?php

			/**
			 * @hook tutor_course/archive/after_loop_course
			 * @type action
			 * Usage Idea, If you start any div before course loop, you can end it here, such as </div>
			 */
			do_action( 'after_course_taken' );
			$index++;
		endforeach;
	else :
		?>
	<li>
		<?php esc_html_e( 'No course yet.', 'geeks' ); ?>
	</li>
	<?php endif; ?>
</ul>
