<?php
/**
 * Display single course add to cart
 *
 * @since v.1.0.0
 *
 * @package TutorLMS/Templates
 * @version 1.4.3
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$monetize_by              = tutils()->get_option( 'monetize_by' );
$enable_guest_course_cart = tutor_utils()->get_option( 'enable_guest_course_cart' );

$is_public      = 'yes' === get_post_meta( get_the_ID(), '_tutor_is_public_course', true );
$is_purchasable = tutor_utils()->is_course_purchasable();

$required_loggedin_class = '';
if ( ! is_user_logged_in() && ! $is_public ) {
	$required_loggedin_class = apply_filters( 'tutor_enroll_required_login_class', 'cart-required-login' );
}
if ( $is_purchasable && 'wc' === $monetize_by && $enable_guest_course_cart ) {
	$required_loggedin_class = '';
}

$tutor_form_class = apply_filters(
	'tutor_enroll_form_classes',
	array(
		'tutor-enroll-form',
	)
);

$tutor_course_sell_by = apply_filters( 'tutor_course_sell_by', null );

do_action( 'tutor_course/single/add-to-cart/before' ); //phpcs:ignore WordPress.NamingConventions.ValidHookName.UseUnderscores

$is_tutor_login_disabled = tutils()->get_option( 'disable_tutor_native_login' );

$auth_url = '';
$uri      = gke_get_server_value( 'REQUEST_URI' );
$host     = gke_get_server_value( 'HTTP_HOST' );

if ( $is_tutor_login_disabled ) {
	$scheme   = gke_get_server_value( 'REQUEST_SCHEME' );
	$auth_url = wp_login_url( $scheme ) . '://' . $host . $uri;
}

?>

<div class="tutor-single-add-to-cart-box <?php echo esc_attr( $required_loggedin_class ); ?> " data-login_page_url="<?php echo esc_url( $auth_url ); ?>">
	<?php
	if ( $is_purchasable && $tutor_course_sell_by ) {
		tutor_load_template( 'single.course.add-to-cart-' . $tutor_course_sell_by );
	} else {

		if ( $is_public ) {
			$first_lesson_url = tutor_utils()->get_course_first_lesson( get_the_ID(), tutor()->lesson_post_type );

			if ( ! $first_lesson_url ) {
				$first_lesson_url = tutor_utils()->get_course_first_lesson( get_the_ID() );
			}

			?>
			<div class="<?php echo esc_attr( implode( ' ', $tutor_form_class ) ); ?> ">
				<div class=" tutor-course-enroll-wrap d-grid">
					<a href="<?php echo esc_url( $first_lesson_url ); ?>" style="display:block">
						<button class="tutor-btn-enroll tutor-btn tutor-course-purchase-btn btn btn-primary btn-block w-100">
							<?php esc_html_e( 'Start Learning', 'geeks' ); ?>
						</button>
					</a>
				</div>
			</div>
			<?php
		} else {
			?>
			<form class="<?php echo esc_attr( implode( ' ', $tutor_form_class ) ); ?>" method="post">
				<?php wp_nonce_field( tutor()->nonce_action, tutor()->nonce ); ?>
				<input type="hidden" name="tutor_course_id" value="<?php echo get_the_ID(); ?>">
				<input type="hidden" name="tutor_course_action" value="_tutor_course_enroll_now">

				<div class="tutor-course-enroll-wrap d-grid">
					<button type="submit" class="tutor-btn-enroll tutor-btn tutor-course-purchase-btn btn btn-primary">
						<?php esc_html_e( 'Enroll Now', 'geeks' ); ?>
					</button>
				</div>
			</form>
			<?php
		}
	}
	?>
</div>

<?php do_action( 'tutor_course/single/add-to-cart/after' ); //phpcs:ignore WordPress.NamingConventions.ValidHookName.UseUnderscores ?>
