<?php
/**
 * Template for displaying student & instructor Public Profile.
 * It is used for both of instructor and student. Separate file has not been introduced due to complicacy and backward compatibility. -JK
 *
 * @since v.1.0.0
 *
 * @author Themeum
 * @url https://themeum.com
 *
 * @package TutorLMS/Templates
 * @version 1.4.3
 */

$user_name = sanitize_text_field( get_query_var( 'tutor_student_username' ) );
$get_user  = tutor_utils()->get_user_by_login( $user_name );

if ( ! is_object( $get_user ) || ! property_exists( $get_user, 'ID' ) ) {
	wp_redirect( get_home_url() . '/404' );
	exit;
}

$user_id       = $get_user->ID;
$is_instructor = tutor_utils()->is_instructor( $user_id );

$profile_layout                    = tutor_utils()->get_option( ( $is_instructor ? 'instructor' : 'student' ) . '_public_profile_layout', 'pp-circle' );
! $is_instructor ? $profile_layout = 'pp-circle' : 0; // For now

$tutor_user_social_icons = tutor_utils()->tutor_user_social_icons();

foreach ( $tutor_user_social_icons as $key => $social_icon ) {
	$url                                    = get_user_meta( $user_id, $key, true );
	$tutor_user_social_icons[ $key ]['url'] = $url;
}

$user_job_title = get_user_meta( $user_id, '_tutor_profile_job_title', true );

$is_administrator = current_user_can( 'administrator' );

if ( $is_instructor ) {
	$user_role = esc_html__( 'Instructor', 'geeks' );
}


get_header();

	// Rating content
	ob_start();
if ( $is_instructor ) {
	$instructor_rating = tutor_utils()->get_instructor_ratings( $user_id );

	?>
		<div class="tutor-rating-container">      
			<div class="ratings">
				<span class="rating-generated">
				<?php tutor_utils()->star_rating_generator( $instructor_rating->rating_avg ); ?>
				</span>

			<?php
			echo " <span class='rating-digits'>{$instructor_rating->rating_avg}</span> ";
			echo " <span class='rating-total-meta'>({$instructor_rating->rating_count})</span> ";
			?>
			</div>
		</div>
		<?php
}
	$rating_content = ob_get_clean();


	// Social media content
	ob_start();
foreach ( $tutor_user_social_icons as $key => $social_icon ) {
	$url = $social_icon['url'];
	echo ! empty( $url ) ? '<a href="' . $url . '" target="_blank" rel="noopener noreferrer nofollow" class="fs-5 me-2 pe-1 text-muted ' . $social_icon['icon_classes'] . '" title="' . $social_icon['label'] . '"></a>' : '';
}
	$social_media = ob_get_clean();

?>
	<div class="py-20" style="background: url(<?php echo esc_url( get_template_directory_uri() ); ?>/assets/images/background/profile-bg.jpg) no-repeat;background-size: cover; "></div>
	<div class="card p-lg-2 pt-2 pt-lg-0 rounded-0 border-0">
		<div class="container">
			<div class="row align-items-center">
				<div class="col-lg-8 col-md-8 col-12">
					<div class="d-flex align-items-center">
						<div class="position-relative mt-n9">
							<?php echo get_avatar( $user_id, 112, '', '', array( 'class' => 'h-100 h-md-auto rounded-circle avatar-xxl border-white border border-4 position-relative' ) ); ?>
							<?php if ( isset( $is_verified ) && $is_verified ) : ?>
								<a href="#" class="position-absolute top-0 end-0 me-2" data-bs-toggle="tooltip" data-placement="top" data-original-title="<?php esc_attr_e( 'Verified', 'geeks' ); ?>">
									<img src="<?php echo esc_url( get_template_directory_uri() ); ?>/assets/images/svg/checked-mark.svg" alt="" height="30" width="30" />
								</a>
							<?php endif; ?>
						</div>
						<div class="ms-3">
							<div class="d-flex align-items-center">
								<h3 class="mb-0 fw-bold me-2"><?php echo esc_html( get_the_author_meta( 'display_name', $user_id ) ); ?></h3>
								<?php if ( $is_instructor ) { ?>
									<span class="badge bg-light-primary text-primary"><?php echo esc_html( $user_role ); ?></span>
								<?php } ?>
							</div>
							<?php if ( ! empty( $user_job_title ) ) : ?>
								<span class="fs-6"><?php echo esc_html( $user_job_title ); ?></span>
							<?php endif; ?>
						</div>
					</div>
				</div>
				<div class="col-lg-4 col-md-4 col-12">
					<div class="fs-4 mt-4 mt-lg-0 pb-2 pb-lg-0 d-lg-flex justify-content-end">
						<?php echo wp_kses_post( $social_media ); ?>
					</div>
				</div>
			</div>
		</div>
	</div>

	<?php do_action( 'tutor_student/before/wrap' ); ?>
	<div class="py-5 py-md-5">
		<div class="container">
			<div class="row">
				<div class="col-lg-3 col-md-4 col-12">
					<div class="tutor-user-profile-content">
						<?php tutor_load_template( 'profile.bio' ); ?>

						<div class="card border-0 mb-4 mb-lg-0">
							<!-- Card body -->
							<div class="card-body">
								<?php
								if ( $is_instructor ) {
									$course_count  = tutor_utils()->get_course_count_by_instructor( $user_id );
									$student_count = tutor_utils()->get_total_students_by_instructor( $user_id );
									?>
									<div class="d-flex align-items-center justify-content-between border-bottom pb-3 mb-3">
										<div>
											<h4 class="mb-0 fw-bold"><?php echo esc_html( $course_count ); ?></h4>
											<p class="fs-6 mb-0"><?php $course_count > 1 ? esc_html_e( 'Courses', 'geeks' ) : esc_html_e( 'Course', 'geeks' ); ?></p>
										</div>
										<div>
											<span><i class="fe fe-file-text fs-3"></i></span>
										</div>
									</div>

									<div class="d-flex align-items-center justify-content-between border-bottom pb-3 mb-3">
										<div>
											<h4 class="mb-0 fw-bold"><?php echo esc_html( $student_count ); ?></h4>
											<p class="fs-6 mb-0"><?php $student_count > 1 ? esc_html_e( 'Total Students', 'geeks' ) : esc_html_e( 'Student', 'geeks' ); ?></p>
										</div>
										<div>
											<span><i class="fe fe-users fs-3"></i></span>
										</div>
									</div>

									<div class="d-flex align-items-center justify-content-between">
										<div>
											<h4 class="mb-0 fw-bold"><?php echo esc_html( $instructor_rating->rating_count ); ?></h4>
											<p class="fs-6 mb-0"><?php $instructor_rating->rating_count > 1 ? esc_html_e( 'Reviews', 'geeks' ) : esc_html_e( 'Reviews', 'geeks' ); ?></p>
										</div>
										<div>
											<span><i class="fe fe-star fs-3"></i></span>
										</div>
									</div>
									<?php
								} else {
									$enrolled_course = tutor_utils()->get_enrolled_courses_by_user( $user_id );
									$enrol_count     = is_object( $enrolled_course ) ? $enrolled_course->found_posts : 0;

									$complete_count = tutor_utils()->get_completed_courses_ids_by_user( $user_id );
									$complete_count = $complete_count ? count( $complete_count ) : 0;
									?>
									<div class="d-flex align-items-center justify-content-between border-bottom pb-3 mb-3">
										<div>
											<h4 class="mb-0 fw-bold"><?php echo esc_html( $enrol_count ); ?></h4>
											<p class="fs-6 mb-0"><?php $enrol_count > 1 ? esc_html_e( 'Courses Enrolled', 'geeks' ) : esc_html_e( 'Course Enrolled', 'geeks' ); ?></p>
										</div>
										<div>
											<span><i class="fe fe-file-text fs-3"></i></span>
										</div>
									</div>

									<div class="d-flex align-items-center justify-content-between">
										<div>
											<h4 class="mb-0 fw-bold"><?php echo esc_html( $complete_count ); ?></h4>
											<p class="fs-6 mb-0"><?php $complete_count > 1 ? esc_html_e( 'Courses Completed', 'geeks' ) : esc_html_e( 'Course Completed', 'geeks' ); ?></p>
										</div>
										<div>
											<span><i class="fe fe-file-text fs-3"></i></span>
										</div>
									</div>
									<?php
								}
								?>

							</div>
						</div>
					</div>
				</div>

				<?php if ( $is_instructor ) : ?>

					<div class="col-lg-9 col-md-8 col-12">
						<div class="card border-0">
							<div class="card-header">
								<h4 class="mb-0"><?php echo esc_html__( 'My Courses', 'geeks' ); ?>
									<span class="text-muted fs-6">(<?php echo esc_html( $course_count ); ?>)</span>
								</h4>
							</div>
							<div class="card-body">

								<?php
									add_filter(
										'courses_col_per_row',
										function() {
											return 3;
										}
									);

									tutor_load_template( 'profile.courses_taken' );
								?>

								<?php
									/*
									 if(tutor_utils()->get_option('show_courses_completed_by_student')){
										echo '<h3>',__('Course Completed', 'tutor'),'</h3>';
										tutor_load_template('profile.enrolled_course');
									} */
								?>

								<?php
									/*
									 if(tutor_utils()->get_option('students_own_review_show_at_profile')){
										echo '<h3>',__('Reviews Wrote', 'tutor'),'</h3>';
										tutor_load_template('profile.reviews_wrote');
									} */
								?>

							</div>
						</div>
					</div>
				<?php endif; ?>
			</div>
		</div>
	</div>


<?php do_action( 'tutor_student/after/wrap' ); ?>

<?php
get_footer();
