<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 8.6.0
 */

defined( 'ABSPATH' ) || exit;

get_header();

/**
 * Hook: woocommerce_before_main_content.
 *
 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
 * @hooked woocommerce_breadcrumb - 20
 * @hooked WC_Structured_Data::generate_website_data() - 30
 */
do_action( 'woocommerce_before_main_content' );

if ( is_active_sidebar( 'sidebar-shop' ) ) {
	$content_classes = 'col-xl-9 col-lg-9 col-md-8 col-12 order-2';
} else {
	$content_classes = 'col-12';
}

?>
<header class="woocommerce-products-header bg-primary py-4 py-lg-6">
	<div class="container">
		<?php if ( apply_filters( 'woocommerce_show_page_title', true ) ) : ?>
			<h1 class="woocommerce-products-header__title page-title mb-0 text-white display-4"><?php woocommerce_page_title(); ?></h1>
		<?php endif; ?>

		<?php
		/**
		 * Hook: woocommerce_archive_description.
		 *
		 * @hooked woocommerce_taxonomy_archive_description - 10
		 * @hooked woocommerce_product_archive_description - 10
		 */
		do_action( 'woocommerce_archive_description' );
		?>
	</div>
</header>

<div class="py-6">
	<div class="container">
		<div class="row">
		<?php
		if ( woocommerce_product_loop() ) {
			/**
			 * Hook: woocommerce_before_shop_loop.
			 *
			 * @hooked woocommerce_output_all_notices - 10
			 * @hooked woocommerce_result_count - 20
			 * @hooked woocommerce_catalog_ordering - 30
			 */
			do_action( 'woocommerce_before_shop_loop' );

			$active = geeks_get_shop_layout();

			$class_tp_grid = 'tab-pane fade pb-4';
			$class_tp_list = 'tab-pane fade pb-4';

			if ( 'grid' === $active ) {
				$class_tp_grid .= ' show active';
			}

			if ( 'list' === $active ) {
				$class_tp_list .= ' show active';
			}

			$list_view = '';

			?>
				<div class="<?php echo esc_attr( $content_classes ); ?>">
					<div class="tab-content">
						<div class="<?php echo esc_attr( $class_tp_grid ); ?>" id="tab-pane-grid" role="tabpanel" aria-labelledby="tab-pane-grid">
						<?php
							woocommerce_product_loop_start();
						if ( wc_get_loop_prop( 'total' ) ) {
							while ( have_posts() ) {
								the_post();

								/**
								 * Hook: woocommerce_shop_loop.
								 */
								do_action( 'woocommerce_shop_loop' );

								wc_get_template_part( 'content', 'product-grid-view' );

								ob_start();
								wc_get_template_part( 'content', 'product-list-view' );
								$list_view .= ob_get_clean();
							}
						}
							woocommerce_product_loop_end();
						?>
						</div>

						<div class="<?php echo esc_attr( $class_tp_list ); ?>" id="tab-pane-list" role="tabpanel" aria-labelledby="tab-pane-list">
							<?php echo wp_kses( $list_view, 'post-svg' ); ?>
						</div>
					</div>
				<?php
				/**
				 * Hook: woocommerce_after_shop_loop.
				 *
				 * @hooked woocommerce_pagination - 10
				 */
				do_action( 'woocommerce_after_shop_loop' );
				?>
				</div>
				<?php
		} else {
			/**
			 * Hook: woocommerce_no_products_found.
			 *
			 * @hooked wc_no_products_found - 10
			 */
			?>
				<div class="<?php echo esc_attr( $content_classes ); ?>">
				<?php do_action( 'woocommerce_no_products_found' ); ?>
				</div>
				<?php
		}
		?>


			<?php if ( is_active_sidebar( 'sidebar-shop' ) ) : ?>
				<div class="shop-sidebar col-lg-3 col-md-4 col-12 order-1 mb-4 mb-md-0 mb-0-last-child">
				<?php
					/**
					 * Hook: woocommerce_sidebar.
					 *
					 * @hooked woocommerce_get_sidebar - 10
					 */
					do_action( 'woocommerce_sidebar' );
				?>
				</div>
			<?php endif; ?>
		</div>
	</div>
</div>
<?php

do_action( 'woocommerce_after_main_content' );
get_footer();
?>
