<?php
/**
 * My Account navigation
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/navigation.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 2.6.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

do_action( 'woocommerce_before_account_navigation' );

$default_icons = apply_filters(
	'geeks_wc_account_endpoint_icons',
	[
		'dashboard'       => 'fe fe-home',
		'orders'          => 'fe fe-shopping-bag',
		'downloads'       => 'fe fe-download',
		'edit-address'    => 'fe fe-map-pin',
		'edit-account'    => 'fe fe-user',
		'payment-methods' => 'fe fe-credit-card',
		'customer-logout' => 'fe fe-power',
	]
);

?>
<div class="collapse navbar-collapse" id="sidenav">
	<div class="navbar-nav flex-column">

		<ul class="woocommerce-MyAccount-navigation-tab list-unstyled ms-n2 mb-0">
			<?php
			$index = 0;
			foreach ( wc_get_account_menu_items() as $endpoint => $label ) :
				$default_icon = isset( $default_icons[ $endpoint ] ) ? $default_icons[ $endpoint ] : '';
				$separator    = false;

				if ( is_array( $label ) ) {

					if ( isset( $label['type'] ) && $label['type'] == 'separator' ) {
						$separator = true;
					}
				}
				if ( $separator ) {
					if ( $label ) {
						?>
						<li class="<?php if ( 0 != $index ):?>mt-4<?php endif;?> tutor-dashboard-menu-divider-header">
							<span class="navbar-header"><?php echo esc_html( $label['title'] ); ?></span>
						</li>
						<?php
					}
				} else {
					if ( 'dashboard' === $endpoint && ( isset( $wp->query_vars['page'] ) || empty( $wp->query_vars ) ) ) { ?>
						<li class="<?php if ( 0 != $index ):?>mt-4<?php endif;?> tutor-dashboard-menu-divider-header">
							<span class="navbar-header">
								<?php echo esc_html__( 'Store', 'geeks' );?>									
							</span>
						</li>
					<?php } ?>
					
					<li class="nav-item <?php echo wc_get_account_menu_item_classes( $endpoint ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>">                    
						<a href="<?php echo esc_url( wc_get_account_endpoint_url( $endpoint ) ); ?>" class="nav-link">
							<?php if ( ! empty( $default_icon ) ) : ?>
								<i class="<?php echo esc_attr( $default_icon ); ?> nav-icon"></i>
							<?php endif; ?>
							<?php echo esc_html( $label ); ?>
						</a>
					</li>
					<?php
				}
				$index++;
			endforeach;
			?>

		</ul>
	</div>
</div>
<?php do_action( 'woocommerce_after_account_navigation' ); ?>
