<?php
/**
 * Display single product reviews (comments)
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product-reviews.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 4.3.0
 */

defined( 'ABSPATH' ) || exit;

global $product;

if ( ! comments_open() ) {
	return;
}

?>
<div class="single-product-review">
	<div id="reviews" class="woocommerce-Reviews">
		<?php do_action( 'geeks_single_product_reviews_before' ); ?>

			<div id="comments" class="mb-3">
				<div class="d-lg-flex align-items-center justify-content-between mb-5">
					<!-- Reviews -->
					<div class="mb-3 mb-lg-0">
						<h3 class="mb-0"><?php esc_html_e( 'Reviews', 'geeks' ); ?></h3>
					</div>
				</div>
				<?php
				if ( have_comments() ) :

					wp_list_comments(
						apply_filters(
							'woocommerce_product_review_list_args',
							[
								'style'        => 'div',
								'format'       => 'html5',
								'avatar_size'  => 56,
								'short_ping'   => false,
								'callback'     => 'woocommerce_comments',
								'end-callback' => function() {
									echo '</div>';
								},


							]
						)
					);

					geeks_wc_comments_navigation();
				else :
					?>
					<p class="woocommerce-noreviews alert alert-warning mb-4"><?php esc_html_e( 'There are no reviews yet.', 'geeks' ); ?></p>
					<?php
				endif;
				?>
			</div>

			<div class="rounded py-md-3 mt-4">
				<?php
				if ( get_option( 'woocommerce_review_rating_verification_required' ) === 'no' || wc_customer_bought_product( '', get_current_user_id(), $product->get_id() ) ) :
					$account_page_url = wc_get_page_permalink( 'myaccount' );
					$commenter        = wp_get_current_commenter();
					$is_req           = (bool) get_option( 'require_name_email', 1 );
					$_cf_args         = [];

					$_cf_args['class_form']      = 'comment-form row';
					$_cf_args['comment_field']   = '';
					$_cf_args['class_container'] = 'comment-respond mt-0';

					if ( wc_review_ratings_enabled() ) {
						$_cf_args['comment_field'] .= sprintf(
							'<label class="form-label">%1$s<span class="text-danger">*</span></label>
							<div class="form-group mb-2 comment-form-rating">
		                        <select name="rating" id="rating">
									<option value="">' . esc_html__( 'Rate&hellip;', 'geeks' ) . '</option>
									<option value="5">' . esc_html__( 'Perfect', 'geeks' ) . '</option>
									<option value="4">' . esc_html__( 'Good', 'geeks' ) . '</option>
									<option value="3">' . esc_html__( 'Average', 'geeks' ) . '</option>
									<option value="2">' . esc_html__( 'Not that bad', 'geeks' ) . '</option>
									<option value="1">' . esc_html__( 'Very Poor', 'geeks' ) . '</option>
		                        </select>
		                    </div>',
							esc_html__( 'Your rating', 'geeks' )
						);
					}

					$_cf_args['comment_field'] .= sprintf(
						'<div class="form-group comment-form-comment mb-3">
							<label for="comment" class="form-label p-0">%s<span class="text-danger">*</span></label>
							<textarea id="comment" name="comment" class="form-control" rows="8" maxlength="65525" required></textarea>
							<small class="form-text text-muted">' . esc_html__( ' Your review must be at least 50 characters.', 'geeks' ) . '</small>
						</div>',
						esc_html__( 'Review Content', 'geeks' )
					);

					// Other arguments.
					$_cf_args['logged_in_as']         = '';
					$_cf_args['label_submit']         = esc_html_x( 'Submit Review', 'front-end', 'geeks' );
					$_cf_args['title_reply']          = esc_html_x( 'Write a review', 'front-end', 'geeks' );
					$_cf_args['title_reply_to']       = esc_html__( 'Leave a Reply', 'geeks' );
					$_cf_args['title_reply_before']   = '<h3 id="reply-title" class="mb-3">';
					$_cf_args['title_reply_after']    = '</h3>';
					$_cf_args['submit_button']        = '<button type="submit" name="%1$s" id="%2$s" class="%3$s">%4$s</button>';
					$_cf_args['submit_field']         = '<div class="form-group form-submit mb-0">%1$s%2$s</div>';
					$_cf_args['class_submit']         = 'btn btn-primary btn-block';
					$_cf_args['comment_notes_after']  = '';
					$_cf_args['comment_notes_before'] = sprintf(
						'<p>%s %s <span class="text-danger">*</span></p>',
						esc_html_x( 'Your email address will not be published.', 'front-end', 'geeks' ),
						/* translators: related to comment form; phrase follows by red mark*/
						esc_html_x( 'Required fields are marked', 'front-end', 'geeks' )
					);

					if ( $account_page_url ) {
						/* translators: %s opening and closing link tags respectively */
						$_cf_args['must_log_in'] = '<p class="must-log-in">' . sprintf( esc_html__( 'You must be %1$slogged in%2$s to post a review.', 'geeks' ), '<a href="' . esc_url( $account_page_url ) . '" class="text-primary">', '</a>' ) . '</p>';
					}

					comment_form( apply_filters( 'woocommerce_product_review_comment_form_args', $_cf_args ) );
					?>
				<?php else : ?>
					<div class="media">
						<div class="me-3 fs-5 text-danger">
							<i class="fe fe-announcement"></i>
						</div>
						<div class="media-body">
							<p class="woocommerce-verification-required mb-0"><?php esc_html_e( 'Only logged in customers who have purchased this product may leave a review.', 'geeks' ); ?></p>
						</div>
					</div>
				<?php endif; ?>
			</div>

		<?php do_action( 'geeks_single_product_reviews_after' ); ?>

	</div>
</div>
